AccountChatThemes class

Account Chat Themes.

ID: be098173.

Inheritance

Constructors

AccountChatThemes({required int hash, required List<ChatThemeBase> themes, required List<ChatBase> chats, required List<UserBase> users, String? nextOffset})
Account Chat Themes constructor.
const
AccountChatThemes.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

chats List<ChatBase>
Chats.
final
flags int
Flags.
no setter
hash int
Hash.
final
hashCode int
The hash code for this object.
no setterinherited
nextOffset String?
Next Offset.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
themes List<ChatThemeBase>
Themes.
final
users List<UserBase>
Users.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited