AccountConnectedBots class
Account Connected Bots.
ID: 17d7f87b.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- AccountConnectedBotsBase
- AccountConnectedBots
Constructors
-
AccountConnectedBots({required List<
ConnectedBotBase> connectedBots, required List<UserBase> users}) -
Account Connected Bots constructor.
const
- AccountConnectedBots.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
-
connectedBots
→ List<
ConnectedBotBase> -
Connected Bots.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
users
→ List<
UserBase> -
Users.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited