AccountGetUniqueGiftChatThemes class

Account Get Unique Gift Chat Themes.

Return Type: AccountChatThemesBase. ID: e42ce9c9.

Inheritance

Constructors

AccountGetUniqueGiftChatThemes({required String offset, required int limit, required int hash})
Account Get Unique Gift Chat Themes constructor.
const
AccountGetUniqueGiftChatThemes.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hash int
Hash.
final
hashCode int
The hash code for this object.
no setterinherited
limit int
Limit.
final
offset String
Offset.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited