AccountInitTakeoutSession class

Account Init Takeout Session.

Return Type: AccountTakeoutBase. ID: 8ef3eab0.

Inheritance

Constructors

AccountInitTakeoutSession({required bool contacts, required bool messageUsers, required bool messageChats, required bool messageMegagroups, required bool messageChannels, required bool files, int? fileMaxSize})
Account Init Takeout Session constructor.
const
AccountInitTakeoutSession.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

contacts bool
contacts: bit 0 of flags.0?true
final
fileMaxSize int?
File Max Size.
final
files bool
files: bit 5 of flags.5?true
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
messageChannels bool
message_channels: bit 4 of flags.4?true
final
messageChats bool
message_chats: bit 2 of flags.2?true
final
messageMegagroups bool
message_megagroups: bit 3 of flags.3?true
final
messageUsers bool
message_users: bit 1 of flags.1?true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited