AccountResolvedBusinessChatLinks class
Account Resolved Business Chat Links.
ID: 9a23af21.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- AccountResolvedBusinessChatLinksBase
- AccountResolvedBusinessChatLinks
Constructors
-
AccountResolvedBusinessChatLinks({required PeerBase peer, required String message, List<
MessageEntityBase> ? entities, required List<ChatBase> chats, required List<UserBase> users}) -
Account Resolved Business Chat Links constructor.
const
- AccountResolvedBusinessChatLinks.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
-
chats
→ List<
ChatBase> -
Chats.
final
-
entities
→ List<
MessageEntityBase> ? -
Entities.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Message.
final
- peer → PeerBase
-
Peer.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
users
→ List<
UserBase> -
Users.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited