AccountSaveMusic class

Account Save Music.

Return Type: bool. ID: b26732a9.

Inheritance

Constructors

AccountSaveMusic({required bool unsave, required InputDocumentBase id, InputDocumentBase? afterId})
Account Save Music constructor.
const
AccountSaveMusic.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

afterId InputDocumentBase?
After Id.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
id InputDocumentBase
Id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unsave bool
unsave: bit 0 of flags.0?true
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited