AccountSetMainProfileTab class

Account Set Main Profile Tab.

Return Type: bool. ID: 5dee78b0.

Inheritance

Constructors

AccountSetMainProfileTab({required ProfileTabBase tab})
Account Set Main Profile Tab constructor.
const
AccountSetMainProfileTab.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tab ProfileTabBase
Tab.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited