AccountToggleConnectedBotPaused class
Account Toggle Connected Bot Paused.
Return Type: bool.
ID: 646e1097.
Constructors
- AccountToggleConnectedBotPaused({required InputPeerBase peer, required bool paused})
-
Account Toggle Connected Bot Paused constructor.
const
- AccountToggleConnectedBotPaused.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- paused → bool
-
Paused.
final
- peer → InputPeerBase
-
Peer.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited