AccountToggleWebBrowserSettingsException class

Account Toggle Web Browser Settings Exception.

Return Type: UpdatesBase. ID: 60ed4229.

Inheritance

Constructors

AccountToggleWebBrowserSettingsException({required bool delete, bool? openExternalBrowser, required String url})
Account Toggle Web Browser Settings Exception constructor.
const
AccountToggleWebBrowserSettingsException.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

delete bool
delete: bit 1 of flags.1?true
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
openExternalBrowser bool?
open_external_browser: bit 0 of flags.0?Bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
Url.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited