AccountUpdateBusinessIntro class
Account Update Business Intro.
Return Type: bool.
ID: a614d034.
Constructors
- AccountUpdateBusinessIntro({InputBusinessIntroBase? intro})
-
Account Update Business Intro constructor.
const
- AccountUpdateBusinessIntro.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- intro → InputBusinessIntroBase?
-
Intro.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited