AccountUpdateWebBrowserSettings class
Account Update Web Browser Settings.
Return Type: AccountWebBrowserSettingsBase.
ID: 9adf82fe.
Constructors
- AccountUpdateWebBrowserSettings({required bool openExternalBrowser, required bool displayCloseButton})
-
Account Update Web Browser Settings constructor.
const
- AccountUpdateWebBrowserSettings.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- displayCloseButton → bool
-
display_close_button: bit 1 of flags.1?true
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- openExternalBrowser → bool
-
open_external_browser: bit 0 of flags.0?true
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited