AccountUploadTheme class

Account Upload Theme.

Return Type: DocumentBase. ID: 1c3db333.

Inheritance

Constructors

AccountUploadTheme({required InputFileBase file, InputFileBase? thumb, required String fileName, required String mimeType})
Account Upload Theme constructor.
const
AccountUploadTheme.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

file InputFileBase
File.
final
fileName String
File Name.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
mimeType String
Mime Type.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumb InputFileBase?
Thumb.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited