AccountWallPapers class

Account Wall Papers.

ID: cdc3858c.

Inheritance

Constructors

AccountWallPapers({required int hash, required List<WallPaperBase> wallpapers})
Account Wall Papers constructor.
const
AccountWallPapers.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hash int
Hash.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wallpapers List<WallPaperBase>
Wallpapers.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited