AiComposeToneExample class

Ai Compose Tone Example.

ID: f1d628ec.

Inheritance

Constructors

AiComposeToneExample({required TextWithEntitiesBase from, required TextWithEntitiesBase to})
Ai Compose Tone Example constructor.
const
AiComposeToneExample.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

from TextWithEntitiesBase
From.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to TextWithEntitiesBase
To.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited