AicomposeGetToneExample class

Aicompose Get Tone Example.

Return Type: AiComposeToneExampleBase. ID: d1b4ab14.

Inheritance

Constructors

AicomposeGetToneExample({required InputAiComposeToneBase tone, required int num})
Aicompose Get Tone Example constructor.
const
AicomposeGetToneExample.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
num int
Num.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tone InputAiComposeToneBase
Tone.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited