AicomposeTones class

Aicompose Tones.

ID: 6c9d0efe.

Inheritance

Constructors

AicomposeTones({required int hash, required List<AiComposeToneBase> tones, required List<UserBase> users})
Aicompose Tones constructor.
const
AicomposeTones.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hash int
Hash.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tones List<AiComposeToneBase>
Tones.
final
users List<UserBase>
Users.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited