AicomposeUpdateTone class

Aicompose Update Tone.

Return Type: AiComposeToneBase. ID: 903bcf59.

Inheritance

Constructors

AicomposeUpdateTone({required InputAiComposeToneBase tone, bool? displayAuthor, int? emojiId, String? title, String? prompt})
Aicompose Update Tone constructor.
const
AicomposeUpdateTone.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

displayAuthor bool?
display_author: bit 0 of flags.0?Bool
final
emojiId int?
Emoji Id.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
prompt String?
Prompt.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
Title.
final
tone InputAiComposeToneBase
Tone.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited