AttachMenuBotsBot class
Attach Menu Bots Bot.
ID: 93bf667f.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- AttachMenuBotsBotBase
- AttachMenuBotsBot
Constructors
-
AttachMenuBotsBot({required AttachMenuBotBase bot, required List<
UserBase> users}) -
Attach Menu Bots Bot constructor.
const
- AttachMenuBotsBot.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- bot → AttachMenuBotBase
-
Bot.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
users
→ List<
UserBase> -
Users.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited