AuctionBidLevel class

Auction Bid Level.

ID: 310240cc.

Inheritance

Constructors

AuctionBidLevel({required int pos, required int amount, required DateTime date})
Auction Bid Level constructor.
const
AuctionBidLevel.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

amount int
Amount.
final
date DateTime
Date.
final
hashCode int
The hash code for this object.
no setterinherited
pos int
Pos.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited