AuthInitPasskeyLogin class

Auth Init Passkey Login.

Return Type: AuthPasskeyLoginOptionsBase. ID: 518ad0b7.

Inheritance

Constructors

AuthInitPasskeyLogin({required int apiId, required String apiHash})
Auth Init Passkey Login constructor.
const
AuthInitPasskeyLogin.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

apiHash String
Api Hash.
final
apiId int
Api Id.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited