AuthPasskeyLoginOptions class
Auth Passkey Login Options.
ID: e2037789.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- AuthPasskeyLoginOptionsBase
- AuthPasskeyLoginOptions
Constructors
- AuthPasskeyLoginOptions({required DataJSONBase options})
-
Auth Passkey Login Options constructor.
const
- AuthPasskeyLoginOptions.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- options → DataJSONBase
-
Options.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited