AuthPasswordRecovery class

Auth Password Recovery.

ID: 137948a5.

Inheritance

Constructors

AuthPasswordRecovery({required String emailPattern})
Auth Password Recovery constructor.
const
AuthPasswordRecovery.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

emailPattern String
Email Pattern.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited