AuthResetLoginEmail class

Auth Reset Login Email.

Return Type: AuthSentCodeBase. ID: 7e960193.

Inheritance

Constructors

AuthResetLoginEmail({required String phoneNumber, required String phoneCodeHash})
Auth Reset Login Email constructor.
const
AuthResetLoginEmail.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
phoneCodeHash String
Phone Code Hash.
final
phoneNumber String
Phone Number.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited