AuthSentCodeTypeSmsPhrase class

Auth Sent Code Type Sms Phrase.

ID: b37794af.

Inheritance

Constructors

AuthSentCodeTypeSmsPhrase({String? beginning})
Auth Sent Code Type Sms Phrase constructor.
const
AuthSentCodeTypeSmsPhrase.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

beginning String?
Beginning.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited