AvailableReaction class

Available Reaction.

ID: c077ec01.

Inheritance

Constructors

AvailableReaction({required bool inactive, required bool premium, required String reaction, required String title, required DocumentBase staticIcon, required DocumentBase appearAnimation, required DocumentBase selectAnimation, required DocumentBase activateAnimation, required DocumentBase effectAnimation, DocumentBase? aroundAnimation, DocumentBase? centerIcon})
Available Reaction constructor.
const
AvailableReaction.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

activateAnimation DocumentBase
Activate Animation.
final
appearAnimation DocumentBase
Appear Animation.
final
aroundAnimation DocumentBase?
Around Animation.
final
centerIcon DocumentBase?
Center Icon.
final
effectAnimation DocumentBase
Effect Animation.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
inactive bool
inactive: bit 0 of flags.0?true
final
premium bool
premium: bit 2 of flags.2?true
final
reaction String
Reaction.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectAnimation DocumentBase
Select Animation.
final
staticIcon DocumentBase
Static Icon.
final
title String
Title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited