Birthday class

Birthday.

ID: 6c8e1e06.

Inheritance

Constructors

Birthday({required int day, required int month, int? year})
Birthday constructor.
const
Birthday.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

day int
Day.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
month int
Month.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
year int?
Year.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited