BotInfo class

Bot Info.

ID: 4d8a0299.

Inheritance

Constructors

BotInfo({required bool hasPreviewMedias, int? userId, String? description, PhotoBase? descriptionPhoto, DocumentBase? descriptionDocument, List<BotCommandBase>? commands, BotMenuButtonBase? menuButton, String? privacyPolicyUrl, BotAppSettingsBase? appSettings, BotVerifierSettingsBase? verifierSettings})
Bot Info constructor.
const
BotInfo.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

appSettings BotAppSettingsBase?
App Settings.
final
commands List<BotCommandBase>?
Commands.
final
description String?
Description.
final
descriptionDocument DocumentBase?
Description Document.
final
descriptionPhoto PhotoBase?
Description Photo.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
hasPreviewMedias bool
has_preview_medias: bit 6 of flags.6?true
final
Menu Button.
final
privacyPolicyUrl String?
Privacy Policy Url.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int?
User Id.
final
verifierSettings BotVerifierSettingsBase?
Verifier Settings.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited