BotInlineMessageRichMessage class

Bot Inline Message Rich Message.

ID: 0a617e7b.

Inheritance

Constructors

BotInlineMessageRichMessage({ReplyMarkupBase? replyMarkup, required RichMessageBase richMessage})
Bot Inline Message Rich Message constructor.
const
BotInlineMessageRichMessage.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
replyMarkup ReplyMarkupBase?
Reply Markup.
final
richMessage RichMessageBase
Rich Message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited