BotVerifierSettings class

Bot Verifier Settings.

ID: b0cd6617.

Inheritance

Constructors

BotVerifierSettings({required bool canModifyCustomDescription, required int icon, required String company, String? customDescription})
Bot Verifier Settings constructor.
const
BotVerifierSettings.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

canModifyCustomDescription bool
can_modify_custom_description: bit 1 of flags.1?true
final
company String
Company.
final
customDescription String?
Custom Description.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
icon int
Icon.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited