BotsAccessSettings class

Bots Access Settings.

ID: dd1fbf93.

Inheritance

Constructors

BotsAccessSettings({required bool restricted, List<UserBase>? addUsers})
Bots Access Settings constructor.
const
BotsAccessSettings.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

addUsers List<UserBase>?
Add Users.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
restricted bool
restricted: bit 0 of flags.0?true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited