BotsEditPreviewMedia class

Bots Edit Preview Media.

Return Type: BotPreviewMediaBase. ID: 8525606f.

Inheritance

Constructors

BotsEditPreviewMedia({required InputUserBase bot, required String langCode, required InputMediaBase media, required InputMediaBase newMedia})
Bots Edit Preview Media constructor.
const
BotsEditPreviewMedia.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

bot InputUserBase
Bot.
final
hashCode int
The hash code for this object.
no setterinherited
langCode String
Lang Code.
final
media InputMediaBase
Media.
final
newMedia InputMediaBase
New Media.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited