BotsExportBotToken class

Bots Export Bot Token.

Return Type: BotsExportedBotTokenBase. ID: bd0d99eb.

Inheritance

Constructors

BotsExportBotToken({required InputUserBase bot, required bool revoke})
Bots Export Bot Token constructor.
const
BotsExportBotToken.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

bot InputUserBase
Bot.
final
hashCode int
The hash code for this object.
no setterinherited
revoke bool
Revoke.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited