BotsGetPopularAppBots class

Bots Get Popular App Bots.

Return Type: BotsPopularAppBotsBase. ID: c2510192.

Inheritance

Constructors

BotsGetPopularAppBots({required String offset, required int limit})
Bots Get Popular App Bots constructor.
const
BotsGetPopularAppBots.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
limit int
Limit.
final
offset String
Offset.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited