BotsPreviewInfo class

Bots Preview Info.

ID: 0ca71d64.

Inheritance

Constructors

BotsPreviewInfo({required List<BotPreviewMediaBase> media, required List<String> langCodes})
Bots Preview Info constructor.
const
BotsPreviewInfo.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
langCodes List<String>
Lang Codes.
final
media List<BotPreviewMediaBase>
Media.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited