BotsReorderPreviewMedias class

Bots Reorder Preview Medias.

Return Type: bool. ID: b627f3aa.

Inheritance

Constructors

BotsReorderPreviewMedias({required InputUserBase bot, required String langCode, required List<InputMediaBase> order})
Bots Reorder Preview Medias constructor.
const
BotsReorderPreviewMedias.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

bot InputUserBase
Bot.
final
hashCode int
The hash code for this object.
no setterinherited
langCode String
Lang Code.
final
order List<InputMediaBase>
Order.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited