BotsSetCustomVerification class
Bots Set Custom Verification.
Return Type: bool.
ID: 8b89dfbd.
Constructors
- BotsSetCustomVerification({required bool enabled, InputUserBase? bot, required InputPeerBase peer, String? customDescription})
-
Bots Set Custom Verification constructor.
const
- BotsSetCustomVerification.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- bot → InputUserBase?
-
Bot.
final
- customDescription → String?
-
Custom Description.
final
- enabled → bool
-
enabled: bit 1 of flags.1?true
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- peer → InputPeerBase
-
Peer.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited