BotsSetJoinChatResults class

Bots Set Join Chat Results.

Return Type: bool. ID: e71a4810.

Inheritance

Constructors

BotsSetJoinChatResults({required int queryId, required JoinChatBotResultBase result})
Bots Set Join Chat Results constructor.
const
BotsSetJoinChatResults.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
queryId int
Query Id.
final
result JoinChatBotResultBase
Result.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited