BotsUpdateUserEmojiStatus class
Bots Update User Emoji Status.
Return Type: bool.
ID: ed9f30c5.
Constructors
- BotsUpdateUserEmojiStatus({required InputUserBase userId, required EmojiStatusBase emojiStatus})
-
Bots Update User Emoji Status constructor.
const
- BotsUpdateUserEmojiStatus.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- emojiStatus → EmojiStatusBase
-
Emoji Status.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → InputUserBase
-
User Id.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited