BusinessGreetingMessage class
Business Greeting Message.
ID: e519abab.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- BusinessGreetingMessageBase
- BusinessGreetingMessage
Constructors
- BusinessGreetingMessage({required int shortcutId, required BusinessRecipientsBase recipients, required int noActivityDays})
-
Business Greeting Message constructor.
const
- BusinessGreetingMessage.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- noActivityDays → int
-
No Activity Days.
final
- recipients → BusinessRecipientsBase
-
Recipients.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortcutId → int
-
Shortcut Id.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited