BusinessIntro class

Business Intro.

ID: 5a0a066d.

Inheritance

Constructors

BusinessIntro({required String title, required String description, DocumentBase? sticker})
Business Intro constructor.
const
BusinessIntro.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

description String
Description.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sticker DocumentBase?
Sticker.
final
title String
Title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited