BusinessWeeklyOpen class
Business Weekly Open.
ID: 120b1ab9.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- BusinessWeeklyOpenBase
- BusinessWeeklyOpen
Constructors
- BusinessWeeklyOpen({required int startMinute, required int endMinute})
-
Business Weekly Open constructor.
const
- BusinessWeeklyOpen.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- endMinute → int
-
End Minute.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startMinute → int
-
Start Minute.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited