ChannelFull class
Channel Full.
ID: a04e8d3a.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- ChatFullBase
- ChannelFull
Constructors
-
ChannelFull({required bool canViewParticipants, required bool canSetUsername, required bool canSetStickers, required bool canSetLocation, required bool hasScheduled, required bool canViewStats, required bool blocked, required bool canDeleteChannel, required bool antispam, required bool participantsHidden, required bool translationsDisabled, required bool storiesPinnedAvailable, required bool viewForumAsMessages, required bool restrictedSponsored, required bool canViewRevenue, required bool paidMediaAllowed, required bool canViewStarsRevenue, required bool paidReactionsAvailable, required bool stargiftsAvailable, required bool paidMessagesAvailable, required int id, required String about, int? participantsCount, int? adminsCount, int? kickedCount, int? bannedCount, int? onlineCount, required int readInboxMaxId, required int readOutboxMaxId, required int unreadCount, required PhotoBase chatPhoto, required PeerNotifySettingsBase notifySettings, ExportedChatInviteBase? exportedInvite, required List<
BotInfoBase> botInfo, int? migratedFromChatId, int? migratedFromMaxId, int? pinnedMsgId, StickerSetBase? stickerset, int? availableMinId, int? folderId, int? linkedChatId, ChannelLocationBase? location, int? slowmodeSeconds, DateTime? slowmodeNextSendDate, int? statsDc, required int pts, InputGroupCallBase? call, int? ttlPeriod, List<String> ? pendingSuggestions, PeerBase? groupcallDefaultJoinAs, String? themeEmoticon, int? requestsPending, List<int> ? recentRequesters, PeerBase? defaultSendAs, ChatReactionsBase? availableReactions, int? reactionsLimit, PeerStoriesBase? stories, WallPaperBase? wallpaper, int? boostsApplied, int? boostsUnrestrict, StickerSetBase? emojiset, BotVerificationBase? botVerification, int? stargiftsCount, int? sendPaidMessagesStars, ProfileTabBase? mainTab, int? guardBotId}) -
Channel Full constructor.
const
- ChannelFull.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- about → String
-
About.
final
- adminsCount → int?
-
Admins Count.
final
- antispam → bool
-
antispam: bit 1 of flags2.1?true
final
- availableMinId → int?
-
Available Min Id.
final
- availableReactions → ChatReactionsBase?
-
Available Reactions.
final
- bannedCount → int?
-
Banned Count.
final
- blocked → bool
-
blocked: bit 22 of flags.22?true
final
- boostsApplied → int?
-
Boosts Applied.
final
- boostsUnrestrict → int?
-
Boosts Unrestrict.
final
-
botInfo
→ List<
BotInfoBase> -
Bot Info.
final
- botVerification → BotVerificationBase?
-
Bot Verification.
final
- call → InputGroupCallBase?
-
Call.
final
- canDeleteChannel → bool
-
can_delete_channel: bit 0 of flags2.0?true
final
- canSetLocation → bool
-
can_set_location: bit 16 of flags.16?true
final
- canSetStickers → bool
-
can_set_stickers: bit 7 of flags.7?true
final
- canSetUsername → bool
-
can_set_username: bit 6 of flags.6?true
final
- canViewParticipants → bool
-
can_view_participants: bit 3 of flags.3?true
final
- canViewRevenue → bool
-
can_view_revenue: bit 12 of flags2.12?true
final
- canViewStarsRevenue → bool
-
can_view_stars_revenue: bit 15 of flags2.15?true
final
- canViewStats → bool
-
can_view_stats: bit 20 of flags.20?true
final
- chatPhoto → PhotoBase
-
Chat Photo.
final
- defaultSendAs → PeerBase?
-
Default Send As.
final
- emojiset → StickerSetBase?
-
Emojiset.
final
- exportedInvite → ExportedChatInviteBase?
-
Exported Invite.
final
- flags → int
-
Flags.
no setter
- flags2 → int
-
Flags2.
no setter
- folderId → int?
-
Folder Id.
final
- groupcallDefaultJoinAs → PeerBase?
-
Groupcall Default Join As.
final
- guardBotId → int?
-
Guard Bot Id.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasScheduled → bool
-
has_scheduled: bit 19 of flags.19?true
final
-
hidden_prehistory: bit 10 of flags.10?true
final
- id → int
-
Id.
final
- kickedCount → int?
-
Kicked Count.
final
- linkedChatId → int?
-
Linked Chat Id.
final
- location → ChannelLocationBase?
-
Location.
final
- mainTab → ProfileTabBase?
-
Main Tab.
final
- migratedFromChatId → int?
-
Migrated From Chat Id.
final
- migratedFromMaxId → int?
-
Migrated From Max Id.
final
- notifySettings → PeerNotifySettingsBase
-
Notify Settings.
final
- onlineCount → int?
-
Online Count.
final
- paidMediaAllowed → bool
-
paid_media_allowed: bit 14 of flags2.14?true
final
- paidMessagesAvailable → bool
-
paid_messages_available: bit 20 of flags2.20?true
final
- paidReactionsAvailable → bool
-
paid_reactions_available: bit 16 of flags2.16?true
final
- participantsCount → int?
-
Participants Count.
final
- participantsHidden → bool
-
participants_hidden: bit 2 of flags2.2?true
final
-
pendingSuggestions
→ List<
String> ? -
Pending Suggestions.
final
- pinnedMsgId → int?
-
Pinned Msg Id.
final
- pts → int
-
Pts.
final
- reactionsLimit → int?
-
Reactions Limit.
final
- readInboxMaxId → int
-
Read Inbox Max Id.
final
- readOutboxMaxId → int
-
Read Outbox Max Id.
final
-
recentRequesters
→ List<
int> ? -
Recent Requesters.
final
- requestsPending → int?
-
Requests Pending.
final
- restrictedSponsored → bool
-
restricted_sponsored: bit 11 of flags2.11?true
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendPaidMessagesStars → int?
-
Send Paid Messages Stars.
final
- slowmodeNextSendDate → DateTime?
-
Slowmode Next Send Date.
final
- slowmodeSeconds → int?
-
Slowmode Seconds.
final
- stargiftsAvailable → bool
-
stargifts_available: bit 19 of flags2.19?true
final
- stargiftsCount → int?
-
Stargifts Count.
final
- statsDc → int?
-
Stats Dc.
final
- stickerset → StickerSetBase?
-
Stickerset.
final
- stories → PeerStoriesBase?
-
Stories.
final
- storiesPinnedAvailable → bool
-
stories_pinned_available: bit 5 of flags2.5?true
final
- themeEmoticon → String?
-
Theme Emoticon.
final
- translationsDisabled → bool
-
translations_disabled: bit 3 of flags2.3?true
final
- ttlPeriod → int?
-
Ttl Period.
final
- unreadCount → int
-
Unread Count.
final
- viewForumAsMessages → bool
-
view_forum_as_messages: bit 6 of flags2.6?true
final
- wallpaper → WallPaperBase?
-
Wallpaper.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited