ChannelParticipant class
Channel Participant.
ID: 1bd54456.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- ChannelParticipantBase
- ChannelParticipant
Constructors
- ChannelParticipant({required int userId, required DateTime date, DateTime? subscriptionUntilDate, String? rank})
-
Channel Participant constructor.
const
- ChannelParticipant.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- date → DateTime
-
Date.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- rank → String?
-
Rank.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriptionUntilDate → DateTime?
-
Subscription Until Date.
final
- userId → int
-
User Id.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited