ChannelsCheckSearchPostsFlood class

Channels Check Search Posts Flood.

Return Type: SearchPostsFloodBase. ID: 22567115.

Inheritance

Constructors

ChannelsCheckSearchPostsFlood({String? query})
Channels Check Search Posts Flood constructor.
const
ChannelsCheckSearchPostsFlood.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
query String?
Query.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited