ChannelsGetAdminLog class

Channels Get Admin Log.

Return Type: ChannelsAdminLogResultsBase. ID: 33ddf480.

Inheritance

Constructors

ChannelsGetAdminLog({required InputChannelBase channel, required String q, ChannelAdminLogEventsFilterBase? eventsFilter, List<InputUserBase>? admins, required int maxId, required int minId, required int limit})
Channels Get Admin Log constructor.
const
ChannelsGetAdminLog.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

admins List<InputUserBase>?
Admins.
final
channel InputChannelBase
Channel.
final
eventsFilter ChannelAdminLogEventsFilterBase?
Events Filter.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
limit int
Limit.
final
maxId int
Max Id.
final
minId int
Min Id.
final
q String
Q.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited