ChannelsGetSendAs class

Channels Get Send As.

Return Type: ChannelsSendAsPeersBase. ID: e785a43f.

Inheritance

Constructors

ChannelsGetSendAs({required bool forPaidReactions, required bool forLiveStories, required InputPeerBase peer})
Channels Get Send As constructor.
const
ChannelsGetSendAs.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
forLiveStories bool
for_live_stories: bit 1 of flags.1?true
final
forPaidReactions bool
for_paid_reactions: bit 0 of flags.0?true
final
hashCode int
The hash code for this object.
no setterinherited
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited