ChannelsRestrictSponsoredMessages class
Channels Restrict Sponsored Messages.
Return Type: UpdatesBase.
ID: 9ae91519.
Constructors
- ChannelsRestrictSponsoredMessages({required InputChannelBase channel, required bool restricted})
-
Channels Restrict Sponsored Messages constructor.
const
- ChannelsRestrictSponsoredMessages.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- channel → InputChannelBase
-
Channel.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- restricted → bool
-
Restricted.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited