ChannelsSetDiscussionGroup class
Channels Set Discussion Group.
Return Type: bool.
ID: 40582bb2.
Constructors
- ChannelsSetDiscussionGroup({required InputChannelBase broadcast, required InputChannelBase group})
-
Channels Set Discussion Group constructor.
const
- ChannelsSetDiscussionGroup.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- broadcast → InputChannelBase
-
Broadcast.
final
- group → InputChannelBase
-
Group.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited