ChannelsSetMainProfileTab class

Channels Set Main Profile Tab.

Return Type: bool. ID: 3583fcb1.

Inheritance

Constructors

ChannelsSetMainProfileTab({required InputChannelBase channel, required ProfileTabBase tab})
Channels Set Main Profile Tab constructor.
const
ChannelsSetMainProfileTab.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

channel InputChannelBase
Channel.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tab ProfileTabBase
Tab.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited