ChannelsToggleSignatures class

Channels Toggle Signatures.

Return Type: UpdatesBase. ID: 418d549c.

Inheritance

Constructors

ChannelsToggleSignatures({required bool signaturesEnabled, required bool profilesEnabled, required InputChannelBase channel})
Channels Toggle Signatures constructor.
const
ChannelsToggleSignatures.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

channel InputChannelBase
Channel.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
profilesEnabled bool
profiles_enabled: bit 1 of flags.1?true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signaturesEnabled bool
signatures_enabled: bit 0 of flags.0?true
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited