ChatInvite class
Chat Invite.
ID: 5c9d3702.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- ChatInviteBase
- ChatInvite
Constructors
-
ChatInvite({required bool channel, required bool broadcast, required bool public, required bool megagroup, required bool requestNeeded, required bool verified, required bool scam, required bool fake, required bool canRefulfillSubscription, required String title, String? about, required PhotoBase photo, required int participantsCount, List<
UserBase> ? participants, required int color, StarsSubscriptionPricingBase? subscriptionPricing, int? subscriptionFormId, BotVerificationBase? botVerification}) -
Chat Invite constructor.
const
- ChatInvite.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- about → String?
-
About.
final
- botVerification → BotVerificationBase?
-
Bot Verification.
final
- broadcast → bool
-
broadcast: bit 1 of flags.1?true
final
- canRefulfillSubscription → bool
-
can_refulfill_subscription: bit 11 of flags.11?true
final
- channel → bool
-
channel: bit 0 of flags.0?true
final
- color → int
-
Color.
final
- fake → bool
-
fake: bit 9 of flags.9?true
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- megagroup → bool
-
megagroup: bit 3 of flags.3?true
final
-
participants
→ List<
UserBase> ? -
Participants.
final
- participantsCount → int
-
Participants Count.
final
- photo → PhotoBase
-
Photo.
final
- public → bool
-
public: bit 2 of flags.2?true
final
- requestNeeded → bool
-
request_needed: bit 6 of flags.6?true
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scam → bool
-
scam: bit 8 of flags.8?true
final
- subscriptionFormId → int?
-
Subscription Form Id.
final
- subscriptionPricing → StarsSubscriptionPricingBase?
-
Subscription Pricing.
final
- title → String
-
Title.
final
- verified → bool
-
verified: bit 7 of flags.7?true
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited