ChatInviteExported class
Chat Invite Exported.
ID: a22cbd96.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- ExportedChatInviteBase
- ChatInviteExported
Constructors
- ChatInviteExported({required bool revoked, required bool permanent, required bool requestNeeded, required String link, required int adminId, required DateTime date, DateTime? startDate, DateTime? expireDate, int? usageLimit, int? usage, int? requested, int? subscriptionExpired, String? title, StarsSubscriptionPricingBase? subscriptionPricing})
-
Chat Invite Exported constructor.
const
- ChatInviteExported.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- adminId → int
-
Admin Id.
final
- date → DateTime
-
Date.
final
- expireDate → DateTime?
-
Expire Date.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- link → String
-
Link.
final
- permanent → bool
-
permanent: bit 5 of flags.5?true
final
- requested → int?
-
Requested.
final
- requestNeeded → bool
-
request_needed: bit 6 of flags.6?true
final
- revoked → bool
-
revoked: bit 0 of flags.0?true
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDate → DateTime?
-
Start Date.
final
- subscriptionExpired → int?
-
Subscription Expired.
final
- subscriptionPricing → StarsSubscriptionPricingBase?
-
Subscription Pricing.
final
- title → String?
-
Title.
final
- usage → int?
-
Usage.
final
- usageLimit → int?
-
Usage Limit.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited