ChatParticipantAdmin class
Chat Participant Admin.
ID: 0360d5d2.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- ChatParticipantBase
- ChatParticipantAdmin
Constructors
- ChatParticipantAdmin({required int userId, required int inviterId, required DateTime date, String? rank})
-
Chat Participant Admin constructor.
const
- ChatParticipantAdmin.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- date → DateTime
-
Date.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- inviterId → int
-
Inviter Id.
final
- rank → String?
-
Rank.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
User Id.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited