ChatlistsChatlistInvite class

Chatlists Chatlist Invite.

ID: f10ece2f.

Inheritance

Constructors

ChatlistsChatlistInvite({required bool titleNoanimate, required TextWithEntitiesBase title, String? emoticon, required List<PeerBase> peers, required List<ChatBase> chats, required List<UserBase> users})
Chatlists Chatlist Invite constructor.
const
ChatlistsChatlistInvite.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

chats List<ChatBase>
Chats.
final
emoticon String?
Emoticon.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
peers List<PeerBase>
Peers.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title TextWithEntitiesBase
Title.
final
titleNoanimate bool
title_noanimate: bit 1 of flags.1?true
final
users List<UserBase>
Users.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited