ClientCommunities class

Communities.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create({required bool hidden, required String title, String? about, required InputPeerBase peer}) Future<Result<UpdatesBase>>
Create.
getJoinedCommunities() Future<Result<MessagesChatsBase>>
Get Joined Communities.
getParticipantJoinedChats({required InputChannelBase community, required InputPeerBase participant}) Future<Result<CommunitiesParticipantJoinedChatsBase>>
Get Participant Joined Chats.
getPeerLinkRequests({required InputChannelBase community, required String offset, required int limit}) Future<Result<CommunitiesPeerLinkRequestsBase>>
Get Peer Link Requests.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toggleAllPeerLinkRequestApproval({required bool reject, required InputChannelBase community}) Future<Result<Boolean>>
Toggle All Peer Link Request Approval.
toggleCommunityCollapsedInDialogs({required bool collapsed, required InputChannelBase community}) Future<Result<UpdatesBase>>
Toggle Community Collapsed In Dialogs.
toggleParticipantBanned({required bool unban, required InputChannelBase community, required InputPeerBase participant}) Future<Result<Boolean>>
Toggle Participant Banned.
Toggle Peer Link.
togglePeerLinkRequestApproval({required bool reject, required InputChannelBase community, required InputPeerBase peer}) Future<Result<Boolean>>
Toggle Peer Link Request Approval.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited