ClientSmsjobs class
Smsjobs.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
finishJob(
{required String jobId, String? error}) → Future< Result< Boolean> > - Finish Job.
-
getSmsJob(
{required String jobId}) → Future< Result< SmsJobBase> > - Get Sms Job.
-
getStatus(
) → Future< Result< SmsjobsStatusBase> > - Get Status.
-
isEligibleToJoin(
) → Future< Result< SmsjobsEligibilityToJoinBase> > - Is Eligible To Join.
-
join(
) → Future< Result< Boolean> > - Join.
-
leave(
) → Future< Result< Boolean> > - Leave.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateSettings(
{required bool allowInternational}) → Future< Result< Boolean> > - Update Settings.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited