ClientUsers class

Users.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFullUser({required InputUserBase id}) Future<Result<UsersUserFullBase>>
Get Full User.
getRequirementsToContact({required List<InputUserBase> id}) Future<Result<Vector<RequirementToContactBase>>>
Get Requirements To Contact.
getSavedMusic({required InputUserBase id, required int offset, required int limit, required int hash}) Future<Result<UsersSavedMusicBase>>
Get Saved Music.
getSavedMusicByID({required InputUserBase id, required List<InputDocumentBase> documents}) Future<Result<UsersSavedMusicBase>>
Get Saved Music By I D.
getUsers({required List<InputUserBase> id}) Future<Result<Vector<UserBase>>>
Get Users.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setSecureValueErrors({required InputUserBase id, required List<SecureValueErrorBase> errors}) Future<Result<Boolean>>
Set Secure Value Errors.
suggestBirthday({required InputUserBase id, required BirthdayBase birthday}) Future<Result<UpdatesBase>>
Suggest Birthday.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited