CommunitiesGetParticipantJoinedChats class

Communities Get Participant Joined Chats.

Return Type: CommunitiesParticipantJoinedChatsBase. ID: f87eabab.

Inheritance

Constructors

CommunitiesGetParticipantJoinedChats({required InputChannelBase community, required InputPeerBase participant})
Communities Get Participant Joined Chats constructor.
const
CommunitiesGetParticipantJoinedChats.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

community InputChannelBase
Community.
final
hashCode int
The hash code for this object.
no setterinherited
participant InputPeerBase
Participant.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited