CommunitiesGetPeerLinkRequests class

Communities Get Peer Link Requests.

Return Type: CommunitiesPeerLinkRequestsBase. ID: 93773344.

Inheritance

Constructors

CommunitiesGetPeerLinkRequests({required InputChannelBase community, required String offset, required int limit})
Communities Get Peer Link Requests constructor.
const
CommunitiesGetPeerLinkRequests.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

community InputChannelBase
Community.
final
hashCode int
The hash code for this object.
no setterinherited
limit int
Limit.
final
offset String
Offset.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited