CommunitiesPeerLinkRequests class

Communities Peer Link Requests.

ID: 2244afad.

Inheritance

Constructors

CommunitiesPeerLinkRequests({required int totalCount, required List<CommunityPeerRequestBase> requests, String? nextOffset, required List<ChatBase> chats, required List<UserBase> users})
Communities Peer Link Requests constructor.
const
CommunitiesPeerLinkRequests.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

chats List<ChatBase>
Chats.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
nextOffset String?
Next Offset.
final
requests List<CommunityPeerRequestBase>
Requests.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
Total Count.
final
users List<UserBase>
Users.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited