CommunitiesToggleCommunityCollapsedInDialogs class

Communities Toggle Community Collapsed In Dialogs.

Return Type: UpdatesBase. ID: d766e3ea.

Inheritance

Constructors

CommunitiesToggleCommunityCollapsedInDialogs({required bool collapsed, required InputChannelBase community})
Communities Toggle Community Collapsed In Dialogs constructor.
const
CommunitiesToggleCommunityCollapsedInDialogs.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

collapsed bool
collapsed: bit 0 of flags.0?true
final
community InputChannelBase
Community.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited