CommunitiesToggleParticipantBanned class
Communities Toggle Participant Banned.
Return Type: bool.
ID: 9967ad0f.
Constructors
- CommunitiesToggleParticipantBanned({required bool unban, required InputChannelBase community, required InputPeerBase participant})
-
Communities Toggle Participant Banned constructor.
const
- CommunitiesToggleParticipantBanned.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- community → InputChannelBase
-
Community.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- participant → InputPeerBase
-
Participant.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unban → bool
-
unban: bit 0 of flags.0?true
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited