CommunitiesTogglePeerLink class

Communities Toggle Peer Link.

Return Type: bool. ID: 736dcfea.

Inheritance

Constructors

CommunitiesTogglePeerLink({required bool visible, required bool hidden, required bool deleted, required InputChannelBase community, required InputPeerBase peer})
Communities Toggle Peer Link constructor.
const
CommunitiesTogglePeerLink.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

community InputChannelBase
Community.
final
deleted bool
deleted: bit 2 of flags.2?true
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
hidden bool
hidden: bit 1 of flags.1?true
final
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible bool
visible: bit 0 of flags.0?true
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited