CommunitiesTogglePeerLinkRequestApproval class

Communities Toggle Peer Link Request Approval.

Return Type: bool. ID: 8c8219a8.

Inheritance

Constructors

CommunitiesTogglePeerLinkRequestApproval({required bool reject, required InputChannelBase community, required InputPeerBase peer})
Communities Toggle Peer Link Request Approval constructor.
const
CommunitiesTogglePeerLinkRequestApproval.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

community InputChannelBase
Community.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
peer InputPeerBase
Peer.
final
reject bool
reject: bit 0 of flags.0?true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited