CommunityFull class

Community Full.

ID: cbb7a507.

Inheritance

Constructors

CommunityFull({required int id, required String about, required PhotoBase chatPhoto, required List<CommunityPeerBase> linkedPeers, int? adminsCount, int? kickedCount, int? peerLinkRequestsPending})
Community Full constructor.
const
CommunityFull.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

about String
About.
final
adminsCount int?
Admins Count.
final
chatPhoto PhotoBase
Chat Photo.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
id int
Id.
final
kickedCount int?
Kicked Count.
final
linkedPeers List<CommunityPeerBase>
Linked Peers.
final
peerLinkRequestsPending int?
Peer Link Requests Pending.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited