CommunityPeer class
Community Peer.
ID: 76141ebd.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- CommunityPeerBase
- CommunityPeer
Constructors
- CommunityPeer({required bool canViewHistory, bool? visible, required PeerBase peer})
-
Community Peer constructor.
const
- CommunityPeer.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- canViewHistory → bool
-
can_view_history: bit 2 of flags.2?true
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- peer → PeerBase
-
Peer.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- visible → bool?
-
visible: bit 0 of flags.0?Bool
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited