CommunityPeerRequest class

Community Peer Request.

ID: 7beafa85.

Inheritance

Constructors

CommunityPeerRequest({required bool visible, required PeerBase peer, required int requestedBy, required DateTime date})
Community Peer Request constructor.
const
CommunityPeerRequest.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

date DateTime
Date.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
peer PeerBase
Peer.
final
requestedBy int
Requested By.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible bool
visible: bit 0 of flags.0?true
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited