ConnectedBotStarRef class

Connected Bot Star Ref.

ID: 19a13f71.

Inheritance

Constructors

ConnectedBotStarRef({required bool revoked, required String url, required DateTime date, required int botId, required int commissionPermille, int? durationMonths, required int participants, required int revenue})
Connected Bot Star Ref constructor.
const
ConnectedBotStarRef.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

botId int
Bot Id.
final
commissionPermille int
Commission Permille.
final
date DateTime
Date.
final
durationMonths int?
Duration Months.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
participants int
Participants.
final
revenue int
Revenue.
final
revoked bool
revoked: bit 1 of flags.1?true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
Url.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited