ContactBirthday class
Contact Birthday.
ID: 1d998733.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- ContactBirthdayBase
- ContactBirthday
Constructors
- ContactBirthday({required int contactId, required BirthdayBase birthday})
-
Contact Birthday constructor.
const
- ContactBirthday.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- birthday → BirthdayBase
-
Birthday.
final
- contactId → int
-
Contact Id.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited