ContactsFound class

Contacts Found.

ID: b3134d9d.

Inheritance

Constructors

ContactsFound({required List<PeerBase> myResults, required List<PeerBase> results, required List<ChatBase> chats, required List<UserBase> users})
Contacts Found constructor.
const
ContactsFound.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

chats List<ChatBase>
Chats.
final
hashCode int
The hash code for this object.
no setterinherited
myResults List<PeerBase>
My Results.
final
results List<PeerBase>
Results.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
users List<UserBase>
Users.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited