ContactsResolveUsername class

Contacts Resolve Username.

Return Type: ContactsResolvedPeerBase. ID: 725afbbc.

Inheritance

Constructors

ContactsResolveUsername({required String username, String? referer})
Contacts Resolve Username constructor.
const
ContactsResolveUsername.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
referer String?
Referer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
Username.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited