ContactsSearch class

Contacts Search.

Return Type: ContactsFoundBase. ID: 05f58d0f.

Inheritance

Constructors

ContactsSearch({required bool broadcasts, required bool bots, required String q, required int limit})
Contacts Search constructor.
const
ContactsSearch.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

bots bool
bots: bit 1 of flags.1?true
final
broadcasts bool
broadcasts: bit 0 of flags.0?true
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
limit int
Limit.
final
q String
Q.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited