DecryptedMessageMediaVideo045 class
Decrypted Message Media Video.
Layer: 45.
ID: 970c8c0e.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- DecryptedMessageMediaBase
- DecryptedMessageMediaVideo045
Constructors
- DecryptedMessageMediaVideo045({required Uint8List thumb, required int thumbW, required int thumbH, required int duration, required String mimeType, required int w, required int h, required int size, required Uint8List key, required Uint8List iv, required String caption})
-
Decrypted Message Media Video constructor.
const
- DecryptedMessageMediaVideo045.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- caption → String
-
Caption.
final
- duration → int
-
Duration.
final
- h → int
-
H.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iv → Uint8List
-
Iv.
final
- key → Uint8List
-
Key.
final
- mimeType → String
-
Mime Type.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
Size.
final
- thumb → Uint8List
-
Thumb.
final
- thumbH → int
-
Thumb H.
final
- thumbW → int
-
Thumb W.
final
- w → int
-
W.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited