DialogCommunity class
Dialog Community.
ID: f78a0973.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- DialogBase
- DialogCommunity
Constructors
- DialogCommunity({required bool pinned, required int communityId, required PeerNotifySettingsBase notifySettings})
-
Dialog Community constructor.
const
- DialogCommunity.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- communityId → int
-
Community Id.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- notifySettings → PeerNotifySettingsBase
-
Notify Settings.
final
- pinned → bool
-
pinned: bit 2 of flags.2?true
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited