DialogFilterChatlist class

Dialog Filter Chatlist.

ID: 96537bd7.

Inheritance

Constructors

DialogFilterChatlist({required bool hasMyInvites, required bool titleNoanimate, required int id, required TextWithEntitiesBase title, String? emoticon, int? color, required List<InputPeerBase> pinnedPeers, required List<InputPeerBase> includePeers})
Dialog Filter Chatlist constructor.
const
DialogFilterChatlist.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

color int?
Color.
final
emoticon String?
Emoticon.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
hasMyInvites bool
has_my_invites: bit 26 of flags.26?true
final
id int
Id.
final
includePeers List<InputPeerBase>
Include Peers.
final
pinnedPeers List<InputPeerBase>
Pinned Peers.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title TextWithEntitiesBase
Title.
final
titleNoanimate bool
title_noanimate: bit 28 of flags.28?true
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited