DisallowedGiftsSettings class

Disallowed Gifts Settings.

ID: 71f276c4.

Inheritance

Constructors

DisallowedGiftsSettings({required bool disallowUnlimitedStargifts, required bool disallowLimitedStargifts, required bool disallowUniqueStargifts, required bool disallowPremiumGifts, required bool disallowStargiftsFromChannels})
Disallowed Gifts Settings constructor.
const
DisallowedGiftsSettings.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

disallowLimitedStargifts bool
disallow_limited_stargifts: bit 1 of flags.1?true
final
disallowPremiumGifts bool
disallow_premium_gifts: bit 3 of flags.3?true
final
disallowStargiftsFromChannels bool
disallow_stargifts_from_channels: bit 4 of flags.4?true
final
disallowUniqueStargifts bool
disallow_unique_stargifts: bit 2 of flags.2?true
final
disallowUnlimitedStargifts bool
disallow_unlimited_stargifts: bit 0 of flags.0?true
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited