DocumentAttributeSticker045 class

Document Attribute Sticker.

Layer: 45. ID: 3a556302.

Inheritance

Constructors

DocumentAttributeSticker045({required String alt, required InputStickerSetBase stickerset})
Document Attribute Sticker constructor.
const
DocumentAttributeSticker045.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

alt String
Alt.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stickerset InputStickerSetBase
Stickerset.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited