DraftMessage class

Draft Message.

ID: 60fe3294.

Inheritance

Constructors

DraftMessage({required bool noWebpage, required bool invertMedia, InputReplyToBase? replyTo, required String message, List<MessageEntityBase>? entities, InputMediaBase? media, required DateTime date, int? effect, SuggestedPostBase? suggestedPost, RichMessageBase? richMessage})
Draft Message constructor.
const
DraftMessage.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

date DateTime
Date.
final
effect int?
Effect.
final
entities List<MessageEntityBase>?
Entities.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
invertMedia bool
invert_media: bit 6 of flags.6?true
final
media InputMediaBase?
Media.
final
message String
Message.
final
noWebpage bool
no_webpage: bit 1 of flags.1?true
final
replyTo InputReplyToBase?
Reply To.
final
richMessage RichMessageBase?
Rich Message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suggestedPost SuggestedPostBase?
Suggested Post.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited