EmojiGroupGreeting class

Emoji Group Greeting.

ID: 80d26cc7.

Inheritance

Constructors

EmojiGroupGreeting({required String title, required int iconEmojiId, required List<String> emoticons})
Emoji Group Greeting constructor.
const
EmojiGroupGreeting.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

emoticons List<String>
Emoticons.
final
hashCode int
The hash code for this object.
no setterinherited
iconEmojiId int
Icon Emoji Id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
Title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited