EmojiGroupPremium class
Emoji Group Premium.
ID: 093bcf34.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- EmojiGroupBase
- EmojiGroupPremium
Constructors
- EmojiGroupPremium({required String title, required int iconEmojiId})
-
Emoji Group Premium constructor.
const
- EmojiGroupPremium.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconEmojiId → int
-
Icon Emoji Id.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
Title.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited