EphemeralDeleteMessage class

Ephemeral Delete Message.

Return Type: bool. ID: a3c0d511.

Inheritance

Constructors

EphemeralDeleteMessage({required InputPeerBase peer, required InputUserBase receiverId, required int id})
Ephemeral Delete Message constructor.
const
EphemeralDeleteMessage.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
Id.
final
peer InputPeerBase
Peer.
final
receiverId InputUserBase
Receiver Id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited