EphemeralMessage class

Ephemeral Message.

ID: d9c6dc1a.

Inheritance

Constructors

EphemeralMessage({required bool out, required int id, required PeerBase fromId, required PeerBase peerId, required int receiverId, int? topMsgId, required DateTime date, required String message, List<MessageEntityBase>? entities, MessageMediaBase? media, ReplyMarkupBase? replyMarkup, MessageReplyHeaderBase? replyTo})
Ephemeral Message constructor.
const
EphemeralMessage.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

date DateTime
Date.
final
entities List<MessageEntityBase>?
Entities.
final
flags int
Flags.
no setter
fromId PeerBase
From Id.
final
hashCode int
The hash code for this object.
no setterinherited
id int
Id.
final
media MessageMediaBase?
Media.
final
message String
Message.
final
out bool
out: bit 0 of flags.0?true
final
peerId PeerBase
Peer Id.
final
receiverId int
Receiver Id.
final
replyMarkup ReplyMarkupBase?
Reply Markup.
final
replyTo MessageReplyHeaderBase?
Reply To.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topMsgId int?
Top Msg Id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited