EphemeralReportMessage class

Ephemeral Report Message.

Return Type: ReportResultBase. ID: 8704f2bf.

Inheritance

Constructors

EphemeralReportMessage({required InputPeerBase peer, required int id, required Uint8List option, required String message})
Ephemeral Report Message constructor.
const
EphemeralReportMessage.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
Id.
final
message String
Message.
final
option Uint8List
Option.
final
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited