EphemeralSendMessage class

Ephemeral Send Message.

Return Type: UpdatesBase. ID: 68cbd09f.

Inheritance

Constructors

EphemeralSendMessage({required InputPeerBase peer, required InputUserBase receiverId, int? queryId, required String message, List<MessageEntityBase>? entities, InputMediaBase? media, ReplyMarkupBase? replyMarkup, InputRichMessageBase? richMessage, required int randomId, InputReplyToBase? replyTo})
Ephemeral Send Message constructor.
const
EphemeralSendMessage.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

entities List<MessageEntityBase>?
Entities.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
media InputMediaBase?
Media.
final
message String
Message.
final
peer InputPeerBase
Peer.
final
queryId int?
Query Id.
final
randomId int
Random Id.
final
receiverId InputUserBase
Receiver Id.
final
replyMarkup ReplyMarkupBase?
Reply Markup.
final
replyTo InputReplyToBase?
Reply To.
final
richMessage InputRichMessageBase?
Rich Message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited