FactCheck class

Fact Check.

ID: b89bfccf.

Inheritance

Constructors

FactCheck({required bool needCheck, String? country, TextWithEntitiesBase? text, required int hash})
Fact Check constructor.
const
FactCheck.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

country String?
Country.
final
flags int
Flags.
no setter
hash int
Hash.
final
hashCode int
The hash code for this object.
no setterinherited
needCheck bool
need_check: bit 0 of flags.0?true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text TextWithEntitiesBase?
Text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited