FileLocation023 class

File Location.

Layer: 23. ID: 53d69076.

Inheritance

Constructors

FileLocation023({required int dcId, required int volumeId, required int localId, required int secret})
File Location constructor.
const
FileLocation023.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

dcId int
Dc Id.
final
hashCode int
The hash code for this object.
no setterinherited
localId int
Local Id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secret int
Secret.
final
volumeId int
Volume Id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited