Game class

Game.

ID: bdf9653b.

Inheritance

Constructors

Game({required int id, required int accessHash, required String shortName, required String title, required String description, required PhotoBase photo, DocumentBase? document})
Game constructor.
const
Game.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

accessHash int
Access Hash.
final
description String
Description.
final
document DocumentBase?
Document.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
id int
Id.
final
photo PhotoBase
Photo.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortName String
Short Name.
final
title String
Title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited