GeoPointAddress class

Geo Point Address.

ID: de4c5d93.

Inheritance

Constructors

GeoPointAddress({required String countryIso2, String? state, String? city, String? street})
Geo Point Address constructor.
const
GeoPointAddress.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

city String?
City.
final
countryIso2 String
Country Iso2.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
State.
final
street String?
Street.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited