GroupCallParticipantVideo class

Group Call Participant Video.

ID: 67753ac8.

Inheritance

Constructors

GroupCallParticipantVideo({required bool paused, required String endpoint, required List<GroupCallParticipantVideoSourceGroupBase> sourceGroups, int? audioSource})
Group Call Participant Video constructor.
const
GroupCallParticipantVideo.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

audioSource int?
Audio Source.
final
endpoint String
Endpoint.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
paused bool
paused: bit 0 of flags.0?true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceGroups List<GroupCallParticipantVideoSourceGroupBase>
Source Groups.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited