HelpSupport class

Help Support.

ID: 17c6b5f6.

Inheritance

Constructors

HelpSupport({required String phoneNumber, required UserBase user})
Help Support constructor.
const
HelpSupport.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
phoneNumber String
Phone Number.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user UserBase
User.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited