HelpTimezonesList class
Help Timezones List.
ID: 7b74ed71.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- HelpTimezonesListBase
- HelpTimezonesList
Constructors
-
HelpTimezonesList({required List<
TimezoneBase> timezones, required int hash}) -
Help Timezones List constructor.
const
- HelpTimezonesList.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- hash → int
-
Hash.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
timezones
→ List<
TimezoneBase> -
Timezones.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited