InputBotInlineResultGame class
Input Bot Inline Result Game.
ID: 4fa417f2.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- InputBotInlineResultBase
- InputBotInlineResultGame
Constructors
- InputBotInlineResultGame({required String id, required String shortName, required InputBotInlineMessageBase sendMessage})
-
Input Bot Inline Result Game constructor.
const
- InputBotInlineResultGame.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Id.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendMessage → InputBotInlineMessageBase
-
Send Message.
final
- shortName → String
-
Short Name.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited