InputBusinessAwayMessage class
Input Business Away Message.
ID: 832175e0.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- InputBusinessAwayMessageBase
- InputBusinessAwayMessage
Constructors
- InputBusinessAwayMessage({required bool offlineOnly, required int shortcutId, required BusinessAwayMessageScheduleBase schedule, required InputBusinessRecipientsBase recipients})
-
Input Business Away Message constructor.
const
- InputBusinessAwayMessage.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- offlineOnly → bool
-
offline_only: bit 0 of flags.0?true
final
- recipients → InputBusinessRecipientsBase
-
Recipients.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schedule → BusinessAwayMessageScheduleBase
-
Schedule.
final
- shortcutId → int
-
Shortcut Id.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited