InputChatUploadedPhoto class

Input Chat Uploaded Photo.

ID: bdcdaec0.

Inheritance

Constructors

InputChatUploadedPhoto({InputFileBase? file, InputFileBase? video, double? videoStartTs, VideoSizeBase? videoEmojiMarkup})
Input Chat Uploaded Photo constructor.
const
InputChatUploadedPhoto.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

file InputFileBase?
File.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
video InputFileBase?
Video.
final
videoEmojiMarkup VideoSizeBase?
Video Emoji Markup.
final
videoStartTs double?
Video Start Ts.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited