InputCollectibleUsername class

Input Collectible Username.

ID: e39460a9.

Inheritance

Constructors

InputCollectibleUsername({required String username})
Input Collectible Username constructor.
const
InputCollectibleUsername.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
Username.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited