InputFileBig class

Input File Big.

ID: fa4f0bb5.

Inheritance

Constructors

InputFileBig({required int id, required int parts, required String name})
Input File Big constructor.
const
InputFileBig.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
Id.
final
name String
Name.
final
parts int
Parts.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited