InputInvoiceBusinessBotTransferStars class

Input Invoice Business Bot Transfer Stars.

ID: f4997e42.

Inheritance

Constructors

InputInvoiceBusinessBotTransferStars({required InputUserBase bot, required int stars})
Input Invoice Business Bot Transfer Stars constructor.
const
InputInvoiceBusinessBotTransferStars.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

bot InputUserBase
Bot.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stars int
Stars.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited