InputInvoicePremiumGiftStars class

Input Invoice Premium Gift Stars.

ID: dabab2ef.

Inheritance

Constructors

InputInvoicePremiumGiftStars({required InputUserBase userId, required int months, TextWithEntitiesBase? message})
Input Invoice Premium Gift Stars constructor.
const
InputInvoicePremiumGiftStars.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
message TextWithEntitiesBase?
Message.
final
months int
Months.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId InputUserBase
User Id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited