InputInvoiceStarGift class

Input Invoice Star Gift.

ID: e8625e92.

Inheritance

Constructors

InputInvoiceStarGift({required bool hideName, required bool includeUpgrade, required InputPeerBase peer, required int giftId, TextWithEntitiesBase? message})
Input Invoice Star Gift constructor.
const
InputInvoiceStarGift.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
giftId int
Gift Id.
final
hashCode int
The hash code for this object.
no setterinherited
hideName bool
hide_name: bit 0 of flags.0?true
final
includeUpgrade bool
include_upgrade: bit 2 of flags.2?true
final
message TextWithEntitiesBase?
Message.
final
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited