InputInvoiceStarGiftAuctionBid class

Input Invoice Star Gift Auction Bid.

ID: 1ecafa10.

Inheritance

Constructors

InputInvoiceStarGiftAuctionBid({required bool hideName, required bool updateBid, InputPeerBase? peer, required int giftId, required int bidAmount, TextWithEntitiesBase? message})
Input Invoice Star Gift Auction Bid constructor.
const
InputInvoiceStarGiftAuctionBid.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

bidAmount int
Bid Amount.
final
flags int
Flags.
no setter
giftId int
Gift Id.
final
hashCode int
The hash code for this object.
no setterinherited
hideName bool
hide_name: bit 0 of flags.0?true
final
message TextWithEntitiesBase?
Message.
final
peer InputPeerBase?
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateBid bool
update_bid: bit 2 of flags.2?true
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited