InputInvoiceStarGiftDropOriginalDetails class
Input Invoice Star Gift Drop Original Details.
ID: 0923d8d1.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- InputInvoiceBase
- InputInvoiceStarGiftDropOriginalDetails
Constructors
- InputInvoiceStarGiftDropOriginalDetails({required InputSavedStarGiftBase stargift})
-
Input Invoice Star Gift Drop Original Details constructor.
const
- InputInvoiceStarGiftDropOriginalDetails.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stargift → InputSavedStarGiftBase
-
Stargift.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited