InputInvoiceStarGiftTransfer class

Input Invoice Star Gift Transfer.

ID: 4a5f5bd9.

Inheritance

Constructors

InputInvoiceStarGiftTransfer({required InputSavedStarGiftBase stargift, required InputPeerBase toId})
Input Invoice Star Gift Transfer constructor.
const
InputInvoiceStarGiftTransfer.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stargift InputSavedStarGiftBase
Stargift.
final
toId InputPeerBase
To Id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited