InputInvoiceStarGiftUpgrade class

Input Invoice Star Gift Upgrade.

ID: 4d818d5d.

Inheritance

Constructors

InputInvoiceStarGiftUpgrade({required bool keepOriginalDetails, required InputSavedStarGiftBase stargift})
Input Invoice Star Gift Upgrade constructor.
const
InputInvoiceStarGiftUpgrade.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
keepOriginalDetails bool
keep_original_details: bit 0 of flags.0?true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stargift InputSavedStarGiftBase
Stargift.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited