InputKeyboardButtonRequestPeer class

Input Keyboard Button Request Peer.

ID: 02b78156.

Inheritance

Constructors

InputKeyboardButtonRequestPeer({required bool nameRequested, required bool usernameRequested, required bool photoRequested, KeyboardButtonStyleBase? style, required String text, required int buttonId, required RequestPeerTypeBase peerType, required int maxQuantity})
Input Keyboard Button Request Peer constructor.
const
InputKeyboardButtonRequestPeer.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

buttonId int
Button Id.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
maxQuantity int
Max Quantity.
final
nameRequested bool
name_requested: bit 0 of flags.0?true
final
peerType RequestPeerTypeBase
Peer Type.
final
photoRequested bool
photo_requested: bit 2 of flags.2?true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style KeyboardButtonStyleBase?
Style.
final
text String
Text.
final
usernameRequested bool
username_requested: bit 1 of flags.1?true
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited