InputMediaDocumentExternal class
Input Media Document External.
ID: 779600f9.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- InputMediaBase
- InputMediaDocumentExternal
Constructors
- InputMediaDocumentExternal({required bool spoiler, required String url, int? ttlSeconds, InputPhotoBase? videoCover, int? videoTimestamp})
-
Input Media Document External constructor.
const
- InputMediaDocumentExternal.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spoiler → bool
-
spoiler: bit 1 of flags.1?true
final
- ttlSeconds → int?
-
Ttl Seconds.
final
- url → String
-
Url.
final
- videoCover → InputPhotoBase?
-
Video Cover.
final
- videoTimestamp → int?
-
Video Timestamp.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited