InputMediaPaidMedia class

Input Media Paid Media.

ID: c4103386.

Inheritance

Constructors

InputMediaPaidMedia({required int starsAmount, required List<InputMediaBase> extendedMedia, String? payload})
Input Media Paid Media constructor.
const
InputMediaPaidMedia.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

extendedMedia List<InputMediaBase>
Extended Media.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
payload String?
Payload.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starsAmount int
Stars Amount.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited