InputMessageReadMetric class

Input Message Read Metric.

ID: 402b4495.

Inheritance

Constructors

InputMessageReadMetric({required int msgId, required int viewId, required int timeInViewMs, required int activeTimeInViewMs, required int heightToViewportRatioPermille, required int seenRangeRatioPermille})
Input Message Read Metric constructor.
const
InputMessageReadMetric.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

activeTimeInViewMs int
Active Time In View Ms.
final
hashCode int
The hash code for this object.
no setterinherited
heightToViewportRatioPermille int
Height To Viewport Ratio Permille.
final
msgId int
Msg Id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seenRangeRatioPermille int
Seen Range Ratio Permille.
final
timeInViewMs int
Time In View Ms.
final
viewId int
View Id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited