InputPageBlockMap class
Input Page Block Map.
ID: 574b617f.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- PageBlockBase
- InputPageBlockMap
Constructors
- InputPageBlockMap({required InputGeoPointBase geo, required int zoom, required int w, required int h, required PageCaptionBase caption})
-
Input Page Block Map constructor.
const
- InputPageBlockMap.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- caption → PageCaptionBase
-
Caption.
final
- geo → InputGeoPointBase
-
Geo.
final
- h → int
-
H.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- w → int
-
W.
final
- zoom → int
-
Zoom.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited