InputPasskeyCredentialPublicKey class
Input Passkey Credential Public Key.
ID: 3c27b78f.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- InputPasskeyCredentialBase
- InputPasskeyCredentialPublicKey
Constructors
- InputPasskeyCredentialPublicKey({required String id, required String rawId, required InputPasskeyResponseBase response})
-
Input Passkey Credential Public Key constructor.
const
- InputPasskeyCredentialPublicKey.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Id.
final
- rawId → String
-
Raw Id.
final
- response → InputPasskeyResponseBase
-
Response.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited