InputPasskeyResponseLogin class

Input Passkey Response Login.

ID: c31fc14a.

Inheritance

Constructors

InputPasskeyResponseLogin({required DataJSONBase clientData, required Uint8List authenticatorData, required Uint8List signature, required String userHandle})
Input Passkey Response Login constructor.
const
InputPasskeyResponseLogin.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

authenticatorData Uint8List
Authenticator Data.
final
clientData DataJSONBase
Client Data.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature Uint8List
Signature.
final
userHandle String
User Handle.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited