InputPasskeyResponseRegister class

Input Passkey Response Register.

ID: 3e63935c.

Inheritance

Constructors

InputPasskeyResponseRegister({required DataJSONBase clientData, required Uint8List attestationData})
Input Passkey Response Register constructor.
const
InputPasskeyResponseRegister.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

attestationData Uint8List
Attestation Data.
final
clientData DataJSONBase
Client Data.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited