InputPollAnswer class

Input Poll Answer.

ID: 199fed96.

Inheritance

Constructors

InputPollAnswer({required TextWithEntitiesBase text, InputMediaBase? media})
Input Poll Answer constructor.
const
InputPollAnswer.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
media InputMediaBase?
Media.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text TextWithEntitiesBase
Text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited