InputPrivacyKeyPhoneP2P class
Input Privacy Key Phone P2 P.
ID: db9e70d2.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- InputPrivacyKeyBase
- InputPrivacyKeyPhoneP2P
Constructors
- InputPrivacyKeyPhoneP2P()
-
Input Privacy Key Phone P2 P constructor.
const
- InputPrivacyKeyPhoneP2P.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited