InputReplyToMessage class

Input Reply To Message.

ID: 3bd4b7c2.

Inheritance

Constructors

InputReplyToMessage({required int replyToMsgId, int? topMsgId, InputPeerBase? replyToPeerId, String? quoteText, List<MessageEntityBase>? quoteEntities, int? quoteOffset, InputPeerBase? monoforumPeerId, int? todoItemId, Uint8List? pollOption})
Input Reply To Message constructor.
const
InputReplyToMessage.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
monoforumPeerId InputPeerBase?
Monoforum Peer Id.
final
pollOption Uint8List?
Poll Option.
final
quoteEntities List<MessageEntityBase>?
Quote Entities.
final
quoteOffset int?
Quote Offset.
final
quoteText String?
Quote Text.
final
replyToMsgId int
Reply To Msg Id.
final
replyToPeerId InputPeerBase?
Reply To Peer Id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
todoItemId int?
Todo Item Id.
final
topMsgId int?
Top Msg Id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited