InputRichFilePhoto class

Input Rich File Photo.

ID: 9b00622b.

Inheritance

Constructors

InputRichFilePhoto({required String id, required InputPhotoBase photo})
Input Rich File Photo constructor.
const
InputRichFilePhoto.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Id.
final
photo InputPhotoBase
Photo.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited