InputRichMessage class

Input Rich Message.

ID: e4c449fc.

Inheritance

Constructors

InputRichMessage({required bool rtl, required bool noautolink, required List<PageBlockBase> blocks, List<InputPhotoBase>? photos, List<InputDocumentBase>? documents, List<InputUserBase>? users})
Input Rich Message constructor.
const
InputRichMessage.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

blocks List<PageBlockBase>
Blocks.
final
documents List<InputDocumentBase>?
Documents.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
noautolink: bit 1 of flags.1?true
final
photos List<InputPhotoBase>?
Photos.
final
rtl bool
rtl: bit 0 of flags.0?true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
users List<InputUserBase>?
Users.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited