InputRichMessageHTML class
Input Rich Message H T M L.
ID: dacb836a.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- InputRichMessageBase
- InputRichMessageHTML
Constructors
-
InputRichMessageHTML({required bool rtl, required bool noautolink, required String html, List<
InputRichFileBase> ? files}) -
Input Rich Message H T M L constructor.
const
- InputRichMessageHTML.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
-
files
→ List<
InputRichFileBase> ? -
Files.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- html → String
-
Html.
final
- noautolink → bool
-
noautolink: bit 1 of flags.1?true
final
- rtl → bool
-
rtl: bit 0 of flags.0?true
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited