InputSendMessageRichMessageDraftAction class

Input Send Message Rich Message Draft Action.

ID: e2b23b51.

Inheritance

Constructors

InputSendMessageRichMessageDraftAction({required int randomId, required InputRichMessageBase richMessage})
Input Send Message Rich Message Draft Action constructor.
const
InputSendMessageRichMessageDraftAction.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
randomId int
Random Id.
final
richMessage InputRichMessageBase
Rich Message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited