InputStarsTransaction class

Input Stars Transaction.

ID: 206ae6d1.

Inheritance

Constructors

InputStarsTransaction({required bool refund, required String id})
Input Stars Transaction constructor.
const
InputStarsTransaction.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
Id.
final
refund bool
refund: bit 0 of flags.0?true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited