InputStorePaymentStarsGift class
Input Store Payment Stars Gift.
ID: 1d741ef7.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- InputStorePaymentPurposeBase
- InputStorePaymentStarsGift
Constructors
- InputStorePaymentStarsGift({required InputUserBase userId, required int stars, required String currency, required int amount})
-
Input Store Payment Stars Gift constructor.
const
- InputStorePaymentStarsGift.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited