InputStorePaymentStarsTopup class

Input Store Payment Stars Topup.

ID: f9a2a6cb.

Inheritance

Constructors

InputStorePaymentStarsTopup({required int stars, required String currency, required int amount, InputPeerBase? spendPurposePeer})
Input Store Payment Stars Topup constructor.
const
InputStorePaymentStarsTopup.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

amount int
Amount.
final
currency String
Currency.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spendPurposePeer InputPeerBase?
Spend Purpose Peer.
final
stars int
Stars.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited