InvokeWithGooglePlayIntegrity class

Invoke With Google Play Integrity.

Return Type: X. ID: 1df92984.

Inheritance

Constructors

InvokeWithGooglePlayIntegrity({required String nonce, required String token, required TlMethod query})
Invoke With Google Play Integrity constructor.
const
InvokeWithGooglePlayIntegrity.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
nonce String
Nonce.
final
query TlMethod
Query.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
Token.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited