KeyboardButtonCopy class

Keyboard Button Copy.

ID: bcc4af10.

Inheritance

Constructors

KeyboardButtonCopy({KeyboardButtonStyleBase? style, required String text, required String copyText})
Keyboard Button Copy constructor.
const
KeyboardButtonCopy.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

copyText String
Copy Text.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style KeyboardButtonStyleBase?
Style.
final
text String
Text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited