KeyboardButtonRequestPoll class

Keyboard Button Request Poll.

ID: 7a11d782.

Inheritance

Constructors

KeyboardButtonRequestPoll({KeyboardButtonStyleBase? style, bool? quiz, required String text})
Keyboard Button Request Poll constructor.
const
KeyboardButtonRequestPoll.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
quiz bool?
quiz: bit 0 of flags.0?Bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style KeyboardButtonStyleBase?
Style.
final
text String
Text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited