KeyboardButtonUrlAuth class
Keyboard Button Url Auth.
ID: f51006f9.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- KeyboardButtonBase
- KeyboardButtonUrlAuth
Constructors
- KeyboardButtonUrlAuth({KeyboardButtonStyleBase? style, required String text, String? fwdText, required String url, required int buttonId})
-
Keyboard Button Url Auth constructor.
const
- KeyboardButtonUrlAuth.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
-
Button Id.
final
- flags → int
-
Flags.
no setter
- fwdText → String?
-
Fwd Text.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → KeyboardButtonStyleBase?
-
Style.
final
- text → String
-
Text.
final
- url → String
-
Url.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited