MediaAreaWeather class

Media Area Weather.

ID: 49a6549c.

Inheritance

Constructors

MediaAreaWeather({required MediaAreaCoordinatesBase coordinates, required String emoji, required double temperatureC, required int color})
Media Area Weather constructor.
const
MediaAreaWeather.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

color int
Color.
final
coordinates MediaAreaCoordinatesBase
Coordinates.
final
emoji String
Emoji.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temperatureC double
Temperature C.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited