MessageActionChangeCommunity class

Message Action Change Community.

ID: 5d20bae8.

Inheritance

Constructors

MessageActionChangeCommunity({int? communityId})
Message Action Change Community constructor.
const
MessageActionChangeCommunity.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

communityId int?
Community Id.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited