MessageActionChangeCreator class

Message Action Change Creator.

ID: e188503b.

Inheritance

Constructors

MessageActionChangeCreator({required int newCreatorId})
Message Action Change Creator constructor.
const
MessageActionChangeCreator.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
newCreatorId int
New Creator Id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited