MessageActionGiftStars class
Message Action Gift Stars.
ID: 45d5b021.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- MessageActionBase
- MessageActionGiftStars
Constructors
- MessageActionGiftStars({required String currency, required int amount, required int stars, String? cryptoCurrency, int? cryptoAmount, String? transactionId})
-
Message Action Gift Stars constructor.
const
- MessageActionGiftStars.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- amount → int
-
Amount.
final
- cryptoAmount → int?
-
Crypto Amount.
final
- cryptoCurrency → String?
-
Crypto Currency.
final
- currency → String
-
Currency.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stars → int
-
Stars.
final
- transactionId → String?
-
Transaction Id.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited