MessageActionNoForwardsRequest class

Message Action No Forwards Request.

ID: 3e2793ba.

Inheritance

Constructors

MessageActionNoForwardsRequest({required bool expired, required bool prevValue, required bool newValue})
Message Action No Forwards Request constructor.
const
MessageActionNoForwardsRequest.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

expired bool
expired: bit 0 of flags.0?true
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
newValue bool
New Value.
final
prevValue bool
Prev Value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited