MessageActionPaymentRefunded class
Message Action Payment Refunded.
ID: 41b3e202.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- MessageActionBase
- MessageActionPaymentRefunded
Constructors
- MessageActionPaymentRefunded({required PeerBase peer, required String currency, required int totalAmount, Uint8List? payload, required PaymentChargeBase charge})
-
Message Action Payment Refunded constructor.
const
- MessageActionPaymentRefunded.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- charge → PaymentChargeBase
-
Charge.
final
- currency → String
-
Currency.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- payload → Uint8List?
-
Payload.
final
- peer → PeerBase
-
Peer.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalAmount → int
-
Total Amount.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited