MessageActionPrizeStars class

Message Action Prize Stars.

ID: b00c47a2.

Inheritance

Constructors

MessageActionPrizeStars({required bool unclaimed, required int stars, required String transactionId, required PeerBase boostPeer, required int giveawayMsgId})
Message Action Prize Stars constructor.
const
MessageActionPrizeStars.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

boostPeer PeerBase
Boost Peer.
final
flags int
Flags.
no setter
giveawayMsgId int
Giveaway Msg Id.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stars int
Stars.
final
transactionId String
Transaction Id.
final
unclaimed bool
unclaimed: bit 0 of flags.0?true
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited