MessageActionRequestedPeerSentMe class
Message Action Requested Peer Sent Me.
ID: 93b31848.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- MessageActionBase
- MessageActionRequestedPeerSentMe
Constructors
-
MessageActionRequestedPeerSentMe({required int buttonId, required List<
RequestedPeerBase> peers}) -
Message Action Requested Peer Sent Me constructor.
const
- MessageActionRequestedPeerSentMe.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
-
Button Id.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
peers
→ List<
RequestedPeerBase> -
Peers.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited