MessageActionStarGiftPurchaseOfferDeclined class

Message Action Star Gift Purchase Offer Declined.

ID: 73ada76b.

Inheritance

Constructors

MessageActionStarGiftPurchaseOfferDeclined({required bool expired, required StarGiftBase gift, required StarsAmountBase price})
Message Action Star Gift Purchase Offer Declined constructor.
const
MessageActionStarGiftPurchaseOfferDeclined.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

expired bool
expired: bit 0 of flags.0?true
final
flags int
Flags.
no setter
gift StarGiftBase
Gift.
final
hashCode int
The hash code for this object.
no setterinherited
price StarsAmountBase
Price.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited