MessageActionStarGiftUnique class

Message Action Star Gift Unique.

ID: e6c31522.

Inheritance

Constructors

MessageActionStarGiftUnique({required bool upgrade, required bool transferred, required bool saved, required bool refunded, required bool prepaidUpgrade, required bool assigned, required bool fromOffer, required bool craft, required StarGiftBase gift, int? canExportAt, int? transferStars, PeerBase? fromId, PeerBase? peer, int? savedId, StarsAmountBase? resaleAmount, int? canTransferAt, int? canResellAt, int? dropOriginalDetailsStars, int? canCraftAt})
Message Action Star Gift Unique constructor.
const
MessageActionStarGiftUnique.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

assigned bool
assigned: bit 13 of flags.13?true
final
canCraftAt int?
Can Craft At.
final
canExportAt int?
Can Export At.
final
canResellAt int?
Can Resell At.
final
canTransferAt int?
Can Transfer At.
final
craft bool
craft: bit 16 of flags.16?true
final
dropOriginalDetailsStars int?
Drop Original Details Stars.
final
flags int
Flags.
no setter
fromId PeerBase?
From Id.
final
fromOffer bool
from_offer: bit 14 of flags.14?true
final
gift StarGiftBase
Gift.
final
hashCode int
The hash code for this object.
no setterinherited
peer PeerBase?
Peer.
final
prepaidUpgrade bool
prepaid_upgrade: bit 11 of flags.11?true
final
refunded bool
refunded: bit 5 of flags.5?true
final
resaleAmount StarsAmountBase?
Resale Amount.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saved bool
saved: bit 2 of flags.2?true
final
savedId int?
Saved Id.
final
transferred bool
transferred: bit 1 of flags.1?true
final
transferStars int?
Transfer Stars.
final
upgrade bool
upgrade: bit 0 of flags.0?true
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited