MessageActionSuggestBirthday class

Message Action Suggest Birthday.

ID: 2c8f2a25.

Inheritance

Constructors

MessageActionSuggestBirthday({required BirthdayBase birthday})
Message Action Suggest Birthday constructor.
const
MessageActionSuggestBirthday.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

birthday BirthdayBase
Birthday.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited