MessageActionTodoCompletions class

Message Action Todo Completions.

ID: cc7c5c89.

Inheritance

Constructors

MessageActionTodoCompletions({required List<int> completed, required List<int> incompleted})
Message Action Todo Completions constructor.
const
MessageActionTodoCompletions.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

completed List<int>
Completed.
final
hashCode int
The hash code for this object.
no setterinherited
incompleted List<int>
Incompleted.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited