MessageEntityDiffReplace class

Message Entity Diff Replace.

ID: c6c1e5a7.

Inheritance

Constructors

MessageEntityDiffReplace({required int offset, required int length, required String oldText})
Message Entity Diff Replace constructor.
const
MessageEntityDiffReplace.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
Length.
final
offset int
Offset.
final
oldText String
Old Text.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited