MessageEntityFormattedDate class
Message Entity Formatted Date.
ID: 904ac7c7.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- MessageEntityBase
- MessageEntityFormattedDate
Constructors
- MessageEntityFormattedDate({required bool relative, required bool shortTime, required bool longTime, required bool shortDate, required bool longDate, required bool dayOfWeek, required int offset, required int length, required DateTime date})
-
Message Entity Formatted Date constructor.
const
- MessageEntityFormattedDate.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- date → DateTime
-
Date.
final
- dayOfWeek → bool
-
day_of_week: bit 5 of flags.5?true
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → int
-
Length.
final
- longDate → bool
-
long_date: bit 4 of flags.4?true
final
- longTime → bool
-
long_time: bit 2 of flags.2?true
final
- offset → int
-
Offset.
final
- relative → bool
-
relative: bit 0 of flags.0?true
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortDate → bool
-
short_date: bit 3 of flags.3?true
final
- shortTime → bool
-
short_time: bit 1 of flags.1?true
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited