MessageMediaDice class

Message Media Dice.

ID: 08cbec07.

Inheritance

Constructors

MessageMediaDice({required int value, required String emoticon, MessagesEmojiGameOutcomeBase? gameOutcome})
Message Media Dice constructor.
const
MessageMediaDice.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

emoticon String
Emoticon.
final
flags int
Flags.
no setter
gameOutcome MessagesEmojiGameOutcomeBase?
Game Outcome.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
Value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited