MessageMediaPaidMedia class
Message Media Paid Media.
ID: a8852491.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- MessageMediaBase
- MessageMediaPaidMedia
Constructors
-
MessageMediaPaidMedia({required int starsAmount, required List<
MessageExtendedMediaBase> extendedMedia}) -
Message Media Paid Media constructor.
const
- MessageMediaPaidMedia.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
-
extendedMedia
→ List<
MessageExtendedMediaBase> -
Extended Media.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- starsAmount → int
-
Stars Amount.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited