MessageMediaPhoto class

Message Media Photo.

ID: e216eb63.

Inheritance

Constructors

MessageMediaPhoto({required bool spoiler, required bool livePhoto, PhotoBase? photo, int? ttlSeconds, DocumentBase? video})
Message Media Photo constructor.
const
MessageMediaPhoto.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
livePhoto bool
live_photo: bit 4 of flags.4?true
final
photo PhotoBase?
Photo.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spoiler bool
spoiler: bit 3 of flags.3?true
final
ttlSeconds int?
Ttl Seconds.
final
video DocumentBase?
Video.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited