MessageMediaPoll class

Message Media Poll.

ID: 773f4e66.

Inheritance

Constructors

MessageMediaPoll({required PollBase poll, required PollResultsBase results, MessageMediaBase? attachedMedia})
Message Media Poll constructor.
const
MessageMediaPoll.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

attachedMedia MessageMediaBase?
Attached Media.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
poll PollBase
Poll.
final
results PollResultsBase
Results.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited