MessageReplyHeader class

Message Reply Header.

ID: 1b97dd66.

Inheritance

Constructors

MessageReplyHeader({required bool replyToScheduled, required bool forumTopic, required bool quote, required bool replyToEphemeral, int? replyToMsgId, PeerBase? replyToPeerId, MessageFwdHeaderBase? replyFrom, MessageMediaBase? replyMedia, int? replyToTopId, String? quoteText, List<MessageEntityBase>? quoteEntities, int? quoteOffset, int? todoItemId, Uint8List? pollOption})
Message Reply Header constructor.
const
MessageReplyHeader.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
forumTopic bool
forum_topic: bit 3 of flags.3?true
final
hashCode int
The hash code for this object.
no setterinherited
pollOption Uint8List?
Poll Option.
final
quote bool
quote: bit 9 of flags.9?true
final
quoteEntities List<MessageEntityBase>?
Quote Entities.
final
quoteOffset int?
Quote Offset.
final
quoteText String?
Quote Text.
final
replyFrom MessageFwdHeaderBase?
Reply From.
final
replyMedia MessageMediaBase?
Reply Media.
final
replyToEphemeral bool
reply_to_ephemeral: bit 13 of flags.13?true
final
replyToMsgId int?
Reply To Msg Id.
final
replyToPeerId PeerBase?
Reply To Peer Id.
final
replyToScheduled bool
reply_to_scheduled: bit 2 of flags.2?true
final
replyToTopId int?
Reply To Top Id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
todoItemId int?
Todo Item Id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited