MessagesAcceptUrlAuth class

Messages Accept Url Auth.

Return Type: UrlAuthResultBase. ID: 67a3f0de.

Inheritance

Constructors

MessagesAcceptUrlAuth({required bool writeAllowed, required bool sharePhoneNumber, InputPeerBase? peer, int? msgId, int? buttonId, String? url, String? matchCode})
Messages Accept Url Auth constructor.
const
MessagesAcceptUrlAuth.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

buttonId int?
Button Id.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
matchCode String?
Match Code.
final
msgId int?
Msg Id.
final
peer InputPeerBase?
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharePhoneNumber bool
share_phone_number: bit 3 of flags.3?true
final
url String?
Url.
final
writeAllowed bool
write_allowed: bit 0 of flags.0?true
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited