MessagesAddPollAnswer class

Messages Add Poll Answer.

Return Type: UpdatesBase. ID: 19bc4b6d.

Inheritance

Constructors

MessagesAddPollAnswer({required InputPeerBase peer, required int msgId, required PollAnswerBase answer})
Messages Add Poll Answer constructor.
const
MessagesAddPollAnswer.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

answer PollAnswerBase
Answer.
final
hashCode int
The hash code for this object.
no setterinherited
msgId int
Msg Id.
final
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited