MessagesAppendTodoList class

Messages Append Todo List.

Return Type: UpdatesBase. ID: 21a61057.

Inheritance

Constructors

MessagesAppendTodoList({required InputPeerBase peer, required int msgId, required List<TodoItemBase> list})
Messages Append Todo List constructor.
const
MessagesAppendTodoList.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
list List<TodoItemBase>
List.
final
msgId int
Msg Id.
final
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited