MessagesBotPreparedInlineMessage class

Messages Bot Prepared Inline Message.

ID: 8ecf0511.

Inheritance

Constructors

MessagesBotPreparedInlineMessage({required String id, required DateTime expireDate})
Messages Bot Prepared Inline Message constructor.
const
MessagesBotPreparedInlineMessage.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

expireDate DateTime
Expire Date.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited