MessagesComposeMessageWithAI class

Messages Compose Message With A I.

Return Type: MessagesComposedMessageWithAIBase. ID: daecc589.

Inheritance

Constructors

MessagesComposeMessageWithAI({required bool proofread, required bool emojify, required TextWithEntitiesBase text, String? translateToLang, InputAiComposeToneBase? tone})
Messages Compose Message With A I constructor.
const
MessagesComposeMessageWithAI.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

emojify bool
emojify: bit 3 of flags.3?true
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
proofread bool
proofread: bit 0 of flags.0?true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text TextWithEntitiesBase
Text.
final
tone InputAiComposeToneBase?
Tone.
final
translateToLang String?
Translate To Lang.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited