MessagesComposedMessageWithAI class
Messages Composed Message With A I.
ID: 90d7adfa.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- MessagesComposedMessageWithAIBase
- MessagesComposedMessageWithAI
Constructors
- MessagesComposedMessageWithAI({required TextWithEntitiesBase resultText, TextWithEntitiesBase? diffText})
-
Messages Composed Message With A I constructor.
const
- MessagesComposedMessageWithAI.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- diffText → TextWithEntitiesBase?
-
Diff Text.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- resultText → TextWithEntitiesBase
-
Result Text.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited