MessagesDeleteFactCheck class

Messages Delete Fact Check.

Return Type: UpdatesBase. ID: d1da940c.

Inheritance

Constructors

MessagesDeleteFactCheck({required InputPeerBase peer, required int msgId})
Messages Delete Fact Check constructor.
const
MessagesDeleteFactCheck.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
msgId int
Msg Id.
final
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited