MessagesDeleteQuickReplyMessages class
Messages Delete Quick Reply Messages.
Return Type: UpdatesBase.
ID: e105e910.
Constructors
-
MessagesDeleteQuickReplyMessages({required int shortcutId, required List<
int> id}) -
Messages Delete Quick Reply Messages constructor.
const
- MessagesDeleteQuickReplyMessages.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
id
→ List<
int> -
Id.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortcutId → int
-
Shortcut Id.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited