MessagesEditChatCreator class

Messages Edit Chat Creator.

Return Type: UpdatesBase. ID: f743b857.

Inheritance

Constructors

MessagesEditChatCreator({required InputPeerBase peer, required InputUserBase userId, required InputCheckPasswordSRPBase password})
Messages Edit Chat Creator constructor.
const
MessagesEditChatCreator.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
password InputCheckPasswordSRPBase
Password.
final
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId InputUserBase
User Id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited