MessagesEditForumTopic class

Messages Edit Forum Topic.

Return Type: UpdatesBase. ID: cecc1134.

Inheritance

Constructors

MessagesEditForumTopic({required InputPeerBase peer, required int topicId, String? title, int? iconEmojiId, bool? closed, bool? hidden})
Messages Edit Forum Topic constructor.
const
MessagesEditForumTopic.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

closed bool?
closed: bit 2 of flags.2?Bool
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
hidden bool?
hidden: bit 3 of flags.3?Bool
final
iconEmojiId int?
Icon Emoji Id.
final
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
Title.
final
topicId int
Topic Id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited