MessagesEmojiGameOutcome class

Messages Emoji Game Outcome.

ID: da2ad647.

Inheritance

Constructors

MessagesEmojiGameOutcome({required Uint8List seed, required int stakeTonAmount, required int tonAmount})
Messages Emoji Game Outcome constructor.
const
MessagesEmojiGameOutcome.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seed Uint8List
Seed.
final
stakeTonAmount int
Stake Ton Amount.
final
tonAmount int
Ton Amount.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited