MessagesFeaturedStickers class

Messages Featured Stickers.

ID: be382906.

Inheritance

Constructors

MessagesFeaturedStickers({required bool premium, required int hash, required int count, required List<StickerSetCoveredBase> sets, required List<int> unread})
Messages Featured Stickers constructor.
const
MessagesFeaturedStickers.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

count int
Count.
final
flags int
Flags.
no setter
hash int
Hash.
final
hashCode int
The hash code for this object.
no setterinherited
premium bool
premium: bit 0 of flags.0?true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sets List<StickerSetCoveredBase>
Sets.
final
unread List<int>
Unread.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited