MessagesForwardMessages class

Messages Forward Messages.

Return Type: UpdatesBase. ID: 13704a7c.

Inheritance

Constructors

MessagesForwardMessages({required bool silent, required bool background, required bool withMyScore, required bool dropAuthor, required bool dropMediaCaptions, required bool noforwards, required bool allowPaidFloodskip, required InputPeerBase fromPeer, required List<int> id, required List<int> randomId, required InputPeerBase toPeer, int? topMsgId, InputReplyToBase? replyTo, DateTime? scheduleDate, int? scheduleRepeatPeriod, InputPeerBase? sendAs, InputQuickReplyShortcutBase? quickReplyShortcut, int? effect, int? videoTimestamp, int? allowPaidStars, SuggestedPostBase? suggestedPost})
Messages Forward Messages constructor.
const
MessagesForwardMessages.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

allowPaidFloodskip bool
allow_paid_floodskip: bit 19 of flags.19?true
final
allowPaidStars int?
Allow Paid Stars.
final
background bool
background: bit 6 of flags.6?true
final
dropAuthor bool
drop_author: bit 11 of flags.11?true
final
dropMediaCaptions bool
drop_media_captions: bit 12 of flags.12?true
final
effect int?
Effect.
final
flags int
Flags.
no setter
fromPeer InputPeerBase
From Peer.
final
hashCode int
The hash code for this object.
no setterinherited
id List<int>
Id.
final
noforwards bool
noforwards: bit 14 of flags.14?true
final
quickReplyShortcut InputQuickReplyShortcutBase?
Quick Reply Shortcut.
final
randomId List<int>
Random Id.
final
replyTo InputReplyToBase?
Reply To.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduleDate DateTime?
Schedule Date.
final
scheduleRepeatPeriod int?
Schedule Repeat Period.
final
sendAs InputPeerBase?
Send As.
final
silent bool
silent: bit 5 of flags.5?true
final
suggestedPost SuggestedPostBase?
Suggested Post.
final
toPeer InputPeerBase
To Peer.
final
topMsgId int?
Top Msg Id.
final
videoTimestamp int?
Video Timestamp.
final
withMyScore bool
with_my_score: bit 8 of flags.8?true
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited