MessagesFoundStickers class

Messages Found Stickers.

ID: 82c9e290.

Inheritance

Constructors

MessagesFoundStickers({int? nextOffset, required int hash, required List<DocumentBase> stickers})
Messages Found Stickers constructor.
const
MessagesFoundStickers.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hash int
Hash.
final
hashCode int
The hash code for this object.
no setterinherited
nextOffset int?
Next Offset.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stickers List<DocumentBase>
Stickers.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited