MessagesGetBotApp class
Messages Get Bot App.
Return Type: MessagesBotAppBase.
ID: 34fdc5c3.
Constructors
- MessagesGetBotApp({required InputBotAppBase app, required int hash})
-
Messages Get Bot App constructor.
const
- MessagesGetBotApp.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- app → InputBotAppBase
-
App.
final
- hash → int
-
Hash.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited