MessagesGetBotCallbackAnswer class

Messages Get Bot Callback Answer.

Return Type: MessagesBotCallbackAnswerBase. ID: 9342ca07.

Inheritance

Constructors

MessagesGetBotCallbackAnswer({required bool game, required InputPeerBase peer, required int msgId, Uint8List? data, InputCheckPasswordSRPBase? password})
Messages Get Bot Callback Answer constructor.
const
MessagesGetBotCallbackAnswer.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

data Uint8List?
Data.
final
flags int
Flags.
no setter
game bool
game: bit 1 of flags.1?true
final
hashCode int
The hash code for this object.
no setterinherited
msgId int
Msg Id.
final
password InputCheckPasswordSRPBase?
Password.
final
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited