MessagesGetDocumentByHash class

Messages Get Document By Hash.

Return Type: DocumentBase. ID: b1f2061f.

Inheritance

Constructors

MessagesGetDocumentByHash({required Uint8List sha256, required int size, required String mimeType})
Messages Get Document By Hash constructor.
const
MessagesGetDocumentByHash.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
mimeType String
Mime Type.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sha256 Uint8List
Sha256.
final
size int
Size.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited