MessagesGetFactCheck class

Messages Get Fact Check.

Return Type: List<FactCheckBase>. ID: b9cdc5ee.

Inheritance

Constructors

MessagesGetFactCheck({required InputPeerBase peer, required List<int> msgId})
Messages Get Fact Check constructor.
const
MessagesGetFactCheck.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
msgId List<int>
Msg Id.
final
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited