MessagesGetForumTopics class

Messages Get Forum Topics.

Return Type: MessagesForumTopicsBase. ID: 3ba47bff.

Inheritance

Constructors

MessagesGetForumTopics({required InputPeerBase peer, String? q, required DateTime offsetDate, required int offsetId, required int offsetTopic, required int limit})
Messages Get Forum Topics constructor.
const
MessagesGetForumTopics.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
limit int
Limit.
final
offsetDate DateTime
Offset Date.
final
offsetId int
Offset Id.
final
offsetTopic int
Offset Topic.
final
peer InputPeerBase
Peer.
final
q String?
Q.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited