MessagesGetForumTopicsByID class

Messages Get Forum Topics By I D.

Return Type: MessagesForumTopicsBase. ID: af0a4a08.

Inheritance

Constructors

MessagesGetForumTopicsByID({required InputPeerBase peer, required List<int> topics})
Messages Get Forum Topics By I D constructor.
const
MessagesGetForumTopicsByID.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topics List<int>
Topics.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited