MessagesGetFutureChatCreatorAfterLeave class

Messages Get Future Chat Creator After Leave.

Return Type: UserBase. ID: 3b7d0ea6.

Inheritance

Constructors

MessagesGetFutureChatCreatorAfterLeave({required InputPeerBase peer})
Messages Get Future Chat Creator After Leave constructor.
const
MessagesGetFutureChatCreatorAfterLeave.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited