MessagesGetGameHighScores class

Messages Get Game High Scores.

Return Type: MessagesHighScoresBase. ID: e822649d.

Inheritance

Constructors

MessagesGetGameHighScores({required InputPeerBase peer, required int id, required InputUserBase userId})
Messages Get Game High Scores constructor.
const
MessagesGetGameHighScores.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
Id.
final
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId InputUserBase
User Id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited