MessagesGetMyStickers class

Messages Get My Stickers.

Return Type: MessagesMyStickersBase. ID: d0b5e1fc.

Inheritance

Constructors

MessagesGetMyStickers({required int offsetId, required int limit})
Messages Get My Stickers constructor.
const
MessagesGetMyStickers.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
limit int
Limit.
final
offsetId int
Offset Id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited