MessagesQuickReplies class
Messages Quick Replies.
ID: c68d6695.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- MessagesQuickRepliesBase
- MessagesQuickReplies
Constructors
-
MessagesQuickReplies({required List<
QuickReplyBase> quickReplies, required List<MessageBase> messages, required List<ChatBase> chats, required List<UserBase> users}) -
Messages Quick Replies constructor.
const
- MessagesQuickReplies.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
-
chats
→ List<
ChatBase> -
Chats.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messages
→ List<
MessageBase> -
Messages.
final
-
quickReplies
→ List<
QuickReplyBase> -
Quick Replies.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
users
→ List<
UserBase> -
Users.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited