MessagesReorderStickerSets class
Messages Reorder Sticker Sets.
Return Type: bool.
ID: 78337739.
Constructors
-
MessagesReorderStickerSets({required bool masks, required bool emojis, required List<
int> order}) -
Messages Reorder Sticker Sets constructor.
const
- MessagesReorderStickerSets.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- emojis → bool
-
emojis: bit 1 of flags.1?true
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- masks → bool
-
masks: bit 0 of flags.0?true
final
-
order
→ List<
int> -
Order.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited