MessagesRequestMainWebView class

Messages Request Main Web View.

Return Type: WebViewResultBase. ID: c9e01e7b.

Inheritance

Constructors

MessagesRequestMainWebView({required bool compact, required bool fullscreen, required InputPeerBase peer, required InputUserBase bot, String? startParam, DataJSONBase? themeParams, required String platform})
Messages Request Main Web View constructor.
const
MessagesRequestMainWebView.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

bot InputUserBase
Bot.
final
compact bool
compact: bit 7 of flags.7?true
final
flags int
Flags.
no setter
fullscreen bool
fullscreen: bit 8 of flags.8?true
final
hashCode int
The hash code for this object.
no setterinherited
peer InputPeerBase
Peer.
final
platform String
Platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startParam String?
Start Param.
final
themeParams DataJSONBase?
Theme Params.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited