MessagesRequestUrlAuth class
Messages Request Url Auth.
Return Type: UrlAuthResultBase.
ID: 894cc99c.
Constructors
- MessagesRequestUrlAuth({InputPeerBase? peer, int? msgId, int? buttonId, String? url, String? inAppOrigin})
-
Messages Request Url Auth constructor.
const
- MessagesRequestUrlAuth.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
-
Button Id.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- inAppOrigin → String?
-
In App Origin.
final
- msgId → int?
-
Msg Id.
final
- peer → InputPeerBase?
-
Peer.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String?
-
Url.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited