MessagesRequestWebView class

Messages Request Web View.

Return Type: WebViewResultBase. ID: 269dc2c1.

Inheritance

Constructors

MessagesRequestWebView({required bool fromBotMenu, required bool silent, required bool compact, required bool fullscreen, required InputPeerBase peer, required InputUserBase bot, String? url, String? startParam, DataJSONBase? themeParams, required String platform, InputReplyToBase? replyTo, InputPeerBase? sendAs})
Messages Request Web View constructor.
const
MessagesRequestWebView.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

bot InputUserBase
Bot.
final
compact bool
compact: bit 7 of flags.7?true
final
flags int
Flags.
no setter
fromBotMenu bool
from_bot_menu: bit 4 of flags.4?true
final
fullscreen bool
fullscreen: bit 8 of flags.8?true
final
hashCode int
The hash code for this object.
no setterinherited
peer InputPeerBase
Peer.
final
platform String
Platform.
final
replyTo InputReplyToBase?
Reply To.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendAs InputPeerBase?
Send As.
final
silent bool
silent: bit 5 of flags.5?true
final
startParam String?
Start Param.
final
themeParams DataJSONBase?
Theme Params.
final
url String?
Url.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited