MessagesSavedGifs class

Messages Saved Gifs.

ID: 84a02a0d.

Inheritance

Constructors

MessagesSavedGifs({required int hash, required List<DocumentBase> gifs})
Messages Saved Gifs constructor.
const
MessagesSavedGifs.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

gifs List<DocumentBase>
Gifs.
final
hash int
Hash.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited