MessagesSavedReactionTags class

Messages Saved Reaction Tags.

ID: 3259950a.

Inheritance

Constructors

MessagesSavedReactionTags({required List<SavedReactionTagBase> tags, required int hash})
Messages Saved Reaction Tags constructor.
const
MessagesSavedReactionTags.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hash int
Hash.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<SavedReactionTagBase>
Tags.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited