MessagesSearch class
Messages Search.
Return Type: MessagesMessagesBase.
ID: 29ee847a.
Constructors
-
MessagesSearch({required InputPeerBase peer, required String q, InputPeerBase? fromId, InputPeerBase? savedPeerId, List<
ReactionBase> ? savedReaction, int? topMsgId, required MessagesFilterBase filter, required DateTime minDate, required DateTime maxDate, required int offsetId, required int addOffset, required int limit, required int maxId, required int minId, required int hash}) -
Messages Search constructor.
const
- MessagesSearch.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- addOffset → int
-
Add Offset.
final
- filter → MessagesFilterBase
-
Filter.
final
- flags → int
-
Flags.
no setter
- fromId → InputPeerBase?
-
From Id.
final
- hash → int
-
Hash.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int
-
Limit.
final
- maxDate → DateTime
-
Max Date.
final
- maxId → int
-
Max Id.
final
- minDate → DateTime
-
Min Date.
final
- minId → int
-
Min Id.
final
- offsetId → int
-
Offset Id.
final
- peer → InputPeerBase
-
Peer.
final
- q → String
-
Q.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- savedPeerId → InputPeerBase?
-
Saved Peer Id.
final
-
savedReaction
→ List<
ReactionBase> ? -
Saved Reaction.
final
- topMsgId → int?
-
Top Msg Id.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited