MessagesSearchGlobal class
Messages Search Global.
Return Type: MessagesMessagesBase.
ID: 6126a43c.
Constructors
- MessagesSearchGlobal({required bool broadcastsOnly, required bool groupsOnly, required bool usersOnly, int? folderId, InputChannelBase? community, required String q, required MessagesFilterBase filter, required DateTime minDate, required DateTime maxDate, required int offsetRate, required InputPeerBase offsetPeer, required int offsetId, required int limit})
-
Messages Search Global constructor.
const
- MessagesSearchGlobal.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- broadcastsOnly → bool
-
broadcasts_only: bit 1 of flags.1?true
final
- community → InputChannelBase?
-
Community.
final
- filter → MessagesFilterBase
-
Filter.
final
- flags → int
-
Flags.
no setter
- folderId → int?
-
Folder Id.
final
- groupsOnly → bool
-
groups_only: bit 2 of flags.2?true
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int
-
Limit.
final
- maxDate → DateTime
-
Max Date.
final
- minDate → DateTime
-
Min Date.
final
- offsetId → int
-
Offset Id.
final
- offsetPeer → InputPeerBase
-
Offset Peer.
final
- offsetRate → int
-
Offset Rate.
final
- q → String
-
Q.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usersOnly → bool
-
users_only: bit 3 of flags.3?true
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited