MessagesSearchStickers class
Messages Search Stickers.
Return Type: MessagesFoundStickersBase.
ID: 29b1c66a.
Constructors
-
MessagesSearchStickers({required bool emojis, required String q, required String emoticon, required List<
String> langCode, required int offset, required int limit, required int hash}) -
Messages Search Stickers constructor.
const
- MessagesSearchStickers.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- emojis → bool
-
emojis: bit 0 of flags.0?true
final
- emoticon → String
-
Emoticon.
final
- flags → int
-
Flags.
no setter
- hash → int
-
Hash.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
langCode
→ List<
String> -
Lang Code.
final
- limit → int
-
Limit.
final
- offset → int
-
Offset.
final
- q → String
-
Q.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited