MessagesSendBotRequestedPeer class

Messages Send Bot Requested Peer.

Return Type: UpdatesBase. ID: 6c5cf2a7.

Inheritance

Constructors

MessagesSendBotRequestedPeer({required InputPeerBase peer, int? msgId, String? webappReqId, required int buttonId, required List<InputPeerBase> requestedPeers})
Messages Send Bot Requested Peer constructor.
const
MessagesSendBotRequestedPeer.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

buttonId int
Button Id.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
msgId int?
Msg Id.
final
peer InputPeerBase
Peer.
final
requestedPeers List<InputPeerBase>
Requested Peers.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webappReqId String?
Webapp Req Id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited