MessagesSendInlineBotResult class

Messages Send Inline Bot Result.

Return Type: UpdatesBase. ID: c0cf7646.

Inheritance

Constructors

MessagesSendInlineBotResult({required bool silent, required bool background, required bool clearDraft, required bool hideVia, required InputPeerBase peer, InputReplyToBase? replyTo, required int randomId, required int queryId, required String id, DateTime? scheduleDate, InputPeerBase? sendAs, InputQuickReplyShortcutBase? quickReplyShortcut, int? allowPaidStars})
Messages Send Inline Bot Result constructor.
const
MessagesSendInlineBotResult.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

allowPaidStars int?
Allow Paid Stars.
final
background bool
background: bit 6 of flags.6?true
final
clearDraft bool
clear_draft: bit 7 of flags.7?true
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
hideVia bool
hide_via: bit 11 of flags.11?true
final
id String
Id.
final
peer InputPeerBase
Peer.
final
queryId int
Query Id.
final
quickReplyShortcut InputQuickReplyShortcutBase?
Quick Reply Shortcut.
final
randomId int
Random Id.
final
replyTo InputReplyToBase?
Reply To.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduleDate DateTime?
Schedule Date.
final
sendAs InputPeerBase?
Send As.
final
silent bool
silent: bit 5 of flags.5?true
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited