MessagesSetBotGuestChatResult class
Messages Set Bot Guest Chat Result.
Return Type: InputBotInlineMessageIDBase.
ID: b8f106e3.
Constructors
- MessagesSetBotGuestChatResult({required int queryId, required InputBotInlineResultBase result})
-
Messages Set Bot Guest Chat Result constructor.
const
- MessagesSetBotGuestChatResult.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- queryId → int
-
Query Id.
final
- result → InputBotInlineResultBase
-
Result.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited