MessagesSummarizeText class

Messages Summarize Text.

Return Type: TextWithEntitiesBase. ID: abbbd346.

Inheritance

Constructors

MessagesSummarizeText({required InputPeerBase peer, required int id, String? toLang, String? tone})
Messages Summarize Text constructor.
const
MessagesSummarizeText.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
id int
Id.
final
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toLang String?
To Lang.
final
tone String?
Tone.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited