MessagesToggleTodoCompleted class

Messages Toggle Todo Completed.

Return Type: UpdatesBase. ID: d3e03124.

Inheritance

Constructors

MessagesToggleTodoCompleted({required InputPeerBase peer, required int msgId, required List<int> completed, required List<int> incompleted})
Messages Toggle Todo Completed constructor.
const
MessagesToggleTodoCompleted.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

completed List<int>
Completed.
final
hashCode int
The hash code for this object.
no setterinherited
incompleted List<int>
Incompleted.
final
msgId int
Msg Id.
final
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited