MessagesUpdateDialogFiltersOrder class

Messages Update Dialog Filters Order.

Return Type: bool. ID: c563c1e4.

Inheritance

Constructors

MessagesUpdateDialogFiltersOrder({required List<int> order})
Messages Update Dialog Filters Order constructor.
const
MessagesUpdateDialogFiltersOrder.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
order List<int>
Order.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited