MissingInvitee class

Missing Invitee.

ID: 628c9224.

Inheritance

Constructors

MissingInvitee({required bool premiumWouldAllowInvite, required bool premiumRequiredForPm, required int userId})
Missing Invitee constructor.
const
MissingInvitee.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
premiumRequiredForPm bool
premium_required_for_pm: bit 1 of flags.1?true
final
premiumWouldAllowInvite bool
premium_would_allow_invite: bit 0 of flags.0?true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
User Id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited