PQInnerDataDc class

P Q Inner Data Dc.

ID: a9f55f95.

Inheritance

Constructors

PQInnerDataDc({required Uint8List pq, required Uint8List p, required Uint8List q, required Int128 nonce, required Int128 serverNonce, required Int256 newNonce, required int dc})
P Q Inner Data Dc constructor.
const
PQInnerDataDc.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

dc int
Dc.
final
hashCode int
The hash code for this object.
no setterinherited
newNonce Int256
New Nonce.
final
nonce Int128
Nonce.
final
p Uint8List
P.
final
pq Uint8List
Pq.
final
q Uint8List
Q.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverNonce Int128
Server Nonce.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited