PageBlockOrderedList class
Page Block Ordered List.
ID: 1fd6f6c1.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- PageBlockBase
- PageBlockOrderedList
Constructors
-
PageBlockOrderedList({required bool reversed, required List<
PageListOrderedItemBase> items, int? start, String? type}) -
Page Block Ordered List constructor.
const
- PageBlockOrderedList.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
PageListOrderedItemBase> -
Items.
final
- reversed → bool
-
reversed: bit 2 of flags.2?true
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → int?
-
Start.
final
- type → String?
-
Type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited