Passkey class

Passkey.

ID: 98613ebf.

Inheritance

Constructors

Passkey({required String id, required String name, required DateTime date, int? softwareEmojiId, DateTime? lastUsageDate})
Passkey constructor.
const
Passkey.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

date DateTime
Date.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
Id.
final
lastUsageDate DateTime?
Last Usage Date.
final
name String
Name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
softwareEmojiId int?
Software Emoji Id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited