PaymentsChangeStarsSubscription class

Payments Change Stars Subscription.

Return Type: bool. ID: c7770878.

Inheritance

Constructors

PaymentsChangeStarsSubscription({required InputPeerBase peer, required String subscriptionId, bool? canceled})
Payments Change Stars Subscription constructor.
const
PaymentsChangeStarsSubscription.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

canceled bool?
canceled: bit 0 of flags.0?Bool
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionId String
Subscription Id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited