PaymentsConnectStarRefBot class

Payments Connect Star Ref Bot.

Return Type: PaymentsConnectedStarRefBotsBase. ID: 7ed5348a.

Inheritance

Constructors

PaymentsConnectStarRefBot({required InputPeerBase peer, required InputUserBase bot})
Payments Connect Star Ref Bot constructor.
const
PaymentsConnectStarRefBot.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

bot InputUserBase
Bot.
final
hashCode int
The hash code for this object.
no setterinherited
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited