PaymentsConnectedStarRefBots class

Payments Connected Star Ref Bots.

ID: 98d5ea1d.

Inheritance

Constructors

PaymentsConnectedStarRefBots({required int count, required List<ConnectedBotStarRefBase> connectedBots, required List<UserBase> users})
Payments Connected Star Ref Bots constructor.
const
PaymentsConnectedStarRefBots.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

connectedBots List<ConnectedBotStarRefBase>
Connected Bots.
final
count int
Count.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
users List<UserBase>
Users.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited