PaymentsCreateStarGiftCollection class

Payments Create Star Gift Collection.

Return Type: StarGiftCollectionBase. ID: 1f4a0e87.

Inheritance

Constructors

PaymentsCreateStarGiftCollection({required InputPeerBase peer, required String title, required List<InputSavedStarGiftBase> stargift})
Payments Create Star Gift Collection constructor.
const
PaymentsCreateStarGiftCollection.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stargift List<InputSavedStarGiftBase>
Stargift.
final
title String
Title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited