PaymentsGetConnectedStarRefBots class

Payments Get Connected Star Ref Bots.

Return Type: PaymentsConnectedStarRefBotsBase. ID: 5869a553.

Inheritance

Constructors

PaymentsGetConnectedStarRefBots({required InputPeerBase peer, DateTime? offsetDate, String? offsetLink, required int limit})
Payments Get Connected Star Ref Bots constructor.
const
PaymentsGetConnectedStarRefBots.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
limit int
Limit.
final
offsetDate DateTime?
Offset Date.
final
Offset Link.
final
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited