PaymentsGetCraftStarGifts class

Payments Get Craft Star Gifts.

Return Type: PaymentsSavedStarGiftsBase. ID: fd05dd00.

Inheritance

Constructors

PaymentsGetCraftStarGifts({required int giftId, required String offset, required int limit})
Payments Get Craft Star Gifts constructor.
const
PaymentsGetCraftStarGifts.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

giftId int
Gift Id.
final
hashCode int
The hash code for this object.
no setterinherited
limit int
Limit.
final
offset String
Offset.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited