PaymentsGetSavedStarGifts class

Payments Get Saved Star Gifts.

Return Type: PaymentsSavedStarGiftsBase. ID: a319e569.

Inheritance

Constructors

PaymentsGetSavedStarGifts({required bool excludeUnsaved, required bool excludeSaved, required bool excludeUnlimited, required bool excludeUnique, required bool sortByValue, required bool excludeUpgradable, required bool excludeUnupgradable, required bool peerColorAvailable, required bool excludeHosted, required InputPeerBase peer, int? collectionId, required String offset, required int limit})
Payments Get Saved Star Gifts constructor.
const
PaymentsGetSavedStarGifts.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

collectionId int?
Collection Id.
final
excludeHosted bool
exclude_hosted: bit 10 of flags.10?true
final
excludeSaved bool
exclude_saved: bit 1 of flags.1?true
final
excludeUnique bool
exclude_unique: bit 4 of flags.4?true
final
excludeUnlimited bool
exclude_unlimited: bit 2 of flags.2?true
final
excludeUnsaved bool
exclude_unsaved: bit 0 of flags.0?true
final
excludeUnupgradable bool
exclude_unupgradable: bit 8 of flags.8?true
final
excludeUpgradable bool
exclude_upgradable: bit 7 of flags.7?true
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
limit int
Limit.
final
offset String
Offset.
final
peer InputPeerBase
Peer.
final
peerColorAvailable bool
peer_color_available: bit 9 of flags.9?true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortByValue bool
sort_by_value: bit 5 of flags.5?true
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited