PaymentsGetStarGiftWithdrawalUrl class

Payments Get Star Gift Withdrawal Url.

Return Type: PaymentsStarGiftWithdrawalUrlBase. ID: d06e93a8.

Inheritance

Constructors

PaymentsGetStarGiftWithdrawalUrl({required InputSavedStarGiftBase stargift, required InputCheckPasswordSRPBase password})
Payments Get Star Gift Withdrawal Url constructor.
const
PaymentsGetStarGiftWithdrawalUrl.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
password InputCheckPasswordSRPBase
Password.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stargift InputSavedStarGiftBase
Stargift.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited