PaymentsGetStarsSubscriptions class

Payments Get Stars Subscriptions.

Return Type: PaymentsStarsStatusBase. ID: 032512c5.

Inheritance

Constructors

PaymentsGetStarsSubscriptions({required bool missingBalance, required InputPeerBase peer, required String offset})
Payments Get Stars Subscriptions constructor.
const
PaymentsGetStarsSubscriptions.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
missingBalance bool
missing_balance: bit 0 of flags.0?true
final
offset String
Offset.
final
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited