PaymentsGetStarsTransactions class

Payments Get Stars Transactions.

Return Type: PaymentsStarsStatusBase. ID: 69da4557.

Inheritance

Constructors

PaymentsGetStarsTransactions({required bool inbound, required bool outbound, required bool ascending, required bool ton, String? subscriptionId, required InputPeerBase peer, required String offset, required int limit})
Payments Get Stars Transactions constructor.
const
PaymentsGetStarsTransactions.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

ascending bool
ascending: bit 2 of flags.2?true
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
inbound bool
inbound: bit 0 of flags.0?true
final
limit int
Limit.
final
offset String
Offset.
final
outbound bool
outbound: bit 1 of flags.1?true
final
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionId String?
Subscription Id.
final
ton bool
ton: bit 4 of flags.4?true
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited