PaymentsGetStarsTransactionsByID class

Payments Get Stars Transactions By I D.

Return Type: PaymentsStarsStatusBase. ID: 2dca16b8.

Inheritance

Constructors

PaymentsGetStarsTransactionsByID({required bool ton, required InputPeerBase peer, required List<InputStarsTransactionBase> id})
Payments Get Stars Transactions By I D constructor.
const
PaymentsGetStarsTransactionsByID.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
id List<InputStarsTransactionBase>
Id.
final
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ton bool
ton: bit 0 of flags.0?true
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited