PaymentsGetSuggestedStarRefBots class

Payments Get Suggested Star Ref Bots.

Return Type: PaymentsSuggestedStarRefBotsBase. ID: 0d6b48f7.

Inheritance

Constructors

PaymentsGetSuggestedStarRefBots({required bool orderByRevenue, required bool orderByDate, required InputPeerBase peer, required String offset, required int limit})
Payments Get Suggested Star Ref Bots constructor.
const
PaymentsGetSuggestedStarRefBots.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
limit int
Limit.
final
offset String
Offset.
final
orderByDate bool
order_by_date: bit 1 of flags.1?true
final
orderByRevenue bool
order_by_revenue: bit 0 of flags.0?true
final
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited