PaymentsPaymentFormStars class

Payments Payment Form Stars.

ID: 7bf6b15c.

Inheritance

Constructors

PaymentsPaymentFormStars({required int formId, required int botId, required String title, required String description, WebDocumentBase? photo, required InvoiceBase invoice, required List<UserBase> users})
Payments Payment Form Stars constructor.
const
PaymentsPaymentFormStars.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

botId int
Bot Id.
final
description String
Description.
final
flags int
Flags.
no setter
formId int
Form Id.
final
hashCode int
The hash code for this object.
no setterinherited
invoice InvoiceBase
Invoice.
final
photo WebDocumentBase?
Photo.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
Title.
final
users List<UserBase>
Users.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited