PaymentsResolveStarGiftOffer class
Payments Resolve Star Gift Offer.
Return Type: UpdatesBase.
ID: e9ce781c.
Constructors
- PaymentsResolveStarGiftOffer({required bool decline, required int offerMsgId})
-
Payments Resolve Star Gift Offer constructor.
const
- PaymentsResolveStarGiftOffer.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- decline → bool
-
decline: bit 0 of flags.0?true
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- offerMsgId → int
-
Offer Msg Id.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited