PaymentsSavedStarGifts class
Payments Saved Star Gifts.
ID: 95f389b1.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- PaymentsSavedStarGiftsBase
- PaymentsSavedStarGifts
Constructors
-
PaymentsSavedStarGifts({required int count, bool? chatNotificationsEnabled, required List<
SavedStarGiftBase> gifts, String? nextOffset, required List<ChatBase> chats, required List<UserBase> users}) -
Payments Saved Star Gifts constructor.
const
- PaymentsSavedStarGifts.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- chatNotificationsEnabled → bool?
-
chat_notifications_enabled: bit 1 of flags.1?Bool
final
-
chats
→ List<
ChatBase> -
Chats.
final
- count → int
-
Count.
final
- flags → int
-
Flags.
no setter
-
gifts
→ List<
SavedStarGiftBase> -
Gifts.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextOffset → String?
-
Next Offset.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
users
→ List<
UserBase> -
Users.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited