PaymentsSendStarGiftOffer class

Payments Send Star Gift Offer.

Return Type: UpdatesBase. ID: 8fb86b41.

Inheritance

Constructors

PaymentsSendStarGiftOffer({required InputPeerBase peer, required String slug, required StarsAmountBase price, required int duration, required int randomId, int? allowPaidStars})
Payments Send Star Gift Offer constructor.
const
PaymentsSendStarGiftOffer.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

allowPaidStars int?
Allow Paid Stars.
final
duration int
Duration.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
peer InputPeerBase
Peer.
final
price StarsAmountBase
Price.
final
randomId int
Random Id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String
Slug.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited