PaymentsSendStarsForm class

Payments Send Stars Form.

Return Type: PaymentsPaymentResultBase. ID: 7998c914.

Inheritance

Constructors

PaymentsSendStarsForm({required int formId, required InputInvoiceBase invoice})
Payments Send Stars Form constructor.
const
PaymentsSendStarsForm.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

formId int
Form Id.
final
hashCode int
The hash code for this object.
no setterinherited
invoice InputInvoiceBase
Invoice.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited