PaymentsStarGiftAuctionState class
Payments Star Gift Auction State.
ID: 6b39f4ec.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- PaymentsStarGiftAuctionStateBase
- PaymentsStarGiftAuctionState
Constructors
-
PaymentsStarGiftAuctionState({required StarGiftBase gift, required StarGiftAuctionStateBase state, required StarGiftAuctionUserStateBase userState, required int timeout, required List<
UserBase> users, required List<ChatBase> chats}) -
Payments Star Gift Auction State constructor.
const
- PaymentsStarGiftAuctionState.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
-
chats
→ List<
ChatBase> -
Chats.
final
- gift → StarGiftBase
-
Gift.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → StarGiftAuctionStateBase
-
State.
final
- timeout → int
-
Timeout.
final
-
users
→ List<
UserBase> -
Users.
final
- userState → StarGiftAuctionUserStateBase
-
User State.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited