PaymentsStarGiftUpgradeAttributes class

Payments Star Gift Upgrade Attributes.

ID: 46c6e36f.

Inheritance

Constructors

PaymentsStarGiftUpgradeAttributes({required List<StarGiftAttributeBase> attributes})
Payments Star Gift Upgrade Attributes constructor.
const
PaymentsStarGiftUpgradeAttributes.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

attributes List<StarGiftAttributeBase>
Attributes.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited