PaymentsStarsRevenueStats class
Payments Stars Revenue Stats.
ID: 6c207376.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- PaymentsStarsRevenueStatsBase
- PaymentsStarsRevenueStats
Constructors
- PaymentsStarsRevenueStats({StatsGraphBase? topHoursGraph, required StatsGraphBase revenueGraph, required StarsRevenueStatusBase status, required double usdRate})
-
Payments Stars Revenue Stats constructor.
const
- PaymentsStarsRevenueStats.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- revenueGraph → StatsGraphBase
-
Revenue Graph.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → StarsRevenueStatusBase
-
Status.
final
- topHoursGraph → StatsGraphBase?
-
Top Hours Graph.
final
- usdRate → double
-
Usd Rate.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited