PaymentsUniqueStarGiftValueInfo class

Payments Unique Star Gift Value Info.

ID: 512fe446.

Inheritance

Constructors

PaymentsUniqueStarGiftValueInfo({required bool lastSaleOnFragment, required bool valueIsAverage, required String currency, required int value, required DateTime initialSaleDate, required int initialSaleStars, required int initialSalePrice, DateTime? lastSaleDate, int? lastSalePrice, int? floorPrice, int? averagePrice, int? listedCount, int? fragmentListedCount, String? fragmentListedUrl})
Payments Unique Star Gift Value Info constructor.
const
PaymentsUniqueStarGiftValueInfo.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

averagePrice int?
Average Price.
final
currency String
Currency.
final
flags int
Flags.
no setter
floorPrice int?
Floor Price.
final
fragmentListedCount int?
Fragment Listed Count.
final
fragmentListedUrl String?
Fragment Listed Url.
final
hashCode int
The hash code for this object.
no setterinherited
initialSaleDate DateTime
Initial Sale Date.
final
initialSalePrice int
Initial Sale Price.
final
initialSaleStars int
Initial Sale Stars.
final
lastSaleDate DateTime?
Last Sale Date.
final
lastSaleOnFragment bool
last_sale_on_fragment: bit 1 of flags.1?true
final
lastSalePrice int?
Last Sale Price.
final
listedCount int?
Listed Count.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
Value.
final
valueIsAverage bool
value_is_average: bit 6 of flags.6?true
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited