PaymentsUpdateStarGiftCollection class

Payments Update Star Gift Collection.

Return Type: StarGiftCollectionBase. ID: 4fddbee7.

Inheritance

Constructors

PaymentsUpdateStarGiftCollection({required InputPeerBase peer, required int collectionId, String? title, List<InputSavedStarGiftBase>? deleteStargift, List<InputSavedStarGiftBase>? addStargift, List<InputSavedStarGiftBase>? order})
Payments Update Star Gift Collection constructor.
const
PaymentsUpdateStarGiftCollection.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

addStargift List<InputSavedStarGiftBase>?
Add Stargift.
final
collectionId int
Collection Id.
final
deleteStargift List<InputSavedStarGiftBase>?
Delete Stargift.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
order List<InputSavedStarGiftBase>?
Order.
final
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
Title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited