PeerColorCollectible class

Peer Color Collectible.

ID: b9c0639a.

Inheritance

Constructors

PeerColorCollectible({required int collectibleId, required int giftEmojiId, required int backgroundEmojiId, required int accentColor, required List<int> colors, int? darkAccentColor, List<int>? darkColors})
Peer Color Collectible constructor.
const
PeerColorCollectible.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

accentColor int
Accent Color.
final
backgroundEmojiId int
Background Emoji Id.
final
collectibleId int
Collectible Id.
final
colors List<int>
Colors.
final
darkAccentColor int?
Dark Accent Color.
final
darkColors List<int>?
Dark Colors.
final
flags int
Flags.
no setter
giftEmojiId int
Gift Emoji Id.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited