PhoneCreateConferenceCall class
Phone Create Conference Call.
Return Type: UpdatesBase.
ID: 7d0444bb.
Constructors
- PhoneCreateConferenceCall({required bool muted, required bool videoStopped, required bool join, required int randomId, Int256? publicKey, Uint8List? block, DataJSONBase? params})
-
Phone Create Conference Call constructor.
const
- PhoneCreateConferenceCall.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- block → Uint8List?
-
Block.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- join → bool
-
join: bit 3 of flags.3?true
final
- muted → bool
-
muted: bit 0 of flags.0?true
final
- params → DataJSONBase?
-
Params.
final
- publicKey → Int256?
-
Public Key.
final
- randomId → int
-
Random Id.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- videoStopped → bool
-
video_stopped: bit 2 of flags.2?true
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited