PhoneGetGroupCall class

Phone Get Group Call.

Return Type: PhoneGroupCallBase. ID: 041845db.

Inheritance

Constructors

PhoneGetGroupCall({required InputGroupCallBase call, required int limit})
Phone Get Group Call constructor.
const
PhoneGetGroupCall.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

call InputGroupCallBase
Call.
final
hashCode int
The hash code for this object.
no setterinherited
limit int
Limit.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited