PhoneGetGroupCallChainBlocks class

Phone Get Group Call Chain Blocks.

Return Type: UpdatesBase. ID: ee9f88a6.

Inheritance

Constructors

PhoneGetGroupCallChainBlocks({required InputGroupCallBase call, required int subChainId, required int offset, required int limit})
Phone Get Group Call Chain Blocks constructor.
const
PhoneGetGroupCallChainBlocks.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

call InputGroupCallBase
Call.
final
hashCode int
The hash code for this object.
no setterinherited
limit int
Limit.
final
offset int
Offset.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subChainId int
Sub Chain Id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited