PhoneGetGroupCallStreamRtmpUrl class

Phone Get Group Call Stream Rtmp Url.

Return Type: PhoneGroupCallStreamRtmpUrlBase. ID: 5af4c73a.

Inheritance

Constructors

PhoneGetGroupCallStreamRtmpUrl({required bool liveStory, required InputPeerBase peer, required bool revoke})
Phone Get Group Call Stream Rtmp Url constructor.
const
PhoneGetGroupCallStreamRtmpUrl.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
liveStory bool
live_story: bit 0 of flags.0?true
final
peer InputPeerBase
Peer.
final
revoke bool
Revoke.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited