PhoneGroupCallStars class

Phone Group Call Stars.

ID: 9d1dbd26.

Inheritance

Constructors

PhoneGroupCallStars({required int totalStars, required List<GroupCallDonorBase> topDonors, required List<ChatBase> chats, required List<UserBase> users})
Phone Group Call Stars constructor.
const
PhoneGroupCallStars.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

chats List<ChatBase>
Chats.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topDonors List<GroupCallDonorBase>
Top Donors.
final
totalStars int
Total Stars.
final
users List<UserBase>
Users.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited