PhoneRequestCall class
Phone Request Call.
Return Type: PhonePhoneCallBase.
ID: 42ff96ed.
Constructors
- PhoneRequestCall({required bool video, required InputUserBase userId, required int randomId, required Uint8List gAHash, required PhoneCallProtocolBase protocol})
-
Phone Request Call constructor.
const
- PhoneRequestCall.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- flags → int
-
Flags.
no setter
- gAHash → Uint8List
-
G A Hash.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- protocol → PhoneCallProtocolBase
-
Protocol.
final
- randomId → int
-
Random Id.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → InputUserBase
-
User Id.
final
- video → bool
-
video: bit 0 of flags.0?true
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited