PhoneSaveDefaultSendAs class

Phone Save Default Send As.

Return Type: bool. ID: 4167add1.

Inheritance

Constructors

PhoneSaveDefaultSendAs({required InputGroupCallBase call, required InputPeerBase sendAs})
Phone Save Default Send As constructor.
const
PhoneSaveDefaultSendAs.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

call InputGroupCallBase
Call.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendAs InputPeerBase
Send As.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited