PhoneSendConferenceCallBroadcast class

Phone Send Conference Call Broadcast.

Return Type: UpdatesBase. ID: c6701900.

Inheritance

Constructors

PhoneSendConferenceCallBroadcast({required InputGroupCallBase call, required Uint8List block})
Phone Send Conference Call Broadcast constructor.
const
PhoneSendConferenceCallBroadcast.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

block Uint8List
Block.
final
call InputGroupCallBase
Call.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited