Poll class
Poll.
ID: 966e2dbf.
- Inheritance
Constructors
-
Poll({required int id, required bool closed, required bool publicVoters, required bool multipleChoice, required bool quiz, required bool openAnswers, required bool revotingDisabled, required bool shuffleAnswers, required bool hideResultsUntilClose, required bool creator, required bool subscribersOnly, required TextWithEntitiesBase question, required List<
PollAnswerBase> answers, int? closePeriod, DateTime? closeDate, List<String> ? countriesIso2, required int hash}) -
Poll constructor.
const
- Poll.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
-
answers
→ List<
PollAnswerBase> -
Answers.
final
- closed → bool
-
closed: bit 0 of flags.0?true
final
- closeDate → DateTime?
-
Close Date.
final
- closePeriod → int?
-
Close Period.
final
-
countriesIso2
→ List<
String> ? -
Countries Iso2.
final
- creator → bool
-
creator: bit 10 of flags.10?true
final
- flags → int
-
Flags.
no setter
- hash → int
-
Hash.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hideResultsUntilClose → bool
-
hide_results_until_close: bit 9 of flags.9?true
final
- id → int
-
Id.
final
- multipleChoice → bool
-
multiple_choice: bit 2 of flags.2?true
final
- openAnswers → bool
-
open_answers: bit 6 of flags.6?true
final
- publicVoters → bool
-
public_voters: bit 1 of flags.1?true
final
- question → TextWithEntitiesBase
-
Question.
final
- quiz → bool
-
quiz: bit 3 of flags.3?true
final
- revotingDisabled → bool
-
revoting_disabled: bit 7 of flags.7?true
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shuffleAnswers → bool
-
shuffle_answers: bit 8 of flags.8?true
final
- subscribersOnly → bool
-
subscribers_only: bit 11 of flags.11?true
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited