PollResults class

Poll Results.

ID: ba7bb15e.

Inheritance

Constructors

PollResults({required bool min, required bool hasUnreadVotes, required bool canViewStats, List<PollAnswerVotersBase>? results, int? totalVoters, List<PeerBase>? recentVoters, String? solution, List<MessageEntityBase>? solutionEntities, MessageMediaBase? solutionMedia})
Poll Results constructor.
const
PollResults.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

canViewStats bool
can_view_stats: bit 7 of flags.7?true
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
hasUnreadVotes bool
has_unread_votes: bit 6 of flags.6?true
final
min bool
min: bit 0 of flags.0?true
final
recentVoters List<PeerBase>?
Recent Voters.
final
results List<PollAnswerVotersBase>?
Results.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
solution String?
Solution.
final
solutionEntities List<MessageEntityBase>?
Solution Entities.
final
solutionMedia MessageMediaBase?
Solution Media.
final
totalVoters int?
Total Voters.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited