PrepaidStarsGiveaway class

Prepaid Stars Giveaway.

ID: 9a9d77e0.

Inheritance

Constructors

PrepaidStarsGiveaway({required int id, required int stars, required int quantity, required int boosts, required DateTime date})
Prepaid Stars Giveaway constructor.
const
PrepaidStarsGiveaway.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

boosts int
Boosts.
final
date DateTime
Date.
final
hashCode int
The hash code for this object.
no setterinherited
id int
Id.
final
quantity int
Quantity.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stars int
Stars.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited