QuickReply class
Quick Reply.
ID: 0697102b.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- QuickReplyBase
- QuickReply
Constructors
- QuickReply({required int shortcutId, required String shortcut, required int topMessage, required int count})
-
Quick Reply constructor.
const
- QuickReply.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- count → int
-
Count.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortcut → String
-
Shortcut.
final
- shortcutId → int
-
Shortcut Id.
final
- topMessage → int
-
Top Message.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited