ReactionsNotifySettings class
Reactions Notify Settings.
ID: 71e4ea58.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- ReactionsNotifySettingsBase
- ReactionsNotifySettings
Constructors
- ReactionsNotifySettings({ReactionNotificationsFromBase? messagesNotifyFrom, ReactionNotificationsFromBase? storiesNotifyFrom, ReactionNotificationsFromBase? pollVotesNotifyFrom, required NotificationSoundBase sound, required bool showPreviews})
-
Reactions Notify Settings constructor.
const
- ReactionsNotifySettings.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- messagesNotifyFrom → ReactionNotificationsFromBase?
-
Messages Notify From.
final
- pollVotesNotifyFrom → ReactionNotificationsFromBase?
-
Poll Votes Notify From.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showPreviews → bool
-
Show Previews.
final
- sound → NotificationSoundBase
-
Sound.
final
- storiesNotifyFrom → ReactionNotificationsFromBase?
-
Stories Notify From.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited