RequestPeerTypeCreateBot class
Request Peer Type Create Bot.
ID: 3e81e078.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- RequestPeerTypeBase
- RequestPeerTypeCreateBot
Constructors
- RequestPeerTypeCreateBot({required bool botManaged, String? suggestedName, String? suggestedUsername})
-
Request Peer Type Create Bot constructor.
const
- RequestPeerTypeCreateBot.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- botManaged → bool
-
bot_managed: bit 0 of flags.0?true
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suggestedName → String?
-
Suggested Name.
final
- suggestedUsername → String?
-
Suggested Username.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited