RequestedPeerChannel class
Requested Peer Channel.
ID: 8ba403e4.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- RequestedPeerBase
- RequestedPeerChannel
Constructors
- RequestedPeerChannel({required int channelId, String? title, String? username, PhotoBase? photo})
-
Requested Peer Channel constructor.
const
- RequestedPeerChannel.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- channelId → int
-
Channel Id.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- photo → PhotoBase?
-
Photo.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
Title.
final
- username → String?
-
Username.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited