RichMessage class
Rich Message.
ID: baf39d8b.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- RichMessageBase
- RichMessage
Constructors
-
RichMessage({required bool rtl, required bool part, required List<
PageBlockBase> blocks, required List<PhotoBase> photos, required List<DocumentBase> documents}) -
Rich Message constructor.
const
- RichMessage.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
-
blocks
→ List<
PageBlockBase> -
Blocks.
final
-
documents
→ List<
DocumentBase> -
Documents.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- part → bool
-
part: bit 1 of flags.1?true
final
-
photos
→ List<
PhotoBase> -
Photos.
final
- rtl → bool
-
rtl: bit 0 of flags.0?true
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited