RichTextBase class abstract
Predicate Rich Text.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- RichTextBase
- Implementers
- TextAnchor
- TextAutoEmail
- TextAutoPhone
- TextAutoUrl
- TextBankCard
- TextBold
- TextBotCommand
- TextCashtag
- TextConcat
- TextCustomEmoji
- TextDate
- TextDiff
- TextEmail
- TextEmpty
- TextFixed
- TextHashtag
- TextImage
- TextItalic
- TextMarked
- TextMath
- TextMention
- TextMentionName
- TextPhone
- TextPlain
- TextSpoiler
- TextStrike
- TextSubscript
- TextSuperscript
- TextUnderline
- TextUrl
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize to MTProto binary.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited