SavedReactionTag class

Saved Reaction Tag.

ID: cb6ff828.

Inheritance

Constructors

SavedReactionTag({required ReactionBase reaction, String? title, required int count})
Saved Reaction Tag constructor.
const
SavedReactionTag.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

count int
Count.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
reaction ReactionBase
Reaction.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
Title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited