SecureValueHash class

Secure Value Hash.

ID: ed1ecdb0.

Inheritance

Constructors

SecureValueHash({required SecureValueTypeBase type, required Uint8List hash})
Secure Value Hash constructor.
const
SecureValueHash.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hash Uint8List
Hash.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type SecureValueTypeBase
Type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited