SmsJob class

Sms Job.

ID: e6a1eeb8.

Inheritance

Constructors

SmsJob({required String jobId, required String phoneNumber, required String text})
Sms Job constructor.
const
SmsJob.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
jobId String
Job Id.
final
phoneNumber String
Phone Number.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited