SponsoredMessage class

Sponsored Message.

ID: 7dbf8673.

Inheritance

Constructors

SponsoredMessage({required bool recommended, required bool canReport, required Uint8List randomId, required String url, required String title, required String message, List<MessageEntityBase>? entities, PhotoBase? photo, MessageMediaBase? media, PeerColorBase? color, required String buttonText, String? sponsorInfo, String? additionalInfo, int? minDisplayDuration, int? maxDisplayDuration})
Sponsored Message constructor.
const
SponsoredMessage.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

additionalInfo String?
Additional Info.
final
buttonText String
Button Text.
final
canReport bool
can_report: bit 12 of flags.12?true
final
color PeerColorBase?
Color.
final
entities List<MessageEntityBase>?
Entities.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
maxDisplayDuration int?
Max Display Duration.
final
media MessageMediaBase?
Media.
final
message String
Message.
final
minDisplayDuration int?
Min Display Duration.
final
photo PhotoBase?
Photo.
final
randomId Uint8List
Random Id.
final
recommended: bit 5 of flags.5?true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sponsorInfo String?
Sponsor Info.
final
title String
Title.
final
url String
Url.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited