StarGift class
Star Gift.
ID: 313a9547.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- StarGiftBase
- StarGift
Constructors
- StarGift({required bool limited, required bool soldOut, required bool birthday, required bool requirePremium, required bool limitedPerUser, required bool peerColorAvailable, required bool auction, required int id, required DocumentBase sticker, required int stars, int? availabilityRemains, int? availabilityTotal, int? availabilityResale, required int convertStars, DateTime? firstSaleDate, DateTime? lastSaleDate, int? upgradeStars, int? resellMinStars, String? title, PeerBase? releasedBy, int? perUserTotal, int? perUserRemains, DateTime? lockedUntilDate, String? auctionSlug, int? giftsPerRound, DateTime? auctionStartDate, int? upgradeVariants, StarGiftBackgroundBase? background})
-
Star Gift constructor.
const
- StarGift.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- auction → bool
-
auction: bit 11 of flags.11?true
final
- auctionSlug → String?
-
Auction Slug.
final
- auctionStartDate → DateTime?
-
Auction Start Date.
final
- availabilityRemains → int?
-
Availability Remains.
final
- availabilityResale → int?
-
Availability Resale.
final
- availabilityTotal → int?
-
Availability Total.
final
- background → StarGiftBackgroundBase?
-
Background.
final
- birthday → bool
-
birthday: bit 2 of flags.2?true
final
- convertStars → int
-
Convert Stars.
final
- firstSaleDate → DateTime?
-
First Sale Date.
final
- flags → int
-
Flags.
no setter
- giftsPerRound → int?
-
Gifts Per Round.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Id.
final
- lastSaleDate → DateTime?
-
Last Sale Date.
final
- limited → bool
-
limited: bit 0 of flags.0?true
final
- limitedPerUser → bool
-
limited_per_user: bit 8 of flags.8?true
final
- lockedUntilDate → DateTime?
-
Locked Until Date.
final
- peerColorAvailable → bool
-
peer_color_available: bit 10 of flags.10?true
final
- perUserRemains → int?
-
Per User Remains.
final
- perUserTotal → int?
-
Per User Total.
final
- releasedBy → PeerBase?
-
Released By.
final
- requirePremium → bool
-
require_premium: bit 7 of flags.7?true
final
- resellMinStars → int?
-
Resell Min Stars.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- soldOut → bool
-
sold_out: bit 1 of flags.1?true
final
- stars → int
-
Stars.
final
- sticker → DocumentBase
-
Sticker.
final
- title → String?
-
Title.
final
- upgradeStars → int?
-
Upgrade Stars.
final
- upgradeVariants → int?
-
Upgrade Variants.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited