StarGiftAttributeBackdrop class
Star Gift Attribute Backdrop.
ID: 9f2504e4.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- StarGiftAttributeBase
- StarGiftAttributeBackdrop
Constructors
- StarGiftAttributeBackdrop({required String name, required int backdropId, required int centerColor, required int edgeColor, required int patternColor, required int textColor, required StarGiftAttributeRarityBase rarity})
-
Star Gift Attribute Backdrop constructor.
const
- StarGiftAttributeBackdrop.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- backdropId → int
-
Backdrop Id.
final
- centerColor → int
-
Center Color.
final
- edgeColor → int
-
Edge Color.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Name.
final
- patternColor → int
-
Pattern Color.
final
- rarity → StarGiftAttributeRarityBase
-
Rarity.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textColor → int
-
Text Color.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited