StarGiftAttributeCounter class

Star Gift Attribute Counter.

ID: 2eb1b658.

Inheritance

Constructors

StarGiftAttributeCounter({required StarGiftAttributeIdBase attribute, required int count})
Star Gift Attribute Counter constructor.
const
StarGiftAttributeCounter.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

attribute StarGiftAttributeIdBase
Attribute.
final
count int
Count.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited