StarGiftAttributeModel class

Star Gift Attribute Model.

ID: 565251e2.

Inheritance

Constructors

StarGiftAttributeModel({required bool crafted, required String name, required DocumentBase document, required StarGiftAttributeRarityBase rarity})
Star Gift Attribute Model constructor.
const
StarGiftAttributeModel.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

crafted bool
crafted: bit 0 of flags.0?true
final
document DocumentBase
Document.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
Name.
final
rarity StarGiftAttributeRarityBase
Rarity.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited