StarGiftAttributeOriginalDetails class
Star Gift Attribute Original Details.
ID: e0bff26c.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- StarGiftAttributeBase
- StarGiftAttributeOriginalDetails
Constructors
- StarGiftAttributeOriginalDetails({PeerBase? senderId, required PeerBase recipientId, required DateTime date, TextWithEntitiesBase? message})
-
Star Gift Attribute Original Details constructor.
const
- StarGiftAttributeOriginalDetails.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- date → DateTime
-
Date.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → TextWithEntitiesBase?
-
Message.
final
- recipientId → PeerBase
-
Recipient Id.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderId → PeerBase?
-
Sender Id.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited