StarGiftAuctionAcquiredGift class

Star Gift Auction Acquired Gift.

ID: 42b00348.

Inheritance

Constructors

StarGiftAuctionAcquiredGift({required bool nameHidden, required PeerBase peer, required DateTime date, required int bidAmount, required int round, required int pos, TextWithEntitiesBase? message, int? giftNum})
Star Gift Auction Acquired Gift constructor.
const
StarGiftAuctionAcquiredGift.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

bidAmount int
Bid Amount.
final
date DateTime
Date.
final
flags int
Flags.
no setter
giftNum int?
Gift Num.
final
hashCode int
The hash code for this object.
no setterinherited
message TextWithEntitiesBase?
Message.
final
nameHidden bool
name_hidden: bit 0 of flags.0?true
final
peer PeerBase
Peer.
final
pos int
Pos.
final
round int
Round.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited