StarGiftAuctionRound class

Star Gift Auction Round.

ID: 3aae0528.

Inheritance

Constructors

StarGiftAuctionRound({required int num, required int duration})
Star Gift Auction Round constructor.
const
StarGiftAuctionRound.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

duration int
Duration.
final
hashCode int
The hash code for this object.
no setterinherited
num int
Num.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited