StarGiftAuctionStateFinished class

Star Gift Auction State Finished.

ID: 972dabbf.

Inheritance

Constructors

StarGiftAuctionStateFinished({required DateTime startDate, required DateTime endDate, required int averagePrice, int? listedCount, int? fragmentListedCount, String? fragmentListedUrl})
Star Gift Auction State Finished constructor.
const
StarGiftAuctionStateFinished.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

averagePrice int
Average Price.
final
endDate DateTime
End Date.
final
flags int
Flags.
no setter
fragmentListedCount int?
Fragment Listed Count.
final
fragmentListedUrl String?
Fragment Listed Url.
final
hashCode int
The hash code for this object.
no setterinherited
listedCount int?
Listed Count.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate DateTime
Start Date.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited