StarGiftCollection class

Star Gift Collection.

ID: 9d6b13b0.

Inheritance

Constructors

StarGiftCollection({required int collectionId, required String title, DocumentBase? icon, required int giftsCount, required int hash})
Star Gift Collection constructor.
const
StarGiftCollection.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

collectionId int
Collection Id.
final
flags int
Flags.
no setter
giftsCount int
Gifts Count.
final
hash int
Hash.
final
hashCode int
The hash code for this object.
no setterinherited
icon DocumentBase?
Icon.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
Title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited