StarGiftUnique class
Star Gift Unique.
ID: 85f0a9cd.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- StarGiftBase
- StarGiftUnique
Constructors
-
StarGiftUnique({required bool requirePremium, required bool resaleTonOnly, required bool themeAvailable, required bool burned, required bool crafted, required int id, required int giftId, required String title, required String slug, required int num, PeerBase? ownerId, String? ownerName, String? ownerAddress, required List<
StarGiftAttributeBase> attributes, required int availabilityIssued, required int availabilityTotal, String? giftAddress, List<StarsAmountBase> ? resellAmount, PeerBase? releasedBy, int? valueAmount, String? valueCurrency, int? valueUsdAmount, PeerBase? themePeer, PeerColorBase? peerColor, PeerBase? hostId, int? offerMinStars, int? craftChancePermille}) -
Star Gift Unique constructor.
const
- StarGiftUnique.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
-
attributes
→ List<
StarGiftAttributeBase> -
Attributes.
final
- availabilityIssued → int
-
Availability Issued.
final
- availabilityTotal → int
-
Availability Total.
final
- burned → bool
-
burned: bit 14 of flags.14?true
final
- craftChancePermille → int?
-
Craft Chance Permille.
final
- crafted → bool
-
crafted: bit 15 of flags.15?true
final
- flags → int
-
Flags.
no setter
- giftAddress → String?
-
Gift Address.
final
- giftId → int
-
Gift Id.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hostId → PeerBase?
-
Host Id.
final
- id → int
-
Id.
final
- num → int
-
Num.
final
- offerMinStars → int?
-
Offer Min Stars.
final
- ownerAddress → String?
-
Owner Address.
final
- ownerId → PeerBase?
-
Owner Id.
final
- ownerName → String?
-
Owner Name.
final
- peerColor → PeerColorBase?
-
Peer Color.
final
- releasedBy → PeerBase?
-
Released By.
final
- requirePremium → bool
-
require_premium: bit 6 of flags.6?true
final
- resaleTonOnly → bool
-
resale_ton_only: bit 7 of flags.7?true
final
-
resellAmount
→ List<
StarsAmountBase> ? -
Resell Amount.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slug → String
-
Slug.
final
- themeAvailable → bool
-
theme_available: bit 9 of flags.9?true
final
- themePeer → PeerBase?
-
Theme Peer.
final
- title → String
-
Title.
final
- valueAmount → int?
-
Value Amount.
final
- valueCurrency → String?
-
Value Currency.
final
- valueUsdAmount → int?
-
Value Usd Amount.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited