StarGiftUpgradePrice class
Star Gift Upgrade Price.
ID: 99ea331d.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- StarGiftUpgradePriceBase
- StarGiftUpgradePrice
Constructors
- StarGiftUpgradePrice({required DateTime date, required int upgradeStars})
-
Star Gift Upgrade Price constructor.
const
- StarGiftUpgradePrice.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- date → DateTime
-
Date.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- upgradeStars → int
-
Upgrade Stars.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited