StarsGiftOption class

Stars Gift Option.

ID: 5e0589f1.

Inheritance

Constructors

StarsGiftOption({required bool extended, required int stars, String? storeProduct, required String currency, required int amount})
Stars Gift Option constructor.
const
StarsGiftOption.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

amount int
Amount.
final
currency String
Currency.
final
extended bool
extended: bit 1 of flags.1?true
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stars int
Stars.
final
storeProduct String?
Store Product.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited