StarsGiveawayOption class
Stars Giveaway Option.
ID: 94ce852a.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- StarsGiveawayOptionBase
- StarsGiveawayOption
Constructors
-
StarsGiveawayOption({required bool extended, required bool ddefault, required int stars, required int yearlyBoosts, String? storeProduct, required String currency, required int amount, required List<
StarsGiveawayWinnersOptionBase> winners}) -
Stars Giveaway Option constructor.
const
- StarsGiveawayOption.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- amount → int
-
Amount.
final
- currency → String
-
Currency.
final
- ddefault → bool
-
default: bit 1 of flags.1?true
final
- extended → bool
-
extended: bit 0 of flags.0?true
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stars → int
-
Stars.
final
- storeProduct → String?
-
Store Product.
final
-
winners
→ List<
StarsGiveawayWinnersOptionBase> -
Winners.
final
- yearlyBoosts → int
-
Yearly Boosts.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited