StarsGiveawayWinnersOption class

Stars Giveaway Winners Option.

ID: 54236209.

Inheritance

Constructors

StarsGiveawayWinnersOption({required bool ddefault, required int users, required int perUserStars})
Stars Giveaway Winners Option constructor.
const
StarsGiveawayWinnersOption.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

ddefault bool
default: bit 0 of flags.0?true
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
perUserStars int
Per User Stars.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
users int
Users.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited