StarsRevenueStatus class

Stars Revenue Status.

ID: febe5491.

Inheritance

Constructors

StarsRevenueStatus({required bool withdrawalEnabled, required StarsAmountBase currentBalance, required StarsAmountBase availableBalance, required StarsAmountBase overallRevenue, int? nextWithdrawalAt})
Stars Revenue Status constructor.
const
StarsRevenueStatus.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

availableBalance StarsAmountBase
Available Balance.
final
currentBalance StarsAmountBase
Current Balance.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
nextWithdrawalAt int?
Next Withdrawal At.
final
overallRevenue StarsAmountBase
Overall Revenue.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
withdrawalEnabled bool
withdrawal_enabled: bit 0 of flags.0?true
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited