StarsSubscriptionPricing class

Stars Subscription Pricing.

ID: 05416d58.

Inheritance

Constructors

StarsSubscriptionPricing({required int period, required int amount})
Stars Subscription Pricing constructor.
const
StarsSubscriptionPricing.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

amount int
Amount.
final
hashCode int
The hash code for this object.
no setterinherited
period int
Period.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited