StickersReplaceSticker class
Stickers Replace Sticker.
Return Type: MessagesStickerSetBase.
ID: 4696459a.
Constructors
- StickersReplaceSticker({required InputDocumentBase sticker, required InputStickerSetItemBase newSticker})
-
Stickers Replace Sticker constructor.
const
- StickersReplaceSticker.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- newSticker → InputStickerSetItemBase
-
New Sticker.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sticker → InputDocumentBase
-
Sticker.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited