StoriesAlbums class
Stories Albums.
ID: c3987a3a.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- StoriesAlbumsBase
- StoriesAlbums
Constructors
-
StoriesAlbums({required int hash, required List<
StoryAlbumBase> albums}) -
Stories Albums constructor.
const
- StoriesAlbums.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
-
albums
→ List<
StoryAlbumBase> -
Albums.
final
- hash → int
-
Hash.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited