StoriesCanSendStoryCount class
Stories Can Send Story Count.
ID: c387c04e.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- StoriesCanSendStoryCountBase
- StoriesCanSendStoryCount
Constructors
- StoriesCanSendStoryCount({required int countRemains})
-
Stories Can Send Story Count constructor.
const
- StoriesCanSendStoryCount.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- countRemains → int
-
Count Remains.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited