StoriesGetAlbumStories class

Stories Get Album Stories.

Return Type: StoriesStoriesBase. ID: ac806d61.

Inheritance

Constructors

StoriesGetAlbumStories({required InputPeerBase peer, required int albumId, required int offset, required int limit})
Stories Get Album Stories constructor.
const
StoriesGetAlbumStories.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

albumId int
Album Id.
final
hashCode int
The hash code for this object.
no setterinherited
limit int
Limit.
final
offset int
Offset.
final
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited