SuggestedPost class

Suggested Post.

ID: 0e8e37e5.

Inheritance

Constructors

SuggestedPost({required bool accepted, required bool rejected, StarsAmountBase? price, DateTime? scheduleDate})
Suggested Post constructor.
const
SuggestedPost.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

accepted bool
accepted: bit 1 of flags.1?true
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
price StarsAmountBase?
Price.
final
rejected bool
rejected: bit 2 of flags.2?true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduleDate DateTime?
Schedule Date.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited