TextCustomEmoji class

Text Custom Emoji.

ID: a26156c0.

Inheritance

Constructors

TextCustomEmoji({required int documentId, required String alt})
Text Custom Emoji constructor.
const
TextCustomEmoji.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

alt String
Alt.
final
documentId int
Document Id.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited