TextDate class

Text Date.

ID: a5b45e2b.

Inheritance

Constructors

TextDate({required bool relative, required bool shortTime, required bool longTime, required bool shortDate, required bool longDate, required bool dayOfWeek, required RichTextBase text, required DateTime date})
Text Date constructor.
const
TextDate.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

date DateTime
Date.
final
dayOfWeek bool
day_of_week: bit 5 of flags.5?true
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
longDate bool
long_date: bit 4 of flags.4?true
final
longTime bool
long_time: bit 2 of flags.2?true
final
relative bool
relative: bit 0 of flags.0?true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortDate bool
short_date: bit 3 of flags.3?true
final
shortTime bool
short_time: bit 1 of flags.1?true
final
text RichTextBase
Text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited