TextDiff class

Text Diff.

ID: 9686cb50.

Inheritance

Constructors

TextDiff({required RichTextBase text, required RichTextBase oldText})
Text Diff constructor.
const
TextDiff.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
oldText RichTextBase
Old Text.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text RichTextBase
Text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited