TextWithEntities class

Text With Entities.

ID: 751f3146.

Inheritance

Constructors

TextWithEntities({required String text, required List<MessageEntityBase> entities})
Text With Entities constructor.
const
TextWithEntities.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

entities List<MessageEntityBase>
Entities.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited