Timezone class
Timezone.
ID: ff9289f5.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- TimezoneBase
- Timezone
Constructors
- Timezone({required String id, required String name, required int utcOffset})
-
Timezone constructor.
const
- Timezone.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited