TodoCompletion class

Todo Completion.

ID: 221bb5e4.

Inheritance

Constructors

TodoCompletion({required int id, required PeerBase completedBy, required DateTime date})
Todo Completion constructor.
const
TodoCompletion.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

completedBy PeerBase
Completed By.
final
date DateTime
Date.
final
hashCode int
The hash code for this object.
no setterinherited
id int
Id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited