TodoItem class
Todo Item.
ID: cba9a52f.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- TodoItemBase
- TodoItem
Constructors
- TodoItem({required int id, required TextWithEntitiesBase title})
-
Todo Item constructor.
const
- TodoItem.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Id.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → TextWithEntitiesBase
-
Title.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited