UpdateBase class abstract
Predicate Update.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- UpdateBase
- Implementers
- UpdateAiComposeTones
- UpdateAttachMenuBots
- UpdateAutoSaveSettings
- UpdateBotBusinessConnect
- UpdateBotCallbackQuery
- UpdateBotChatBoost
- UpdateBotChatInviteRequester
- UpdateBotCommands
- UpdateBotDeleteBusinessMessage
- UpdateBotEditBusinessMessage
- UpdateBotGuestChatQuery
- UpdateBotInlineQuery
- UpdateBotInlineSend
- UpdateBotMenuButton
- UpdateBotMessageReaction
- UpdateBotMessageReactions
- UpdateBotNewBusinessMessage
- UpdateBotPrecheckoutQuery
- UpdateBotPurchasedPaidMedia
- UpdateBotShippingQuery
- UpdateBotStarsSubscription
- UpdateBotStopped
- UpdateBotWebhookJSON
- UpdateBotWebhookJSONQuery
- UpdateBusinessBotCallbackQuery
- UpdateChannel
- UpdateChannelAvailableMessages
- UpdateChannelMessageForwards
- UpdateChannelMessageViews
- UpdateChannelParticipant
- UpdateChannelReadMessagesContents
- UpdateChannelTooLong
- UpdateChannelUserTyping
- UpdateChannelViewForumAsMessages
- UpdateChannelWebPage
- UpdateChat
- UpdateChatDefaultBannedRights
- UpdateChatParticipant
- UpdateChatParticipantAdd
- UpdateChatParticipantAdmin
- UpdateChatParticipantDelete
- UpdateChatParticipantRank
- UpdateChatParticipants
- UpdateChatUserTyping
- UpdateConfig
- UpdateContactsReset
- UpdateDcOptions
- UpdateDeleteChannelMessages
- UpdateDeleteEphemeralMessages
- UpdateDeleteGroupCallMessages
- UpdateDeleteMessages
- UpdateDeleteQuickReply
- UpdateDeleteQuickReplyMessages
- UpdateDeleteScheduledMessages
- UpdateDialogFilter
- UpdateDialogFilterOrder
- UpdateDialogFilters
- UpdateDialogPinned
- UpdateDialogUnreadMark
- UpdateDraftMessage
- UpdateEditChannelMessage
- UpdateEditEphemeralMessage
- UpdateEditMessage
- UpdateEmojiGameInfo
- UpdateEncryptedChatTyping
- UpdateEncryptedMessagesRead
- UpdateEncryption
- UpdateFavedStickers
- UpdateFolderPeers
- UpdateGeoLiveViewed
- UpdateGroupCall
- UpdateGroupCallChainBlocks
- UpdateGroupCallConnection
- UpdateGroupCallEncryptedMessage
- UpdateGroupCallMessage
- UpdateGroupCallParticipants
- UpdateInlineBotCallbackQuery
- UpdateJoinChatWebViewDecision
- UpdateLangPack
- UpdateLangPackTooLong
- UpdateLoginToken
- UpdateManagedBot
- UpdateMessageExtendedMedia
- UpdateMessageID
- UpdateMessagePoll
- UpdateMessagePollVote
- UpdateMessageReactions
- UpdateMonoForumNoPaidException
- UpdateMoveStickerSetToTop
- UpdateNewAuthorization
- UpdateNewBotConnection
- UpdateNewChannelMessage
- UpdateNewEncryptedMessage
- UpdateNewEphemeralMessage
- UpdateNewMessage
- UpdateNewQuickReply
- UpdateNewScheduledMessage
- UpdateNewStickerSet
- UpdateNewStoryReaction
- UpdateNotifySettings
- UpdatePaidReactionPrivacy
- UpdatePeerBlocked
- UpdatePeerHistoryTTL
- UpdatePeerLocated
- UpdatePeerSettings
- UpdatePeerWallpaper
- UpdatePendingJoinRequests
- UpdatePhoneCall
- UpdatePhoneCallSignalingData
- UpdatePinnedChannelMessages
- UpdatePinnedDialogs
- UpdatePinnedForumTopic
- UpdatePinnedForumTopics
- UpdatePinnedMessages
- UpdatePinnedSavedDialogs
- UpdatePrivacy
- UpdatePtsChanged
- UpdateQuickReplies
- UpdateQuickReplyMessage
- UpdateReadChannelDiscussionInbox
- UpdateReadChannelDiscussionOutbox
- UpdateReadChannelInbox
- UpdateReadChannelOutbox
- UpdateReadFeaturedEmojiStickers
- UpdateReadFeaturedStickers
- UpdateReadHistoryInbox
- UpdateReadHistoryOutbox
- UpdateReadMessagesContents
- UpdateReadMonoForumInbox
- UpdateReadMonoForumOutbox
- UpdateReadStories
- UpdateRecentEmojiStatuses
- UpdateRecentReactions
- UpdateRecentStickers
- UpdateSavedDialogPinned
- UpdateSavedGifs
- UpdateSavedReactionTags
- UpdateSavedRingtones
- UpdateSentPhoneCode
- UpdateSentStoryReaction
- UpdateServiceNotification
- UpdateSmsJob
- UpdateStarGiftAuctionState
- UpdateStarGiftAuctionUserState
- UpdateStarGiftCraftFail
- UpdateStarsBalance
- UpdateStarsRevenueStatus
- UpdateStickerSets
- UpdateStickerSetsOrder
- UpdateStoriesStealthMode
- UpdateStory
- UpdateStoryID
- UpdateTheme
- UpdateTranscribedAudio
- UpdateUser
- UpdateUserEmojiStatus
- UpdateUserName
- UpdateUserPhone
- UpdateUserStatus
- UpdateUserTyping
- UpdateWebBrowserException
- UpdateWebBrowserSettings
- UpdateWebPage
- UpdateWebViewResultSent
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize to MTProto binary.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited