UpdateBotBusinessConnect class
Update Bot Business Connect.
ID: 8ae5c97a.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- UpdateBase
- UpdateBotBusinessConnect
Constructors
- UpdateBotBusinessConnect({required BotBusinessConnectionBase connection, required int qts})
-
Update Bot Business Connect constructor.
const
- UpdateBotBusinessConnect.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- connection → BotBusinessConnectionBase
-
Connection.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qts → int
-
Qts.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited