UpdateBotGuestChatQuery class

Update Bot Guest Chat Query.

ID: cdd4093d.

Inheritance

Constructors

UpdateBotGuestChatQuery({required int queryId, required MessageBase message, List<MessageBase>? referenceMessages, required int qts})
Update Bot Guest Chat Query constructor.
const
UpdateBotGuestChatQuery.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
message MessageBase
Message.
final
qts int
Qts.
final
queryId int
Query Id.
final
referenceMessages List<MessageBase>?
Reference Messages.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited