UpdateBotStarsSubscription class
Update Bot Stars Subscription.
ID: 6c0d8e23.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- UpdateBase
- UpdateBotStarsSubscription
Constructors
- UpdateBotStarsSubscription({required bool canceled, required bool paymentFailed, required bool restored, required int userId, required Uint8List payload, required int qts})
-
Update Bot Stars Subscription constructor.
const
- UpdateBotStarsSubscription.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- canceled → bool
-
canceled: bit 0 of flags.0?true
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- payload → Uint8List
-
Payload.
final
- paymentFailed → bool
-
payment_failed: bit 1 of flags.1?true
final
- qts → int
-
Qts.
final
- restored → bool
-
restored: bit 2 of flags.2?true
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
User Id.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited