UpdateBusinessBotCallbackQuery class

Update Business Bot Callback Query.

ID: 1ea2fda7.

Inheritance

Constructors

UpdateBusinessBotCallbackQuery({required int queryId, required int userId, required String connectionId, required MessageBase message, MessageBase? replyToMessage, required int chatInstance, Uint8List? data})
Update Business Bot Callback Query constructor.
const
UpdateBusinessBotCallbackQuery.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

chatInstance int
Chat Instance.
final
connectionId String
Connection Id.
final
data Uint8List?
Data.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
message MessageBase
Message.
final
queryId int
Query Id.
final
replyToMessage MessageBase?
Reply To Message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
User Id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited