UpdateChannelReadMessagesContents class
Update Channel Read Messages Contents.
ID: 25f324f7.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- UpdateBase
- UpdateChannelReadMessagesContents
Constructors
-
UpdateChannelReadMessagesContents({required int channelId, int? topMsgId, PeerBase? savedPeerId, required List<
int> messages}) -
Update Channel Read Messages Contents constructor.
const
- UpdateChannelReadMessagesContents.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- channelId → int
-
Channel Id.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messages
→ List<
int> -
Messages.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- savedPeerId → PeerBase?
-
Saved Peer Id.
final
- topMsgId → int?
-
Top Msg Id.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited