UpdateChatParticipantRank class

Update Chat Participant Rank.

ID: bd8367b9.

Inheritance

Constructors

UpdateChatParticipantRank({required int chatId, required int userId, required String rank, required int version})
Update Chat Participant Rank constructor.
const
UpdateChatParticipantRank.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

chatId int
Chat Id.
final
hashCode int
The hash code for this object.
no setterinherited
rank String
Rank.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
User Id.
final
version int
Version.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited