UpdateDeleteGroupCallMessages class
Update Delete Group Call Messages.
ID: 3e85e92c.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- UpdateBase
- UpdateDeleteGroupCallMessages
Constructors
-
UpdateDeleteGroupCallMessages({required InputGroupCallBase call, required List<
int> messages}) -
Update Delete Group Call Messages constructor.
const
- UpdateDeleteGroupCallMessages.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- call → InputGroupCallBase
-
Call.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messages
→ List<
int> -
Messages.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited