UpdateDeleteQuickReplyMessages class
Update Delete Quick Reply Messages.
ID: 566fe7cd.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- UpdateBase
- UpdateDeleteQuickReplyMessages
Constructors
-
UpdateDeleteQuickReplyMessages({required int shortcutId, required List<
int> messages}) -
Update Delete Quick Reply Messages constructor.
const
- UpdateDeleteQuickReplyMessages.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messages
→ List<
int> -
Messages.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortcutId → int
-
Shortcut Id.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited