UpdateGroupCallChainBlocks class
Update Group Call Chain Blocks.
ID: a477288f.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- UpdateBase
- UpdateGroupCallChainBlocks
Constructors
-
UpdateGroupCallChainBlocks({required InputGroupCallBase call, required int subChainId, required List<
Uint8List> blocks, required int nextOffset}) -
Update Group Call Chain Blocks constructor.
const
- UpdateGroupCallChainBlocks.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
-
blocks
→ List<
Uint8List> -
Blocks.
final
- call → InputGroupCallBase
-
Call.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextOffset → int
-
Next Offset.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subChainId → int
-
Sub Chain Id.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited