UpdateGroupCallEncryptedMessage class

Update Group Call Encrypted Message.

ID: c957a766.

Inheritance

Constructors

UpdateGroupCallEncryptedMessage({required InputGroupCallBase call, required PeerBase fromId, required Uint8List encryptedMessage})
Update Group Call Encrypted Message constructor.
const
UpdateGroupCallEncryptedMessage.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

call InputGroupCallBase
Call.
final
encryptedMessage Uint8List
Encrypted Message.
final
fromId PeerBase
From Id.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited