UpdateGroupCallMessage class

Update Group Call Message.

ID: d8326f0d.

Inheritance

Constructors

UpdateGroupCallMessage({required InputGroupCallBase call, required GroupCallMessageBase message})
Update Group Call Message constructor.
const
UpdateGroupCallMessage.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

call InputGroupCallBase
Call.
final
hashCode int
The hash code for this object.
no setterinherited
message GroupCallMessageBase
Message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited