UpdateJoinChatWebViewDecision class

Update Join Chat Web View Decision.

ID: bdac7e70.

Inheritance

Constructors

UpdateJoinChatWebViewDecision({required PeerBase peer, required int queryId, required JoinChatBotResultBase result})
Update Join Chat Web View Decision constructor.
const
UpdateJoinChatWebViewDecision.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
peer PeerBase
Peer.
final
queryId int
Query Id.
final
result JoinChatBotResultBase
Result.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited