UpdateManagedBot class

Update Managed Bot.

ID: 4880ed9a.

Inheritance

Constructors

UpdateManagedBot({required int userId, required int botId, required int qts})
Update Managed Bot constructor.
const
UpdateManagedBot.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

botId int
Bot Id.
final
hashCode int
The hash code for this object.
no setterinherited
qts int
Qts.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
User Id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited