UpdateMessagePoll class
Update Message Poll.
ID: d64c522b.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- UpdateBase
- UpdateMessagePoll
Constructors
- UpdateMessagePoll({PeerBase? peer, int? msgId, int? topMsgId, required int pollId, PollBase? poll, required PollResultsBase results})
-
Update Message Poll constructor.
const
- UpdateMessagePoll.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- msgId → int?
-
Msg Id.
final
- peer → PeerBase?
-
Peer.
final
- poll → PollBase?
-
Poll.
final
- pollId → int
-
Poll Id.
final
- results → PollResultsBase
-
Results.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topMsgId → int?
-
Top Msg Id.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited