UpdateMessagePollVote class
Update Message Poll Vote.
ID: 7699f014.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- UpdateBase
- UpdateMessagePollVote
Constructors
-
UpdateMessagePollVote({required int pollId, required PeerBase peer, required List<
Uint8List> options, required List<int> positions, required int qts}) -
Update Message Poll Vote constructor.
const
- UpdateMessagePollVote.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
options
→ List<
Uint8List> -
Options.
final
- peer → PeerBase
-
Peer.
final
- pollId → int
-
Poll Id.
final
-
positions
→ List<
int> -
Positions.
final
- qts → int
-
Qts.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited