UpdateMonoForumNoPaidException class

Update Mono Forum No Paid Exception.

ID: 9f812b08.

Inheritance

Constructors

UpdateMonoForumNoPaidException({required bool exception, required int channelId, required PeerBase savedPeerId})
Update Mono Forum No Paid Exception constructor.
const
UpdateMonoForumNoPaidException.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

channelId int
Channel Id.
final
exception bool
exception: bit 0 of flags.0?true
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savedPeerId PeerBase
Saved Peer Id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited