UpdateNewBotConnection class

Update New Bot Connection.

ID: b22083a6.

Inheritance

Constructors

UpdateNewBotConnection({required bool confirmed, required int botId, DateTime? date, String? device, String? location})
Update New Bot Connection constructor.
const
UpdateNewBotConnection.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

botId int
Bot Id.
final
confirmed bool
confirmed: bit 0 of flags.0?true
final
date DateTime?
Date.
final
device String?
Device.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
location String?
Location.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited