UpdateNewStoryReaction class

Update New Story Reaction.

ID: 1824e40b.

Inheritance

Constructors

UpdateNewStoryReaction({required int storyId, required PeerBase peer, required ReactionBase reaction})
Update New Story Reaction constructor.
const
UpdateNewStoryReaction.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
peer PeerBase
Peer.
final
reaction ReactionBase
Reaction.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyId int
Story Id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited