UpdatePinnedForumTopics class

Update Pinned Forum Topics.

ID: def143d0.

Inheritance

Constructors

UpdatePinnedForumTopics({required PeerBase peer, List<int>? order})
Update Pinned Forum Topics constructor.
const
UpdatePinnedForumTopics.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
order List<int>?
Order.
final
peer PeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited