UpdateReadMonoForumInbox class

Update Read Mono Forum Inbox.

ID: 77b0e372.

Inheritance

Constructors

UpdateReadMonoForumInbox({required int channelId, required PeerBase savedPeerId, required int readMaxId})
Update Read Mono Forum Inbox constructor.
const
UpdateReadMonoForumInbox.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

channelId int
Channel Id.
final
hashCode int
The hash code for this object.
no setterinherited
readMaxId int
Read Max Id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savedPeerId PeerBase
Saved Peer Id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited