UpdateServiceNotification class

Update Service Notification.

ID: ebe46819.

Inheritance

Constructors

UpdateServiceNotification({required bool popup, required bool invertMedia, DateTime? inboxDate, required String type, required String message, required MessageMediaBase media, required List<MessageEntityBase> entities})
Update Service Notification constructor.
const
UpdateServiceNotification.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

entities List<MessageEntityBase>
Entities.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
inboxDate DateTime?
Inbox Date.
final
invertMedia bool
invert_media: bit 2 of flags.2?true
final
media MessageMediaBase
Media.
final
message String
Message.
final
popup: bit 0 of flags.0?true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited