UpdateStarGiftAuctionState class

Update Star Gift Auction State.

ID: 48e246c2.

Inheritance

Constructors

UpdateStarGiftAuctionState({required int giftId, required StarGiftAuctionStateBase state})
Update Star Gift Auction State constructor.
const
UpdateStarGiftAuctionState.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

giftId int
Gift Id.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state StarGiftAuctionStateBase
State.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited