UpdateStarsRevenueStatus class
Update Stars Revenue Status.
ID: a584b019.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- UpdateBase
- UpdateStarsRevenueStatus
Constructors
- UpdateStarsRevenueStatus({required PeerBase peer, required StarsRevenueStatusBase status})
-
Update Stars Revenue Status constructor.
const
- UpdateStarsRevenueStatus.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- peer → PeerBase
-
Peer.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → StarsRevenueStatusBase
-
Status.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited