UpdateUserTyping class

Update User Typing.

ID: 2a17bf5c.

Inheritance

Constructors

UpdateUserTyping({required int userId, int? topMsgId, required SendMessageActionBase action})
Update User Typing constructor.
const
UpdateUserTyping.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

action SendMessageActionBase
Action.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topMsgId int?
Top Msg Id.
final
userId int
User Id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited