UploadGetFileHashes class

Upload Get File Hashes.

Return Type: List<FileHashBase>. ID: 9156982a.

Inheritance

Constructors

UploadGetFileHashes({required InputFileLocationBase location, required int offset})
Upload Get File Hashes constructor.
const
UploadGetFileHashes.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
location InputFileLocationBase
Location.
final
offset int
Offset.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited