User class
User.
ID: b1b8cc83.
- Inheritance
Constructors
-
User({required bool self, required bool contact, required bool mutualContact, required bool deleted, required bool bot, required bool botChatHistory, required bool botNochats, required bool verified, required bool restricted, required bool min, required bool botInlineGeo, required bool support, required bool scam, required bool applyMinPhoto, required bool fake, required bool botAttachMenu, required bool attachMenuEnabled, required bool botCanEdit, required bool closeFriend, required bool storiesHidden, required bool contactRequirePremium, required bool botBusiness, required bool botHasMainApp, required bool botForumView, required bool botForumCanManageTopics, required bool botCanManageBots, required bool botGuestchat, required bool botGuard, required int id, int? accessHash, String? firstName, String? lastName, String? username, String? phone, UserProfilePhotoBase? photo, UserStatusBase? status, int? botInfoVersion, List<
RestrictionReasonBase> ? restrictionReason, String? botInlinePlaceholder, String? langCode, EmojiStatusBase? emojiStatus, List<UsernameBase> ? usernames, RecentStoryBase? storiesMaxId, PeerColorBase? color, PeerColorBase? profileColor, int? botActiveUsers, int? botVerificationIcon, int? sendPaidMessagesStars, int? linkedCommunityId}) -
User constructor.
const
- User.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- accessHash → int?
-
Access Hash.
final
- applyMinPhoto → bool
-
apply_min_photo: bit 25 of flags.25?true
final
- attachMenuEnabled → bool
-
attach_menu_enabled: bit 29 of flags.29?true
final
- bot → bool
-
bot: bit 14 of flags.14?true
final
- botActiveUsers → int?
-
Bot Active Users.
final
- botAttachMenu → bool
-
bot_attach_menu: bit 27 of flags.27?true
final
- botBusiness → bool
-
bot_business: bit 11 of flags2.11?true
final
- botCanEdit → bool
-
bot_can_edit: bit 1 of flags2.1?true
final
- botCanManageBots → bool
-
bot_can_manage_bots: bit 18 of flags2.18?true
final
- botChatHistory → bool
-
bot_chat_history: bit 15 of flags.15?true
final
- botForumCanManageTopics → bool
-
bot_forum_can_manage_topics: bit 17 of flags2.17?true
final
- botForumView → bool
-
bot_forum_view: bit 16 of flags2.16?true
final
- botGuard → bool
-
bot_guard: bit 20 of flags2.20?true
final
- botGuestchat → bool
-
bot_guestchat: bit 19 of flags2.19?true
final
- botHasMainApp → bool
-
bot_has_main_app: bit 13 of flags2.13?true
final
- botInfoVersion → int?
-
Bot Info Version.
final
- botInlineGeo → bool
-
bot_inline_geo: bit 21 of flags.21?true
final
- botInlinePlaceholder → String?
-
Bot Inline Placeholder.
final
- botNochats → bool
-
bot_nochats: bit 16 of flags.16?true
final
- botVerificationIcon → int?
-
Bot Verification Icon.
final
- closeFriend → bool
-
close_friend: bit 2 of flags2.2?true
final
- color → PeerColorBase?
-
Color.
final
- contact → bool
-
contact: bit 11 of flags.11?true
final
- contactRequirePremium → bool
-
contact_require_premium: bit 10 of flags2.10?true
final
- deleted → bool
-
deleted: bit 13 of flags.13?true
final
- emojiStatus → EmojiStatusBase?
-
Emoji Status.
final
- fake → bool
-
fake: bit 26 of flags.26?true
final
- firstName → String?
-
First Name.
final
- flags → int
-
Flags.
no setter
- flags2 → int
-
Flags2.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Id.
final
- langCode → String?
-
Lang Code.
final
- lastName → String?
-
Last Name.
final
- linkedCommunityId → int?
-
Linked Community Id.
final
- min → bool
-
min: bit 20 of flags.20?true
final
- mutualContact → bool
-
mutual_contact: bit 12 of flags.12?true
final
- phone → String?
-
Phone.
final
- photo → UserProfilePhotoBase?
-
Photo.
final
-
premium: bit 28 of flags.28?true
final
- profileColor → PeerColorBase?
-
Profile Color.
final
- restricted → bool
-
restricted: bit 18 of flags.18?true
final
-
restrictionReason
→ List<
RestrictionReasonBase> ? -
Restriction Reason.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scam → bool
-
scam: bit 24 of flags.24?true
final
- self → bool
-
self: bit 10 of flags.10?true
final
- sendPaidMessagesStars → int?
-
Send Paid Messages Stars.
final
- status → UserStatusBase?
-
Status.
final
- storiesHidden → bool
-
stories_hidden: bit 3 of flags2.3?true
final
- storiesMaxId → RecentStoryBase?
-
Stories Max Id.
final
-
stories_unavailable: bit 4 of flags2.4?true
final
- support → bool
-
support: bit 23 of flags.23?true
final
- username → String?
-
Username.
final
-
usernames
→ List<
UsernameBase> ? -
Usernames.
final
- verified → bool
-
verified: bit 17 of flags.17?true
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited