UsersGetSavedMusic class

Users Get Saved Music.

Return Type: UsersSavedMusicBase. ID: 788d7fe3.

Inheritance

Constructors

UsersGetSavedMusic({required InputUserBase id, required int offset, required int limit, required int hash})
Users Get Saved Music constructor.
const
UsersGetSavedMusic.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hash int
Hash.
final
hashCode int
The hash code for this object.
no setterinherited
id InputUserBase
Id.
final
limit int
Limit.
final
offset int
Offset.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited