UsersGetSavedMusicByID class

Users Get Saved Music By I D.

Return Type: UsersSavedMusicBase. ID: 7573a4e9.

Inheritance

Constructors

UsersGetSavedMusicByID({required InputUserBase id, required List<InputDocumentBase> documents})
Users Get Saved Music By I D constructor.
const
UsersGetSavedMusicByID.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

documents List<InputDocumentBase>
Documents.
final
hashCode int
The hash code for this object.
no setterinherited
id InputUserBase
Id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited