UsersSuggestBirthday class

Users Suggest Birthday.

Return Type: UpdatesBase. ID: fc533372.

Inheritance

Constructors

UsersSuggestBirthday({required InputUserBase id, required BirthdayBase birthday})
Users Suggest Birthday constructor.
const
UsersSuggestBirthday.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

birthday BirthdayBase
Birthday.
final
hashCode int
The hash code for this object.
no setterinherited
id InputUserBase
Id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited