VideoSize class

Video Size.

ID: de33b094.

Inheritance

Constructors

VideoSize({required String type, required int w, required int h, required int size, double? videoStartTs})
Video Size constructor.
const
VideoSize.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
h int
H.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
Size.
final
type String
Type.
final
videoStartTs double?
Video Start Ts.
final
w int
W.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited