WebDomainException class
Web Domain Exception.
ID: 933ca597.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- WebDomainExceptionBase
- WebDomainException
Constructors
- WebDomainException({required String domain, required String url, required String title, int? favicon})
-
Web Domain Exception constructor.
const
- WebDomainException.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited