WebPageAttributeStarGiftCollection class

Web Page Attribute Star Gift Collection.

ID: 31cad303.

Inheritance

Constructors

WebPageAttributeStarGiftCollection({required List<DocumentBase> icons})
Web Page Attribute Star Gift Collection constructor.
const
WebPageAttributeStarGiftCollection.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
icons List<DocumentBase>
Icons.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited