AccountSendConfirmPhoneCode class
Account Send Confirm Phone Code.
Return Type: AuthSentCodeBase.
ID: 1b3faa88.
Constructors
- AccountSendConfirmPhoneCode({required String hash, required CodeSettingsBase settings})
-
Account Send Confirm Phone Code constructor.
const
- AccountSendConfirmPhoneCode.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- hash → String
-
Hash.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → CodeSettingsBase
-
Settings.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited