AccountUpdateBusinessWorkHours class
Account Update Business Work Hours.
Return Type: bool.
ID: 4b00e066.
Constructors
- AccountUpdateBusinessWorkHours({BusinessWorkHoursBase? businessWorkHours})
-
Account Update Business Work Hours constructor.
const
- AccountUpdateBusinessWorkHours.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- businessWorkHours → BusinessWorkHoursBase?
-
Business Work Hours.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited