AccountWebBrowserSettings class
Account Web Browser Settings.
ID: 79eb8cb3.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- AccountWebBrowserSettingsBase
- AccountWebBrowserSettings
Constructors
-
AccountWebBrowserSettings({required bool openExternalBrowser, required bool displayCloseButton, required List<
WebDomainExceptionBase> externalExceptions, required List<WebDomainExceptionBase> inappExceptions, required int hash}) -
Account Web Browser Settings constructor.
const
- AccountWebBrowserSettings.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- displayCloseButton → bool
-
display_close_button: bit 1 of flags.1?true
final
-
externalExceptions
→ List<
WebDomainExceptionBase> -
External Exceptions.
final
- flags → int
-
Flags.
no setter
- hash → int
-
Hash.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inappExceptions
→ List<
WebDomainExceptionBase> -
Inapp Exceptions.
final
- openExternalBrowser → bool
-
open_external_browser: bit 0 of flags.0?true
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited