AiComposeTone class
Ai Compose Tone.
ID: cff63ea9.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- AiComposeToneBase
- AiComposeTone
Constructors
- AiComposeTone({required bool creator, required int id, required int accessHash, required String slug, required String title, int? emojiId, String? prompt, int? installsCount, int? authorId, AiComposeToneExampleBase? exampleEnglish})
-
Ai Compose Tone constructor.
const
- AiComposeTone.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- accessHash → int
-
Access Hash.
final
-
Author Id.
final
- creator → bool
-
creator: bit 0 of flags.0?true
final
- emojiId → int?
-
Emoji Id.
final
- exampleEnglish → AiComposeToneExampleBase?
-
Example English.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Id.
final
- installsCount → int?
-
Installs Count.
final
- prompt → String?
-
Prompt.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slug → String
-
Slug.
final
- title → String
-
Title.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited