AuthFinishPasskeyLogin class
Auth Finish Passkey Login.
Return Type: AuthAuthorizationBase.
ID: 9857ad07.
Constructors
- AuthFinishPasskeyLogin({required InputPasskeyCredentialBase credential, int? fromDcId, int? fromAuthKeyId})
-
Auth Finish Passkey Login constructor.
const
- AuthFinishPasskeyLogin.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- credential → InputPasskeyCredentialBase
-
Credential.
final
- flags → int
-
Flags.
no setter
- fromAuthKeyId → int?
-
From Auth Key Id.
final
- fromDcId → int?
-
From Dc Id.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited