AuthSentCodePaymentRequired class
Auth Sent Code Payment Required.
ID: f8827ebf.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- AuthSentCodeBase
- AuthSentCodePaymentRequired
Constructors
- AuthSentCodePaymentRequired({required String storeProduct, required String phoneCodeHash, required String supportEmailAddress, required String supportEmailSubject, required String currency, required int amount})
-
Auth Sent Code Payment Required constructor.
const
- AuthSentCodePaymentRequired.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- amount → int
-
Amount.
final
- currency → String
-
Currency.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- phoneCodeHash → String
-
Phone Code Hash.
final
-
Premium Days.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storeProduct → String
-
Store Product.
final
- supportEmailAddress → String
-
Support Email Address.
final
- supportEmailSubject → String
-
Support Email Subject.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited