BotAppSettings class
Bot App Settings.
ID: c99b1950.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- BotAppSettingsBase
- BotAppSettings
Constructors
- BotAppSettings({Uint8List? placeholderPath, int? backgroundColor, int? backgroundDarkColor, int? headerColor, int? headerDarkColor})
-
Bot App Settings constructor.
const
- BotAppSettings.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- backgroundColor → int?
-
Background Color.
final
- backgroundDarkColor → int?
-
Background Dark Color.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerColor → int?
-
Header Color.
final
- headerDarkColor → int?
-
Header Dark Color.
final
- placeholderPath → Uint8List?
-
Placeholder Path.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited