BotBusinessConnection class
Bot Business Connection.
ID: 8f34b2f5.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- BotBusinessConnectionBase
- BotBusinessConnection
Constructors
- BotBusinessConnection({required bool disabled, required String connectionId, required int userId, required int dcId, required DateTime date, BusinessBotRightsBase? rights})
-
Bot Business Connection constructor.
const
- BotBusinessConnection.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- connectionId → String
-
Connection Id.
final
- date → DateTime
-
Date.
final
- dcId → int
-
Dc Id.
final
- disabled → bool
-
disabled: bit 1 of flags.1?true
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- rights → BusinessBotRightsBase?
-
Rights.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
User Id.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited