BotVerification class

Bot Verification.

ID: f93cd45c.

Inheritance

Constructors

BotVerification({required int botId, required int icon, required String description})
Bot Verification constructor.
const
BotVerification.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

botId int
Bot Id.
final
description String
Description.
final
hashCode int
The hash code for this object.
no setterinherited
icon int
Icon.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited