BotsCheckDownloadFileParams class
Bots Check Download File Params.
Return Type: bool.
ID: 50077589.
Constructors
- BotsCheckDownloadFileParams({required InputUserBase bot, required String fileName, required String url})
-
Bots Check Download File Params constructor.
const
- BotsCheckDownloadFileParams.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- bot → InputUserBase
-
Bot.
final
- fileName → String
-
File Name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
Url.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited