BotsCreateBot class
Bots Create Bot.
Return Type: UserBase.
ID: e5b17f2b.
Constructors
- BotsCreateBot({required bool viaDeeplink, required String name, required String username, required InputUserBase managerId})
-
Bots Create Bot constructor.
const
- BotsCreateBot.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- managerId → InputUserBase
-
Manager Id.
final
- name → String
-
Name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- username → String
-
Username.
final
- viaDeeplink → bool
-
via_deeplink: bit 0 of flags.0?true
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited