BusinessBotRights class

Business Bot Rights.

ID: a0624cf7.

Inheritance

Constructors

BusinessBotRights({required bool reply, required bool readMessages, required bool deleteSentMessages, required bool deleteReceivedMessages, required bool editName, required bool editBio, required bool editProfilePhoto, required bool editUsername, required bool viewGifts, required bool sellGifts, required bool changeGiftSettings, required bool transferAndUpgradeGifts, required bool transferStars, required bool manageStories})
Business Bot Rights constructor.
const
BusinessBotRights.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

changeGiftSettings bool
change_gift_settings: bit 10 of flags.10?true
final
deleteReceivedMessages bool
delete_received_messages: bit 3 of flags.3?true
final
deleteSentMessages bool
delete_sent_messages: bit 2 of flags.2?true
final
editBio bool
edit_bio: bit 5 of flags.5?true
final
editName bool
edit_name: bit 4 of flags.4?true
final
editProfilePhoto bool
edit_profile_photo: bit 6 of flags.6?true
final
editUsername bool
edit_username: bit 7 of flags.7?true
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
manageStories bool
manage_stories: bit 13 of flags.13?true
final
readMessages bool
read_messages: bit 1 of flags.1?true
final
reply bool
reply: bit 0 of flags.0?true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sellGifts bool
sell_gifts: bit 9 of flags.9?true
final
transferAndUpgradeGifts bool
transfer_and_upgrade_gifts: bit 11 of flags.11?true
final
transferStars bool
transfer_stars: bit 12 of flags.12?true
final
viewGifts bool
view_gifts: bit 8 of flags.8?true
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited