BusinessChatLink class

Business Chat Link.

ID: b4ae666f.

Inheritance

Constructors

BusinessChatLink({required String link, required String message, List<MessageEntityBase>? entities, String? title, required int views})
Business Chat Link constructor.
const
BusinessChatLink.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

entities List<MessageEntityBase>?
Entities.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
Link.
final
message String
Message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
Title.
final
views int
Views.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited