ChannelsSearchPosts class
Channels Search Posts.
Return Type: MessagesMessagesBase.
ID: f2c4f24d.
Constructors
- ChannelsSearchPosts({String? hashtag, String? query, required int offsetRate, required InputPeerBase offsetPeer, required int offsetId, required int limit, int? allowPaidStars})
-
Channels Search Posts constructor.
const
- ChannelsSearchPosts.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- allowPaidStars → int?
-
Allow Paid Stars.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hashtag → String?
-
Hashtag.
final
- limit → int
-
Limit.
final
- offsetId → int
-
Offset Id.
final
- offsetPeer → InputPeerBase
-
Offset Peer.
final
- offsetRate → int
-
Offset Rate.
final
- query → String?
-
Query.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited