ChannelsSetBoostsToUnblockRestrictions class

Channels Set Boosts To Unblock Restrictions.

Return Type: UpdatesBase. ID: ad399cee.

Inheritance

Constructors

ChannelsSetBoostsToUnblockRestrictions({required InputChannelBase channel, required int boosts})
Channels Set Boosts To Unblock Restrictions constructor.
const
ChannelsSetBoostsToUnblockRestrictions.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

boosts int
Boosts.
final
channel InputChannelBase
Channel.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited