ChatThemeUniqueGift class

Chat Theme Unique Gift.

ID: 3458f9c8.

Inheritance

Constructors

ChatThemeUniqueGift({required StarGiftBase gift, required List<ThemeSettingsBase> themeSettings})
Chat Theme Unique Gift constructor.
const
ChatThemeUniqueGift.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

gift StarGiftBase
Gift.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
themeSettings List<ThemeSettingsBase>
Theme Settings.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited