Community class
Community.
ID: 65efe954.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- ChatBase
- Community
Constructors
- Community({required bool creator, required bool left, required bool min, required bool collapsedInDialogs, required int id, int? accessHash, required String title, required ChatPhotoBase photo, required DateTime date, ChatAdminRightsBase? adminRights, ChatBannedRightsBase? defaultBannedRights})
-
Community constructor.
const
- Community.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- accessHash → int?
-
Access Hash.
final
- adminRights → ChatAdminRightsBase?
-
Admin Rights.
final
- collapsedInDialogs → bool
-
collapsed_in_dialogs: bit 20 of flags2.20?true
final
- creator → bool
-
creator: bit 0 of flags.0?true
final
- date → DateTime
-
Date.
final
- defaultBannedRights → ChatBannedRightsBase?
-
Default Banned Rights.
final
- flags → int
-
Flags.
no setter
- flags2 → int
-
Flags2.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Id.
final
- left → bool
-
left: bit 2 of flags.2?true
final
- min → bool
-
min: bit 12 of flags.12?true
final
- photo → ChatPhotoBase
-
Photo.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
Title.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited