ConnectedBot class
Connected Bot.
ID: 033ed001.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- ConnectedBotBase
- ConnectedBot
Constructors
- ConnectedBot({required int botId, required BusinessBotRecipientsBase recipients, required BusinessBotRightsBase rights, String? device, DateTime? date, String? location})
-
Connected Bot constructor.
const
- ConnectedBot.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- botId → int
-
Bot Id.
final
- date → DateTime?
-
Date.
final
- device → String?
-
Device.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- location → String?
-
Location.
final
- recipients → BusinessBotRecipientsBase
-
Recipients.
final
- rights → BusinessBotRightsBase
-
Rights.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited