GlobalPrivacySettings class

Global Privacy Settings.

ID: fe41b34f.

Inheritance

Constructors

GlobalPrivacySettings({required bool archiveAndMuteNewNoncontactPeers, required bool keepArchivedUnmuted, required bool keepArchivedFolders, required bool hideReadMarks, required bool newNoncontactPeersRequirePremium, required bool displayGiftsButton, int? noncontactPeersPaidStars, DisallowedGiftsSettingsBase? disallowedGifts})
Global Privacy Settings constructor.
const
GlobalPrivacySettings.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

archiveAndMuteNewNoncontactPeers bool
archive_and_mute_new_noncontact_peers: bit 0 of flags.0?true
final
disallowedGifts DisallowedGiftsSettingsBase?
Disallowed Gifts.
final
displayGiftsButton bool
display_gifts_button: bit 7 of flags.7?true
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
hideReadMarks bool
hide_read_marks: bit 3 of flags.3?true
final
keepArchivedFolders bool
keep_archived_folders: bit 2 of flags.2?true
final
keepArchivedUnmuted bool
keep_archived_unmuted: bit 1 of flags.1?true
final
newNoncontactPeersRequirePremium bool
new_noncontact_peers_require_premium: bit 4 of flags.4?true
final
noncontactPeersPaidStars int?
Noncontact Peers Paid Stars.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited