InputFileBig class
Input File Big.
ID: fa4f0bb5.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- InputFileBase
- InputFileBig
Constructors
- InputFileBig({required int id, required int parts, required String name})
-
Input File Big constructor.
const
- InputFileBig.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited