InputMediaStakeDice class

Input Media Stake Dice.

ID: f3a9244a.

Inheritance

Constructors

InputMediaStakeDice({required String gameHash, required int tonAmount, required Uint8List clientSeed})
Input Media Stake Dice constructor.
const
InputMediaStakeDice.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

clientSeed Uint8List
Client Seed.
final
gameHash String
Game Hash.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tonAmount int
Ton Amount.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited