InputStorePaymentAuthCode class
Input Store Payment Auth Code.
ID: 3fc18057.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- InputStorePaymentPurposeBase
- InputStorePaymentAuthCode
Constructors
- InputStorePaymentAuthCode({required bool restore, required String phoneNumber, required String phoneCodeHash, required String currency, required int amount})
-
Input Store Payment Auth Code constructor.
const
- InputStorePaymentAuthCode.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- amount → int
-
Amount.
final
- currency → String
-
Currency.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- phoneCodeHash → String
-
Phone Code Hash.
final
- phoneNumber → String
-
Phone Number.
final
-
Premium Days.
final
- restore → bool
-
restore: bit 0 of flags.0?true
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited