KeyboardButtonStyle class
Keyboard Button Style.
ID: 4fdd3430.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- KeyboardButtonStyleBase
- KeyboardButtonStyle
Constructors
- KeyboardButtonStyle({required bool bgPrimary, required bool bgDanger, required bool bgSuccess, int? icon})
-
Keyboard Button Style constructor.
const
- KeyboardButtonStyle.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- bgDanger → bool
-
bg_danger: bit 1 of flags.1?true
final
- bgPrimary → bool
-
bg_primary: bit 0 of flags.0?true
final
- bgSuccess → bool
-
bg_success: bit 2 of flags.2?true
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → int?
-
Icon.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited