Message class

Message.

ID: 7600b9d3.

Inheritance

Constructors

Message({required bool out, required bool mentioned, required bool mediaUnread, required bool silent, required bool post, required bool fromScheduled, required bool legacy, required bool editHide, required bool pinned, required bool noforwards, required bool invertMedia, required bool offline, required bool videoProcessingPending, required bool paidSuggestedPostStars, required bool paidSuggestedPostTon, required int id, PeerBase? fromId, int? fromBoostsApplied, String? fromRank, required PeerBase peerId, PeerBase? savedPeerId, MessageFwdHeaderBase? fwdFrom, int? viaBotId, int? viaBusinessBotId, PeerBase? guestchatViaFrom, MessageReplyHeaderBase? replyTo, required DateTime date, required String message, MessageMediaBase? media, ReplyMarkupBase? replyMarkup, List<MessageEntityBase>? entities, int? views, int? forwards, MessageRepliesBase? replies, DateTime? editDate, String? postAuthor, int? groupedId, MessageReactionsBase? reactions, List<RestrictionReasonBase>? restrictionReason, int? ttlPeriod, int? quickReplyShortcutId, int? effect, FactCheckBase? factcheck, DateTime? reportDeliveryUntilDate, int? paidMessageStars, SuggestedPostBase? suggestedPost, int? scheduleRepeatPeriod, String? summaryFromLanguage, RichMessageBase? richMessage})
Message constructor.
const
Message.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

date DateTime
Date.
final
editDate DateTime?
Edit Date.
final
editHide bool
edit_hide: bit 21 of flags.21?true
final
effect int?
Effect.
final
entities List<MessageEntityBase>?
Entities.
final
factcheck FactCheckBase?
Factcheck.
final
flags int
Flags.
no setter
flags2 int
Flags2.
no setter
forwards int?
Forwards.
final
fromBoostsApplied int?
From Boosts Applied.
final
fromId PeerBase?
From Id.
final
fromRank String?
From Rank.
final
fromScheduled bool
from_scheduled: bit 18 of flags.18?true
final
fwdFrom MessageFwdHeaderBase?
Fwd From.
final
groupedId int?
Grouped Id.
final
guestchatViaFrom PeerBase?
Guestchat Via From.
final
hashCode int
The hash code for this object.
no setterinherited
id int
Id.
final
invertMedia bool
invert_media: bit 27 of flags.27?true
final
legacy bool
legacy: bit 19 of flags.19?true
final
media MessageMediaBase?
Media.
final
mediaUnread bool
media_unread: bit 5 of flags.5?true
final
mentioned bool
mentioned: bit 4 of flags.4?true
final
message String
Message.
final
noforwards bool
noforwards: bit 26 of flags.26?true
final
offline bool
offline: bit 1 of flags2.1?true
final
out bool
out: bit 1 of flags.1?true
final
paidMessageStars int?
Paid Message Stars.
final
paidSuggestedPostStars bool
paid_suggested_post_stars: bit 8 of flags2.8?true
final
paidSuggestedPostTon bool
paid_suggested_post_ton: bit 9 of flags2.9?true
final
peerId PeerBase
Peer Id.
final
pinned bool
pinned: bit 24 of flags.24?true
final
post bool
post: bit 14 of flags.14?true
final
postAuthor String?
Post Author.
final
quickReplyShortcutId int?
Quick Reply Shortcut Id.
final
reactions MessageReactionsBase?
Reactions.
final
replies MessageRepliesBase?
Replies.
final
replyMarkup ReplyMarkupBase?
Reply Markup.
final
replyTo MessageReplyHeaderBase?
Reply To.
final
reportDeliveryUntilDate DateTime?
Report Delivery Until Date.
final
restrictionReason List<RestrictionReasonBase>?
Restriction Reason.
final
richMessage RichMessageBase?
Rich Message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savedPeerId PeerBase?
Saved Peer Id.
final
scheduleRepeatPeriod int?
Schedule Repeat Period.
final
silent bool
silent: bit 13 of flags.13?true
final
suggestedPost SuggestedPostBase?
Suggested Post.
final
summaryFromLanguage String?
Summary From Language.
final
ttlPeriod int?
Ttl Period.
final
viaBotId int?
Via Bot Id.
final
viaBusinessBotId int?
Via Business Bot Id.
final
videoProcessingPending bool
video_processing_pending: bit 4 of flags2.4?true
final
views int?
Views.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited