MessageActionStarGift class
Message Action Star Gift.
ID: ea2c31d3.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- MessageActionBase
- MessageActionStarGift
Constructors
- MessageActionStarGift({required bool nameHidden, required bool saved, required bool converted, required bool upgraded, required bool refunded, required bool canUpgrade, required bool prepaidUpgrade, required bool upgradeSeparate, required bool auctionAcquired, required StarGiftBase gift, TextWithEntitiesBase? message, int? convertStars, int? upgradeMsgId, int? upgradeStars, PeerBase? fromId, PeerBase? peer, int? savedId, String? prepaidUpgradeHash, int? giftMsgId, PeerBase? toId, int? giftNum})
-
Message Action Star Gift constructor.
const
- MessageActionStarGift.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- auctionAcquired → bool
-
auction_acquired: bit 17 of flags.17?true
final
- canUpgrade → bool
-
can_upgrade: bit 10 of flags.10?true
final
- converted → bool
-
converted: bit 3 of flags.3?true
final
- convertStars → int?
-
Convert Stars.
final
- flags → int
-
Flags.
no setter
- fromId → PeerBase?
-
From Id.
final
- gift → StarGiftBase
-
Gift.
final
- giftMsgId → int?
-
Gift Msg Id.
final
- giftNum → int?
-
Gift Num.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → TextWithEntitiesBase?
-
Message.
final
- nameHidden → bool
-
name_hidden: bit 0 of flags.0?true
final
- peer → PeerBase?
-
Peer.
final
- prepaidUpgrade → bool
-
prepaid_upgrade: bit 13 of flags.13?true
final
- prepaidUpgradeHash → String?
-
Prepaid Upgrade Hash.
final
- refunded → bool
-
refunded: bit 9 of flags.9?true
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- saved → bool
-
saved: bit 2 of flags.2?true
final
- savedId → int?
-
Saved Id.
final
- toId → PeerBase?
-
To Id.
final
- upgraded → bool
-
upgraded: bit 5 of flags.5?true
final
- upgradeMsgId → int?
-
Upgrade Msg Id.
final
- upgradeSeparate → bool
-
upgrade_separate: bit 16 of flags.16?true
final
- upgradeStars → int?
-
Upgrade Stars.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited