MessageActionStarGiftPurchaseOffer class

Message Action Star Gift Purchase Offer.

ID: 774278d4.

Inheritance

Constructors

MessageActionStarGiftPurchaseOffer({required bool accepted, required bool declined, required StarGiftBase gift, required StarsAmountBase price, required DateTime expiresAt})
Message Action Star Gift Purchase Offer constructor.
const
MessageActionStarGiftPurchaseOffer.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

accepted bool
accepted: bit 0 of flags.0?true
final
declined bool
declined: bit 1 of flags.1?true
final
expiresAt DateTime
Expires At.
final
flags int
Flags.
no setter
gift StarGiftBase
Gift.
final
hashCode int
The hash code for this object.
no setterinherited
price StarsAmountBase
Price.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited