MessageMediaDocument class
Message Media Document.
ID: 52d8ccd9.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- MessageMediaBase
- MessageMediaDocument
Constructors
-
MessageMediaDocument({required bool spoiler, required bool video, required bool round, required bool voice, DocumentBase? document, List<
DocumentBase> ? altDocuments, PhotoBase? videoCover, int? videoTimestamp, int? ttlSeconds}) -
Message Media Document constructor.
const
- MessageMediaDocument.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
-
altDocuments
→ List<
DocumentBase> ? -
Alt Documents.
final
- document → DocumentBase?
-
Document.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
nopremium: bit 3 of flags.3?true
final
- round → bool
-
round: bit 7 of flags.7?true
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spoiler → bool
-
spoiler: bit 4 of flags.4?true
final
- ttlSeconds → int?
-
Ttl Seconds.
final
- video → bool
-
video: bit 6 of flags.6?true
final
- videoCover → PhotoBase?
-
Video Cover.
final
- videoTimestamp → int?
-
Video Timestamp.
final
- voice → bool
-
voice: bit 8 of flags.8?true
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited