MessagesClickSponsoredMessage class
Messages Click Sponsored Message.
Return Type: bool.
ID: 8235057e.
Constructors
- MessagesClickSponsoredMessage({required bool media, required bool fullscreen, required Uint8List randomId})
-
Messages Click Sponsored Message constructor.
const
- MessagesClickSponsoredMessage.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- flags → int
-
Flags.
no setter
- fullscreen → bool
-
fullscreen: bit 1 of flags.1?true
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- media → bool
-
media: bit 0 of flags.0?true
final
- randomId → Uint8List
-
Random Id.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited