MessagesCreateForumTopic class
Messages Create Forum Topic.
Return Type: UpdatesBase.
ID: 2f98c3d5.
Constructors
- MessagesCreateForumTopic({required bool titleMissing, required InputPeerBase peer, required String title, int? iconColor, int? iconEmojiId, required int randomId, InputPeerBase? sendAs})
-
Messages Create Forum Topic constructor.
const
- MessagesCreateForumTopic.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconColor → int?
-
Icon Color.
final
- iconEmojiId → int?
-
Icon Emoji Id.
final
- peer → InputPeerBase
-
Peer.
final
- randomId → int
-
Random Id.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendAs → InputPeerBase?
-
Send As.
final
- title → String
-
Title.
final
- titleMissing → bool
-
title_missing: bit 4 of flags.4?true
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited