MessagesDialogFilters class
Messages Dialog Filters.
ID: 2ad93719.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- MessagesDialogFiltersBase
- MessagesDialogFilters
Constructors
-
MessagesDialogFilters({required bool tagsEnabled, required List<
DialogFilterBase> filters}) -
Messages Dialog Filters constructor.
const
- MessagesDialogFilters.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
-
filters
→ List<
DialogFilterBase> -
Filters.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tags_enabled: bit 0 of flags.0?true
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited