MessagesEmojiGameDiceInfo class
Messages Emoji Game Dice Info.
ID: 44e56023.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- MessagesEmojiGameInfoBase
- MessagesEmojiGameDiceInfo
Constructors
-
MessagesEmojiGameDiceInfo({required String gameHash, required int prevStake, required int currentStreak, required List<
int> params, int? playsLeft}) -
Messages Emoji Game Dice Info constructor.
const
- MessagesEmojiGameDiceInfo.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- currentStreak → int
-
Current Streak.
final
- flags → int
-
Flags.
no setter
- gameHash → String
-
Game Hash.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
params
→ List<
int> -
Params.
final
- playsLeft → int?
-
Plays Left.
final
- prevStake → int
-
Prev Stake.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited