MessagesGetSavedDialogsByID class

Messages Get Saved Dialogs By I D.

Return Type: MessagesSavedDialogsBase. ID: 6f6f9c96.

Inheritance

Constructors

MessagesGetSavedDialogsByID({InputPeerBase? parentPeer, required List<InputPeerBase> ids})
Messages Get Saved Dialogs By I D constructor.
const
MessagesGetSavedDialogsByID.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
ids List<InputPeerBase>
Ids.
final
parentPeer InputPeerBase?
Parent Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited