MessagesPreparedInlineMessage class

Messages Prepared Inline Message.

ID: ff57708d.

Inheritance

Constructors

MessagesPreparedInlineMessage({required int queryId, required BotInlineResultBase result, required List<InlineQueryPeerTypeBase> peerTypes, required int cacheTime, required List<UserBase> users})
Messages Prepared Inline Message constructor.
const
MessagesPreparedInlineMessage.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

cacheTime int
Cache Time.
final
hashCode int
The hash code for this object.
no setterinherited
peerTypes List<InlineQueryPeerTypeBase>
Peer Types.
final
queryId int
Query Id.
final
result BotInlineResultBase
Result.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
users List<UserBase>
Users.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited