MessagesReportReadMetrics class

Messages Report Read Metrics.

Return Type: bool. ID: 4067c5e6.

Inheritance

Constructors

MessagesReportReadMetrics({required InputPeerBase peer, required List<InputMessageReadMetricBase> metrics})
Messages Report Read Metrics constructor.
const
MessagesReportReadMetrics.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
metrics List<InputMessageReadMetricBase>
Metrics.
final
peer InputPeerBase
Peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited