MessagesRequestChatJoinWebView class
Messages Request Chat Join Web View.
Return Type: WebViewResultBase.
ID: ba9ee679.
Constructors
- MessagesRequestChatJoinWebView({required int queryId, DataJSONBase? themeParams, required String platform})
-
Messages Request Chat Join Web View constructor.
const
- MessagesRequestChatJoinWebView.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- platform → String
-
Platform.
final
- queryId → int
-
Query Id.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- themeParams → DataJSONBase?
-
Theme Params.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited