MessagesSavePreparedInlineMessage class
Messages Save Prepared Inline Message.
Return Type: MessagesBotPreparedInlineMessageBase.
ID: f21f7f2f.
Constructors
-
MessagesSavePreparedInlineMessage({required InputBotInlineResultBase result, required InputUserBase userId, List<
InlineQueryPeerTypeBase> ? peerTypes}) -
Messages Save Prepared Inline Message constructor.
const
- MessagesSavePreparedInlineMessage.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
peerTypes
→ List<
InlineQueryPeerTypeBase> ? -
Peer Types.
final
- result → InputBotInlineResultBase
-
Result.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → InputUserBase
-
User Id.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited