MessagesToggleSuggestedPostApproval class

Messages Toggle Suggested Post Approval.

Return Type: UpdatesBase. ID: 8107455c.

Inheritance

Constructors

MessagesToggleSuggestedPostApproval({required bool reject, required InputPeerBase peer, required int msgId, DateTime? scheduleDate, String? rejectComment})
Messages Toggle Suggested Post Approval constructor.
const
MessagesToggleSuggestedPostApproval.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
msgId int
Msg Id.
final
peer InputPeerBase
Peer.
final
reject bool
reject: bit 1 of flags.1?true
final
rejectComment String?
Reject Comment.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduleDate DateTime?
Schedule Date.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited