MonoForumDialog class
Mono Forum Dialog.
ID: 64407ea7.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- SavedDialogBase
- MonoForumDialog
Constructors
- MonoForumDialog({required bool unreadMark, required bool nopaidMessagesException, required PeerBase peer, required int topMessage, required int readInboxMaxId, required int readOutboxMaxId, required int unreadCount, required int unreadReactionsCount, DraftMessageBase? draft})
-
Mono Forum Dialog constructor.
const
- MonoForumDialog.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- draft → DraftMessageBase?
-
Draft.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- nopaidMessagesException → bool
-
nopaid_messages_exception: bit 4 of flags.4?true
final
- peer → PeerBase
-
Peer.
final
- readInboxMaxId → int
-
Read Inbox Max Id.
final
- readOutboxMaxId → int
-
Read Outbox Max Id.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topMessage → int
-
Top Message.
final
- unreadCount → int
-
Unread Count.
final
- unreadMark → bool
-
unread_mark: bit 3 of flags.3?true
final
- unreadReactionsCount → int
-
Unread Reactions Count.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited