PageListOrderedItemText class
Page List Ordered Item Text.
ID: 15031189.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- PageListOrderedItemBase
- PageListOrderedItemText
Constructors
- PageListOrderedItemText({required bool checkbox, required bool checked, String? num, required RichTextBase text, int? value, String? type})
-
Page List Ordered Item Text constructor.
const
- PageListOrderedItemText.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- checkbox → bool
-
checkbox: bit 0 of flags.0?true
final
- checked → bool
-
checked: bit 1 of flags.1?true
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- num → String?
-
Num.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → RichTextBase
-
Text.
final
- type → String?
-
Type.
final
- value → int?
-
Value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited