PaymentsGetResaleStarGifts class
Payments Get Resale Star Gifts.
Return Type: PaymentsResaleStarGiftsBase.
ID: 7a5fa236.
Constructors
-
PaymentsGetResaleStarGifts({required bool sortByPrice, required bool sortByNum, required bool forCraft, required bool starsOnly, int? attributesHash, required int giftId, List<
StarGiftAttributeIdBase> ? attributes, required String offset, required int limit}) -
Payments Get Resale Star Gifts constructor.
const
- PaymentsGetResaleStarGifts.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
-
attributes
→ List<
StarGiftAttributeIdBase> ? -
Attributes.
final
- attributesHash → int?
-
Attributes Hash.
final
- flags → int
-
Flags.
no setter
- forCraft → bool
-
for_craft: bit 4 of flags.4?true
final
- giftId → int
-
Gift Id.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int
-
Limit.
final
- offset → String
-
Offset.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortByNum → bool
-
sort_by_num: bit 2 of flags.2?true
final
- sortByPrice → bool
-
sort_by_price: bit 1 of flags.1?true
final
- starsOnly → bool
-
stars_only: bit 5 of flags.5?true
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited