PaymentsResaleStarGifts class
Payments Resale Star Gifts.
ID: 947a12df.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- PaymentsResaleStarGiftsBase
- PaymentsResaleStarGifts
Constructors
-
PaymentsResaleStarGifts({required int count, required List<
StarGiftBase> gifts, String? nextOffset, List<StarGiftAttributeBase> ? attributes, int? attributesHash, required List<ChatBase> chats, List<StarGiftAttributeCounterBase> ? counters, required List<UserBase> users}) -
Payments Resale Star Gifts constructor.
const
- PaymentsResaleStarGifts.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
-
attributes
→ List<
StarGiftAttributeBase> ? -
Attributes.
final
- attributesHash → int?
-
Attributes Hash.
final
-
chats
→ List<
ChatBase> -
Chats.
final
- count → int
-
Count.
final
-
counters
→ List<
StarGiftAttributeCounterBase> ? -
Counters.
final
- flags → int
-
Flags.
no setter
-
gifts
→ List<
StarGiftBase> -
Gifts.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextOffset → String?
-
Next Offset.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
users
→ List<
UserBase> -
Users.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited