PaymentsStarGiftUpgradePreview class

Payments Star Gift Upgrade Preview.

ID: 3de1dfed.

Inheritance

Constructors

PaymentsStarGiftUpgradePreview({required List<StarGiftAttributeBase> sampleAttributes, required List<StarGiftUpgradePriceBase> prices, required List<StarGiftUpgradePriceBase> nextPrices})
Payments Star Gift Upgrade Preview constructor.
const
PaymentsStarGiftUpgradePreview.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
nextPrices List<StarGiftUpgradePriceBase>
Next Prices.
final
prices List<StarGiftUpgradePriceBase>
Prices.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleAttributes List<StarGiftAttributeBase>
Sample Attributes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited