PaymentsStarsStatus class
Payments Stars Status.
ID: 6c9ce8ed.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- PaymentsStarsStatusBase
- PaymentsStarsStatus
Constructors
-
PaymentsStarsStatus({required StarsAmountBase balance, List<
StarsSubscriptionBase> ? subscriptions, String? subscriptionsNextOffset, int? subscriptionsMissingBalance, List<StarsTransactionBase> ? history, String? nextOffset, required List<ChatBase> chats, required List<UserBase> users}) -
Payments Stars Status constructor.
const
- PaymentsStarsStatus.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- balance → StarsAmountBase
-
Balance.
final
-
chats
→ List<
ChatBase> -
Chats.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
history
→ List<
StarsTransactionBase> ? -
History.
final
- nextOffset → String?
-
Next Offset.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subscriptions
→ List<
StarsSubscriptionBase> ? -
Subscriptions.
final
- subscriptionsMissingBalance → int?
-
Subscriptions Missing Balance.
final
- subscriptionsNextOffset → String?
-
Subscriptions Next Offset.
final
-
users
→ List<
UserBase> -
Users.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited