PhoneEditGroupCallParticipant class
Phone Edit Group Call Participant.
Return Type: UpdatesBase.
ID: a5273abf.
Constructors
- PhoneEditGroupCallParticipant({required InputGroupCallBase call, required InputPeerBase participant, bool? muted, int? volume, bool? raiseHand, bool? videoStopped, bool? videoPaused, bool? presentationPaused})
-
Phone Edit Group Call Participant constructor.
const
- PhoneEditGroupCallParticipant.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- call → InputGroupCallBase
-
Call.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- muted → bool?
-
muted: bit 0 of flags.0?Bool
final
- participant → InputPeerBase
-
Participant.
final
- presentationPaused → bool?
-
presentation_paused: bit 5 of flags.5?Bool
final
- raiseHand → bool?
-
raise_hand: bit 2 of flags.2?Bool
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- videoPaused → bool?
-
video_paused: bit 4 of flags.4?Bool
final
- videoStopped → bool?
-
video_stopped: bit 3 of flags.3?Bool
final
- volume → int?
-
Volume.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited