PollAnswer class
Poll Answer.
ID: 4b7d786a.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- PollAnswerBase
- PollAnswer
Constructors
- PollAnswer({required TextWithEntitiesBase text, required Uint8List option, MessageMediaBase? media, PeerBase? addedBy, DateTime? date})
-
Poll Answer constructor.
const
- PollAnswer.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- addedBy → PeerBase?
-
Added By.
final
- date → DateTime?
-
Date.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- media → MessageMediaBase?
-
Media.
final
- option → Uint8List
-
Option.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → TextWithEntitiesBase
-
Text.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited