PrepaidStarsGiveaway class
Prepaid Stars Giveaway.
ID: 9a9d77e0.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- PrepaidGiveawayBase
- PrepaidStarsGiveaway
Constructors
- PrepaidStarsGiveaway({required int id, required int stars, required int quantity, required int boosts, required DateTime date})
-
Prepaid Stars Giveaway constructor.
const
- PrepaidStarsGiveaway.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited