RequestedPeerUser class
Requested Peer User.
ID: d62ff46a.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- RequestedPeerBase
- RequestedPeerUser
Constructors
- RequestedPeerUser({required int userId, String? firstName, String? lastName, String? username, PhotoBase? photo})
-
Requested Peer User constructor.
const
- RequestedPeerUser.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- firstName → String?
-
First Name.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastName → String?
-
Last Name.
final
- photo → PhotoBase?
-
Photo.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
User Id.
final
- username → String?
-
Username.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited