SearchPostsFlood class
Search Posts Flood.
ID: 3e0b5b6a.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- SearchPostsFloodBase
- SearchPostsFlood
Constructors
- SearchPostsFlood({required bool queryIsFree, required int totalDaily, required int remains, int? waitTill, required int starsAmount})
-
Search Posts Flood constructor.
const
- SearchPostsFlood.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- queryIsFree → bool
-
query_is_free: bit 0 of flags.0?true
final
- remains → int
-
Remains.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- starsAmount → int
-
Stars Amount.
final
- totalDaily → int
-
Total Daily.
final
- waitTill → int?
-
Wait Till.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited