StarGiftActiveAuctionState class
Star Gift Active Auction State.
ID: d31bc45d.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- StarGiftActiveAuctionStateBase
- StarGiftActiveAuctionState
Constructors
- StarGiftActiveAuctionState({required StarGiftBase gift, required StarGiftAuctionStateBase state, required StarGiftAuctionUserStateBase userState})
-
Star Gift Active Auction State constructor.
const
- StarGiftActiveAuctionState.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- gift → StarGiftBase
-
Gift.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → StarGiftAuctionStateBase
-
State.
final
- userState → StarGiftAuctionUserStateBase
-
User State.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited