StarGiftAttributePattern class
Star Gift Attribute Pattern.
ID: 4e7085ea.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- StarGiftAttributeBase
- StarGiftAttributePattern
Constructors
- StarGiftAttributePattern({required String name, required DocumentBase document, required StarGiftAttributeRarityBase rarity})
-
Star Gift Attribute Pattern constructor.
const
- StarGiftAttributePattern.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- document → DocumentBase
-
Document.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Name.
final
- rarity → StarGiftAttributeRarityBase
-
Rarity.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited