StarGiftAuctionRoundExtendable class
Star Gift Auction Round Extendable.
ID: 0aa021e5.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- StarGiftAuctionRoundBase
- StarGiftAuctionRoundExtendable
Constructors
- StarGiftAuctionRoundExtendable({required int num, required int duration, required int extendTop, required int extendWindow})
-
Star Gift Auction Round Extendable constructor.
const
- StarGiftAuctionRoundExtendable.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited