StarGiftAuctionUserState class
Star Gift Auction User State.
ID: 2eeed1c4.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- StarGiftAuctionUserStateBase
- StarGiftAuctionUserState
Constructors
- StarGiftAuctionUserState({required bool returned, int? bidAmount, DateTime? bidDate, int? minBidAmount, PeerBase? bidPeer, required int acquiredCount})
-
Star Gift Auction User State constructor.
const
- StarGiftAuctionUserState.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- acquiredCount → int
-
Acquired Count.
final
- bidAmount → int?
-
Bid Amount.
final
- bidDate → DateTime?
-
Bid Date.
final
- bidPeer → PeerBase?
-
Bid Peer.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- minBidAmount → int?
-
Min Bid Amount.
final
- returned → bool
-
returned: bit 1 of flags.1?true
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited