StarRefProgram class
Star Ref Program.
ID: dd0c66f2.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- StarRefProgramBase
- StarRefProgram
Constructors
- StarRefProgram({required int botId, required int commissionPermille, int? durationMonths, DateTime? endDate, StarsAmountBase? dailyRevenuePerUser})
-
Star Ref Program constructor.
const
- StarRefProgram.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- botId → int
-
Bot Id.
final
- commissionPermille → int
-
Commission Permille.
final
- dailyRevenuePerUser → StarsAmountBase?
-
Daily Revenue Per User.
final
- durationMonths → int?
-
Duration Months.
final
- endDate → DateTime?
-
End Date.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited