StarsSubscription class
Stars Subscription.
ID: 2e6eab1a.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- StarsSubscriptionBase
- StarsSubscription
Constructors
- StarsSubscription({required bool canceled, required bool canRefulfill, required bool missingBalance, required bool botCanceled, required String id, required PeerBase peer, required DateTime untilDate, required StarsSubscriptionPricingBase pricing, String? chatInviteHash, String? title, WebDocumentBase? photo, String? invoiceSlug})
-
Stars Subscription constructor.
const
- StarsSubscription.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- botCanceled → bool
-
bot_canceled: bit 7 of flags.7?true
final
- canceled → bool
-
canceled: bit 0 of flags.0?true
final
- canRefulfill → bool
-
can_refulfill: bit 1 of flags.1?true
final
- chatInviteHash → String?
-
Chat Invite Hash.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Id.
final
- invoiceSlug → String?
-
Invoice Slug.
final
- missingBalance → bool
-
missing_balance: bit 2 of flags.2?true
final
- peer → PeerBase
-
Peer.
final
- photo → WebDocumentBase?
-
Photo.
final
- pricing → StarsSubscriptionPricingBase
-
Pricing.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
Title.
final
- untilDate → DateTime
-
Until Date.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited