StarsTransaction class
Stars Transaction.
ID: 13659eb0.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- StarsTransactionBase
- StarsTransaction
Constructors
-
StarsTransaction({required bool refund, required bool pending, required bool failed, required bool gift, required bool reaction, required bool stargiftUpgrade, required bool businessTransfer, required bool stargiftResale, required bool postsSearch, required bool stargiftPrepaidUpgrade, required bool stargiftDropOriginalDetails, required bool phonegroupMessage, required bool stargiftAuctionBid, required bool offer, required String id, required StarsAmountBase amount, required DateTime date, required StarsTransactionPeerBase peer, String? title, String? description, WebDocumentBase? photo, DateTime? transactionDate, String? transactionUrl, Uint8List? botPayload, int? msgId, List<
MessageMediaBase> ? extendedMedia, int? subscriptionPeriod, int? giveawayPostId, StarGiftBase? stargift, int? floodskipNumber, int? starrefCommissionPermille, PeerBase? starrefPeer, StarsAmountBase? starrefAmount, int? paidMessages, DateTime? adsProceedsFromDate, DateTime? adsProceedsToDate}) -
Stars Transaction constructor.
const
- StarsTransaction.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- adsProceedsFromDate → DateTime?
-
Ads Proceeds From Date.
final
- adsProceedsToDate → DateTime?
-
Ads Proceeds To Date.
final
- amount → StarsAmountBase
-
Amount.
final
- botPayload → Uint8List?
-
Bot Payload.
final
- businessTransfer → bool
-
business_transfer: bit 21 of flags.21?true
final
- date → DateTime
-
Date.
final
- description → String?
-
Description.
final
-
extendedMedia
→ List<
MessageMediaBase> ? -
Extended Media.
final
- failed → bool
-
failed: bit 6 of flags.6?true
final
- flags → int
-
Flags.
no setter
- floodskipNumber → int?
-
Floodskip Number.
final
- gift → bool
-
gift: bit 10 of flags.10?true
final
- giveawayPostId → int?
-
Giveaway Post Id.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Id.
final
- msgId → int?
-
Msg Id.
final
- offer → bool
-
offer: bit 29 of flags.29?true
final
- paidMessages → int?
-
Paid Messages.
final
- peer → StarsTransactionPeerBase
-
Peer.
final
- pending → bool
-
pending: bit 4 of flags.4?true
final
- phonegroupMessage → bool
-
phonegroup_message: bit 27 of flags.27?true
final
- photo → WebDocumentBase?
-
Photo.
final
- postsSearch → bool
-
posts_search: bit 24 of flags.24?true
final
-
Premium Gift Months.
final
- reaction → bool
-
reaction: bit 11 of flags.11?true
final
- refund → bool
-
refund: bit 3 of flags.3?true
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stargift → StarGiftBase?
-
Stargift.
final
- stargiftAuctionBid → bool
-
stargift_auction_bid: bit 28 of flags.28?true
final
- stargiftDropOriginalDetails → bool
-
stargift_drop_original_details: bit 26 of flags.26?true
final
- stargiftPrepaidUpgrade → bool
-
stargift_prepaid_upgrade: bit 25 of flags.25?true
final
- stargiftResale → bool
-
stargift_resale: bit 22 of flags.22?true
final
- stargiftUpgrade → bool
-
stargift_upgrade: bit 18 of flags.18?true
final
- starrefAmount → StarsAmountBase?
-
Starref Amount.
final
- starrefCommissionPermille → int?
-
Starref Commission Permille.
final
- starrefPeer → PeerBase?
-
Starref Peer.
final
- subscriptionPeriod → int?
-
Subscription Period.
final
- title → String?
-
Title.
final
- transactionDate → DateTime?
-
Transaction Date.
final
- transactionUrl → String?
-
Transaction Url.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited