StatsMegagroupStats class
Stats Megagroup Stats.
ID: ef7ff916.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- StatsMegagroupStatsBase
- StatsMegagroupStats
Constructors
-
StatsMegagroupStats({required StatsDateRangeDaysBase period, required StatsAbsValueAndPrevBase members, required StatsAbsValueAndPrevBase messages, required StatsAbsValueAndPrevBase viewers, required StatsAbsValueAndPrevBase posters, required StatsGraphBase growthGraph, required StatsGraphBase membersGraph, required StatsGraphBase newMembersBySourceGraph, required StatsGraphBase languagesGraph, required StatsGraphBase messagesGraph, required StatsGraphBase actionsGraph, required StatsGraphBase topHoursGraph, required StatsGraphBase weekdaysGraph, required List<
StatsGroupTopPosterBase> topPosters, required List<StatsGroupTopAdminBase> topAdmins, required List<StatsGroupTopInviterBase> topInviters, required List<UserBase> users}) -
Stats Megagroup Stats constructor.
const
- StatsMegagroupStats.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- actionsGraph → StatsGraphBase
-
Actions Graph.
final
- growthGraph → StatsGraphBase
-
Growth Graph.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- languagesGraph → StatsGraphBase
-
Languages Graph.
final
- members → StatsAbsValueAndPrevBase
-
Members.
final
- membersGraph → StatsGraphBase
-
Members Graph.
final
- messages → StatsAbsValueAndPrevBase
-
Messages.
final
- messagesGraph → StatsGraphBase
-
Messages Graph.
final
- newMembersBySourceGraph → StatsGraphBase
-
New Members By Source Graph.
final
- period → StatsDateRangeDaysBase
-
Period.
final
- posters → StatsAbsValueAndPrevBase
-
Posters.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
topAdmins
→ List<
StatsGroupTopAdminBase> -
Top Admins.
final
- topHoursGraph → StatsGraphBase
-
Top Hours Graph.
final
-
topInviters
→ List<
StatsGroupTopInviterBase> -
Top Inviters.
final
-
topPosters
→ List<
StatsGroupTopPosterBase> -
Top Posters.
final
-
users
→ List<
UserBase> -
Users.
final
- viewers → StatsAbsValueAndPrevBase
-
Viewers.
final
- weekdaysGraph → StatsGraphBase
-
Weekdays Graph.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited