StickersCreateStickerSet class
Stickers Create Sticker Set.
Return Type: MessagesStickerSetBase.
ID: 9021ab67.
Constructors
-
StickersCreateStickerSet({required bool masks, required bool emojis, required bool textColor, required InputUserBase userId, required String title, required String shortName, InputDocumentBase? thumb, required List<
InputStickerSetItemBase> stickers, String? software}) -
Stickers Create Sticker Set constructor.
const
- StickersCreateStickerSet.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- emojis → bool
-
emojis: bit 5 of flags.5?true
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- masks → bool
-
masks: bit 0 of flags.0?true
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortName → String
-
Short Name.
final
- software → String?
-
Software.
final
-
stickers
→ List<
InputStickerSetItemBase> -
Stickers.
final
- textColor → bool
-
text_color: bit 6 of flags.6?true
final
- thumb → InputDocumentBase?
-
Thumb.
final
- title → String
-
Title.
final
- userId → InputUserBase
-
User Id.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited