StoriesEditStory class
Stories Edit Story.
Return Type: UpdatesBase.
ID: 2c63a72b.
Constructors
-
StoriesEditStory({required InputPeerBase peer, required int id, InputMediaBase? media, List<
MediaAreaBase> ? mediaAreas, String? caption, List<MessageEntityBase> ? entities, List<InputPrivacyRuleBase> ? privacyRules, InputDocumentBase? music}) -
Stories Edit Story constructor.
const
- StoriesEditStory.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- caption → String?
-
Caption.
final
-
entities
→ List<
MessageEntityBase> ? -
Entities.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Id.
final
- media → InputMediaBase?
-
Media.
final
-
mediaAreas
→ List<
MediaAreaBase> ? -
Media Areas.
final
- music → InputDocumentBase?
-
Music.
final
- peer → InputPeerBase
-
Peer.
final
-
privacyRules
→ List<
InputPrivacyRuleBase> ? -
Privacy Rules.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited