StoriesSearchPosts class
Stories Search Posts.
Return Type: StoriesFoundStoriesBase.
ID: d1810907.
Constructors
- StoriesSearchPosts({String? hashtag, MediaAreaBase? area, InputPeerBase? peer, required String offset, required int limit})
-
Stories Search Posts constructor.
const
- StoriesSearchPosts.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- area → MediaAreaBase?
-
Area.
final
- flags → int
-
Flags.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hashtag → String?
-
Hashtag.
final
- limit → int
-
Limit.
final
- offset → String
-
Offset.
final
- peer → InputPeerBase?
-
Peer.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited