UpdateChatUserTyping class

Update Chat User Typing.

ID: 83487af0.

Inheritance

Constructors

UpdateChatUserTyping({required int chatId, required PeerBase fromId, required SendMessageActionBase action})
Update Chat User Typing constructor.
const
UpdateChatUserTyping.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

action SendMessageActionBase
Action.
final
chatId int
Chat Id.
final
fromId PeerBase
From Id.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited