UpdateEmojiGameInfo class

Update Emoji Game Info.

ID: fb9c547a.

Inheritance

Constructors

UpdateEmojiGameInfo({required MessagesEmojiGameInfoBase info})
Update Emoji Game Info constructor.
const
UpdateEmojiGameInfo.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
info MessagesEmojiGameInfoBase
Info.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited