UrlAuthResultRequest class

Url Auth Result Request.

ID: 3cd623ec.

Inheritance

Constructors

UrlAuthResultRequest({required bool requestWriteAccess, required bool requestPhoneNumber, required bool matchCodesFirst, required bool isApp, required UserBase bot, required String domain, String? browser, String? platform, String? ip, String? region, List<String>? matchCodes, int? userIdHint, String? verifiedAppName})
Url Auth Result Request constructor.
const
UrlAuthResultRequest.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

bot UserBase
Bot.
final
browser String?
Browser.
final
domain String
Domain.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
ip String?
Ip.
final
isApp bool
is_app: bit 6 of flags.6?true
final
matchCodes List<String>?
Match Codes.
final
matchCodesFirst bool
match_codes_first: bit 5 of flags.5?true
final
platform String?
Platform.
final
region String?
Region.
final
requestPhoneNumber bool
request_phone_number: bit 1 of flags.1?true
final
requestWriteAccess bool
request_write_access: bit 0 of flags.0?true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userIdHint int?
User Id Hint.
final
verifiedAppName String?
Verified App Name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited