UserFull class
User Full.
ID: 06cbe645.
- Inheritance
-
- Object
- TlObject
- TlConstructor
- UserFullBase
- UserFull
Constructors
- UserFull({required bool blocked, required bool phoneCallsAvailable, required bool phoneCallsPrivate, required bool canPinMessage, required bool hasScheduled, required bool videoCallsAvailable, required bool voiceMessagesForbidden, required bool translationsDisabled, required bool storiesPinnedAvailable, required bool blockedMyStoriesFrom, required bool wallpaperOverridden, required bool contactRequirePremium, required bool readDatesPrivate, required bool sponsoredEnabled, required bool canViewRevenue, required bool botCanManageEmojiStatus, required bool displayGiftsButton, required bool noforwardsMyEnabled, required bool noforwardsPeerEnabled, required bool unofficialSecurityRisk, required int id, String? about, required PeerSettingsBase settings, PhotoBase? personalPhoto, PhotoBase? profilePhoto, PhotoBase? fallbackPhoto, required PeerNotifySettingsBase notifySettings, BotInfoBase? botInfo, int? pinnedMsgId, required int commonChatsCount, int? folderId, int? ttlPeriod, ChatThemeBase? theme, String? privateForwardName, ChatAdminRightsBase? botGroupAdminRights, ChatAdminRightsBase? botBroadcastAdminRights, WallPaperBase? wallpaper, PeerStoriesBase? stories, BusinessWorkHoursBase? businessWorkHours, BusinessLocationBase? businessLocation, BusinessGreetingMessageBase? businessGreetingMessage, BusinessAwayMessageBase? businessAwayMessage, BusinessIntroBase? businessIntro, BirthdayBase? birthday, int? personalChannelId, int? personalChannelMessage, int? stargiftsCount, StarRefProgramBase? starrefProgram, BotVerificationBase? botVerification, int? sendPaidMessagesStars, DisallowedGiftsSettingsBase? disallowedGifts, StarsRatingBase? starsRating, StarsRatingBase? starsMyPendingRating, DateTime? starsMyPendingRatingDate, ProfileTabBase? mainTab, DocumentBase? savedMusic, TextWithEntitiesBase? note, int? botManagerId})
-
User Full constructor.
const
- UserFull.deserialize(BinaryReader reader)
-
Deserialize.
factory
Properties
- about → String?
-
About.
final
- birthday → BirthdayBase?
-
Birthday.
final
- blocked → bool
-
blocked: bit 0 of flags.0?true
final
- blockedMyStoriesFrom → bool
-
blocked_my_stories_from: bit 27 of flags.27?true
final
- botBroadcastAdminRights → ChatAdminRightsBase?
-
Bot Broadcast Admin Rights.
final
- botCanManageEmojiStatus → bool
-
bot_can_manage_emoji_status: bit 10 of flags2.10?true
final
- botGroupAdminRights → ChatAdminRightsBase?
-
Bot Group Admin Rights.
final
- botInfo → BotInfoBase?
-
Bot Info.
final
- botManagerId → int?
-
Bot Manager Id.
final
- botVerification → BotVerificationBase?
-
Bot Verification.
final
- businessAwayMessage → BusinessAwayMessageBase?
-
Business Away Message.
final
- businessGreetingMessage → BusinessGreetingMessageBase?
-
Business Greeting Message.
final
- businessIntro → BusinessIntroBase?
-
Business Intro.
final
- businessLocation → BusinessLocationBase?
-
Business Location.
final
- businessWorkHours → BusinessWorkHoursBase?
-
Business Work Hours.
final
- canPinMessage → bool
-
can_pin_message: bit 7 of flags.7?true
final
- canViewRevenue → bool
-
can_view_revenue: bit 9 of flags2.9?true
final
- commonChatsCount → int
-
Common Chats Count.
final
- contactRequirePremium → bool
-
contact_require_premium: bit 29 of flags.29?true
final
- disallowedGifts → DisallowedGiftsSettingsBase?
-
Disallowed Gifts.
final
- displayGiftsButton → bool
-
display_gifts_button: bit 16 of flags2.16?true
final
- fallbackPhoto → PhotoBase?
-
Fallback Photo.
final
- flags → int
-
Flags.
no setter
- flags2 → int
-
Flags2.
no setter
- folderId → int?
-
Folder Id.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasScheduled → bool
-
has_scheduled: bit 12 of flags.12?true
final
- id → int
-
Id.
final
- mainTab → ProfileTabBase?
-
Main Tab.
final
- noforwardsMyEnabled → bool
-
noforwards_my_enabled: bit 23 of flags2.23?true
final
- noforwardsPeerEnabled → bool
-
noforwards_peer_enabled: bit 24 of flags2.24?true
final
- note → TextWithEntitiesBase?
-
Note.
final
- notifySettings → PeerNotifySettingsBase
-
Notify Settings.
final
- personalChannelId → int?
-
Personal Channel Id.
final
- personalChannelMessage → int?
-
Personal Channel Message.
final
- personalPhoto → PhotoBase?
-
Personal Photo.
final
- phoneCallsAvailable → bool
-
phone_calls_available: bit 4 of flags.4?true
final
- phoneCallsPrivate → bool
-
phone_calls_private: bit 5 of flags.5?true
final
- pinnedMsgId → int?
-
Pinned Msg Id.
final
- privateForwardName → String?
-
Private Forward Name.
final
- profilePhoto → PhotoBase?
-
Profile Photo.
final
- readDatesPrivate → bool
-
read_dates_private: bit 30 of flags.30?true
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- savedMusic → DocumentBase?
-
Saved Music.
final
- sendPaidMessagesStars → int?
-
Send Paid Messages Stars.
final
- settings → PeerSettingsBase
-
Settings.
final
- sponsoredEnabled → bool
-
sponsored_enabled: bit 7 of flags2.7?true
final
- stargiftsCount → int?
-
Stargifts Count.
final
- starrefProgram → StarRefProgramBase?
-
Starref Program.
final
- starsMyPendingRating → StarsRatingBase?
-
Stars My Pending Rating.
final
- starsMyPendingRatingDate → DateTime?
-
Stars My Pending Rating Date.
final
- starsRating → StarsRatingBase?
-
Stars Rating.
final
- stories → PeerStoriesBase?
-
Stories.
final
- storiesPinnedAvailable → bool
-
stories_pinned_available: bit 26 of flags.26?true
final
- theme → ChatThemeBase?
-
Theme.
final
- translationsDisabled → bool
-
translations_disabled: bit 23 of flags.23?true
final
- ttlPeriod → int?
-
Ttl Period.
final
- unofficialSecurityRisk → bool
-
unofficial_security_risk: bit 26 of flags2.26?true
final
- videoCallsAvailable → bool
-
video_calls_available: bit 13 of flags.13?true
final
- voiceMessagesForbidden → bool
-
voice_messages_forbidden: bit 20 of flags.20?true
final
- wallpaper → WallPaperBase?
-
Wallpaper.
final
- wallpaperOverridden → bool
-
wallpaper_overridden: bit 28 of flags.28?true
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
List< int> buffer) → void -
Serialize.
override
-
toJson(
) → Map< String, dynamic> -
Converts an object to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited