WebDomainException class

Web Domain Exception.

ID: 933ca597.

Inheritance

Constructors

WebDomainException({required String domain, required String url, required String title, int? favicon})
Web Domain Exception constructor.
const
WebDomainException.deserialize(BinaryReader reader)
Deserialize.
factory

Properties

domain String
Domain.
final
favicon int?
Favicon.
final
flags int
Flags.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
Title.
final
url String
Url.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(List<int> buffer) → void
Serialize.
override
toJson() Map<String, dynamic>
Converts an object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited